@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions to perform development and integration builds
  */
 
-#include <ac/errno.h>
+#include <errno.h>
 #include <ac/libintl.h>
 #include <ac/stdio.h>
 #include <ac/stdlib.h>
@@ -28,13 +28,13 @@
 #include <ac/time.h>
 
 #include <aeb.h>
-#include <ael/change/by_state.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <col.h>
 #include <commit.h>
 #include <change.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <error.h>
 #include <help.h>
 #include <lock.h>
@@ -185,7 +185,6 @@ build_main()
 	string_ty	*base;
 
 	trace(("build_main()\n{\n"/*}*/));
-	arglex();
 	log_style = log_style_snuggle_default;
 	project_name = 0;
 	change_number = 0;
@@ -215,7 +214,7 @@ build_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -306,39 +305,6 @@ build_main()
 	lock_take();
 	cstate_data = change_cstate_get(cp);
 
-	/*
-	 * Extract the appropriate row of the change table.
-	 * It is an error if the change is not in the in-development state.
-	 * It is an error if the change is not assigned to the current user.
-	 * It is an error if the change has no files assigned.
-	 */
-	switch (cstate_data->state)
-	{
-	default:
-		change_fatal(cp, 0, i18n("bad build state"));
-		break;
-
-	case cstate_state_being_developed:
-		if (change_is_a_branch(cp))
-			change_fatal(cp, 0, i18n("bad branch build"));
-		if (!str_equal(change_developer_name(cp), user_name(up)))
-			change_fatal(cp, 0, i18n("not developer"));
-		if (!change_file_nth(cp, (size_t)0))
-			change_fatal(cp, 0, i18n("no files"));
-		break;
-
-	case cstate_state_being_integrated:
-		if (!str_equal(change_integrator_name(cp), user_name(up)))
-			change_fatal(cp, 0, i18n("not integrator"));
-		if (partial.nstrings)
-			change_fatal(cp, 0, i18n("bad build, partial"));
-		break;
-	}
-
-	/*
-	 * Resolve relative filenames into project filenames.
-	 * Do this after we know the change is in a buildable state.
-	 */
 	if (partial.nstrings)
 	{
 		string_list_ty	search_path;
@@ -404,7 +370,7 @@ build_main()
 			else
 				s2 = str_format("%S/%S", base, s1);
 			user_become(up);
-			s1 = os_pathname(s2, 0);
+			s1 = os_pathname(s2, 1);
 			user_become_undo();
 			str_free(s2);
 			s2 = 0;
@@ -420,7 +386,7 @@ build_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", partial.string[j]);
+				sub_var_set(scp, "File_Name", "%S", partial.string[j]);
 				change_fatal(cp, scp, i18n("$filename unrelated"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -434,7 +400,7 @@ build_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s2);
+				sub_var_set(scp, "File_Name", "%S", s2);
 				change_fatal(cp, scp, i18n("too many $filename"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -447,6 +413,35 @@ build_main()
 		partial = wl2;
 	}
 
+	/*
+	 * Extract the appropriate row of the change table.
+	 * It is an error if the change is not in the in-development state.
+	 * It is an error if the change is not assigned to the current user.
+	 * It is an error if the change has no files assigned.
+	 */
+	switch (cstate_data->state)
+	{
+	default:
+		change_fatal(cp, 0, i18n("bad build state"));
+		break;
+
+	case cstate_state_being_developed:
+		if (change_is_a_branch(cp))
+			change_fatal(cp, 0, i18n("bad branch build"));
+		if (!str_equal(change_developer_name(cp), user_name(up)))
+			change_fatal(cp, 0, i18n("not developer"));
+		if (!change_file_nth(cp, (size_t)0))
+			change_fatal(cp, 0, i18n("no files"));
+		break;
+
+	case cstate_state_being_integrated:
+		if (!str_equal(change_integrator_name(cp), user_name(up)))
+			change_fatal(cp, 0, i18n("not integrator"));
+		if (partial.nstrings)
+			change_fatal(cp, 0, i18n("bad build, partial"));
+		break;
+	}
+
 	/*
 	 * It is an error if the change attributes include architectures
 	 * not in the project.
@@ -476,7 +471,7 @@ build_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name", arglex_token_name(arglex_token_minimum));
+		sub_var_set(scp, "Name", arglex_token_name(arglex_token_minimum));
 		change_fatal(cp, scp, i18n("$name option not meaningful"));
 		sub_context_delete(scp);
 	}
@@ -500,27 +495,22 @@ build_main()
 		pup = project_user(pp);
 		log_open(change_logfile_get(cp), pup, log_style);
 
-		if
-		(
-			pp->parent
-		&&
-			pconf_data->create_symlinks_before_integration_build
-		)
+		if (pp->parent && pconf_data->create_symlinks_before_build)
 			change_create_symlinks_to_baseline(cp, pp->parent, pup, minimum);
 
 		change_verbose(cp, 0, i18n("integration build started"));
 		change_run_build_command(cp);
 		change_verbose(cp, 0, i18n("integration build complete"));
 
-		if
-		(
-			pp->parent
-		&&
-			pconf_data->create_symlinks_before_integration_build
-		&&
-			pconf_data->remove_symlinks_after_integration_build
-		)
+		if (pp->parent && pconf_data->create_symlinks_before_build)
 		{
+			/*
+			 * Integration builds always remove the symlinks
+			 * again, even if they are kept around in the
+			 * development directories.  This stops them
+			 * becoming stale if there are deeper baseline
+			 * integrations.
+			 */
 			change_remove_symlinks_to_baseline(cp, pp->parent, pup);
 		}
 		user_free(pup);
@@ -567,7 +557,6 @@ build_main()
 	 */
 	if (!partial.nstrings)
 	{
-		change_file_list_metrics_check(cp);
 		change_cstate_write(cp);
 		commit();
 	}
@@ -595,13 +584,20 @@ build_main()
 void
 build()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("build()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,            build_help,         },
-		{ arglex_token_list,            build_list,         },
-	};
+	default:
+		build_main();
+		break;
 
-	trace(("build()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), build_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		build_help();
+		break;
+
+	case arglex_token_list:
+		build_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
