@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,17 +20,17 @@
  * MANIFEST: functions to implement copy file
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/unistd.h>
 #include <ac/libintl.h>
 
 #include <aecp.h>
-#include <ael/project/files.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <commit.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <error.h>
 #include <file.h>
 #include <gettime.h>
@@ -40,7 +40,7 @@
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <project_hist.h>
 #include <sub.h>
 #include <trace.h>
@@ -125,7 +125,7 @@ copy_file_list()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -169,6 +169,7 @@ copy_file_independent()
 	long		delta_number;
 	time_t		delta_date;
 	char		*delta_name;
+	string_ty	*delta_date_implies_edit_number = 0;
 	int		number_of_errors;
 	string_list_ty	search_path;
 	char		*branch;
@@ -176,7 +177,6 @@ copy_file_independent()
 	change_ty	*cp_bogus;
 	int		based;
 	string_ty	*base;
-	char		*output;
 
 	trace(("copy_file_independent()\n{\n"/*}*/));
 	arglex();
@@ -187,7 +187,6 @@ copy_file_independent()
 	delta_name = 0;
 	branch = 0;
 	trunk = 0;
-	output = 0;
 	while (arglex_token != arglex_token_eoln)
 	{
 		switch (arglex_token)
@@ -237,7 +236,7 @@ copy_file_independent()
 					sub_context_ty	*scp;
 
 					scp = sub_context_new();
-					sub_var_set_long(scp, "Number", delta_number);
+					sub_var_set(scp, "Number", "%ld", delta_number);
 					fatal_intl(scp, i18n("delta $number out of range"));
 					/* NOTREACHED */
 					sub_context_delete(scp);
@@ -260,7 +259,15 @@ copy_file_independent()
 			}
 			delta_date = date_scan(arglex_value.alv_string);
 			if (delta_date == (time_t)-1)
-				fatal_date_unknown(arglex_value.alv_string);
+			{
+				sub_context_ty	*scp;
+
+				scp = sub_context_new();
+				sub_var_set(scp, "Name", "%s", arglex_value.alv_string);
+				fatal_intl(scp, i18n("date $name unknown"));
+				/* NOTREACHED */
+				sub_context_delete(scp);
+			}
 			break;
 
 		case arglex_token_branch:
@@ -275,10 +282,6 @@ copy_file_independent()
 			case arglex_token_string:
 				branch = arglex_value.alv_string;
 				break;
-
-			case arglex_token_stdio:
-				branch = "";
-				break;
 			}
 			break;
 
@@ -292,24 +295,6 @@ copy_file_independent()
 		case arglex_token_current_relative:
 			user_relative_filename_preference_argument(copy_file_usage);
 			break;
-
-		case arglex_token_output:
-			if (output)
-				duplicate_option(copy_file_usage);
-			switch (arglex())
-			{
-			default:
-				option_needs_file(arglex_token_output, copy_file_usage);
-
-			case arglex_token_stdio:
-				output = "";
-				break;
-
-			case arglex_token_string:
-				output = arglex_value.alv_string;
-				break;
-			}
-			break;
 		}
 		arglex();
 	}
@@ -341,24 +326,6 @@ copy_file_independent()
 		);
 	}
 
-	/*
-	 * make sure output is unambiguous
-	 */
-	if (output)
-	{
-		if (wl.nstrings != 1)
-		{
-			sub_context_ty	*scp;
-
-			scp = sub_context_new();
-			sub_var_set_long(scp, "Number", (long)wl.nstrings);
-			sub_var_optional(scp, "Number");
-			fatal_intl(scp, i18n("single file with -Output"));
-			/* NOTREACHED */
-			sub_context_delete(scp);
-		}
-	}
-
 	/*
 	 * locate project data
 	 */
@@ -385,15 +352,13 @@ copy_file_independent()
 	 * Take a read lock on the baseline, to ensure that it does
 	 * not change (aeip) for the duration of the copy.
 	 */
-	if (!output)
-	{
-		project_baseline_read_lock_prepare(pp2);
-		lock_take();
-	}
+	project_baseline_read_lock_prepare(pp2);
+	lock_take();
 
 	/*
 	 * it is an error if the delta does not exist
 	 */
+	trace(("mark\n"));
 	if (delta_name)
 	{
 		s1 = str_from_c(delta_name);
@@ -408,7 +373,7 @@ copy_file_independent()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_long(scp, "Name", delta_number);
+			sub_var_set(scp, "Name", "%ld", delta_number);
 			project_fatal(pp2, scp, i18n("no delta $name"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -425,9 +390,11 @@ copy_file_independent()
 	 * and any comparison of paths is done on this "system idea"
 	 * of the pathname.
 	 */
+	trace(("mark\n"));
 	os_become_orig();
 	dd = os_curdir();
 	os_become_undo();
+	trace(("mark\n"));
 	string_list_constructor(&search_path);
 	project_search_path_get(pp2, &search_path, 1);
 
@@ -452,6 +419,7 @@ copy_file_independent()
 		base = str_copy(search_path.string[0]);
 	else
 		base = dd;
+	trace(("mark\n"));
 	string_list_prepend(&search_path, dd);
 
 	/*
@@ -460,6 +428,7 @@ copy_file_independent()
 	 * 2. if the file is inside the search list
 	 * 3. if neither, error
 	 */
+	trace(("mark\n"));
 	string_list_constructor(&wl2);
 	number_of_errors = 0;
 	for (j = 0; j < wl.nstrings; ++j)
@@ -486,35 +455,17 @@ copy_file_independent()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", wl.string[j]);
+			sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 			project_error(pp, scp, i18n("$filename unrelated"));
 			sub_context_delete(scp);
 			++number_of_errors;
 			continue;
 		}
-		project_file_directory_query(pp2, s2, &wl_in, &wl_out);
+		project_file_dir(pp2, s2, &wl_in, &wl_out);
 		if (delta_date != (time_t)-1)
 			string_list_append_list(&wl_in, &wl_out);
 		if (wl_in.nstrings)
-		{
-			if (output)
-			{
-				sub_context_ty	*scp;
-
-				scp = sub_context_new();
-				sub_var_set_charstar
-				(
-					scp,
-					"Name",
-					arglex_token_name(arglex_token_output)
-				);
-				error_intl(scp, i18n("no dir with $name"));
-				sub_context_delete(scp);
-				++number_of_errors;
-			}
-
 			string_list_append_list_unique(&wl2, &wl_in);
-		}
 		else
 			string_list_append_unique(&wl2, s2);
 		string_list_destructor(&wl_in);
@@ -529,6 +480,7 @@ copy_file_independent()
 	 * ensure that each file
 	 * is in the baseline
 	 */
+	trace(("mark\n"));
 	for (j = 0; j < wl.nstrings; ++j)
 	{
 		fstate_src	src_data;
@@ -548,10 +500,10 @@ copy_file_independent()
 
 			scp = sub_context_new();
 			src_data = project_file_find_fuzzy(pp2, s1);
-			sub_var_set_string(scp, "File_Name", s1);
+			sub_var_set(scp, "File_Name", "%S", s1);
 			if (src_data)
 			{
-				sub_var_set_string(scp, "Guess", src_data->file_name);
+				sub_var_set(scp, "Guess", "%S", src_data->file_name);
 				project_error
 				(
 					pp2,
@@ -570,7 +522,7 @@ copy_file_independent()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", s1);
+			sub_var_set(scp, "File_Name", "%S", s1);
 			project_error(pp, scp, i18n("$filename is built"));
 			sub_context_delete(scp);
 			++number_of_errors;
@@ -581,7 +533,7 @@ copy_file_independent()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", number_of_errors);
+		sub_var_set(scp, "Number", "%d", number_of_errors);
 		sub_var_optional(scp, "Number");
 		project_fatal(pp, scp, i18n("no files copied"));
 		sub_context_delete(scp);
@@ -592,15 +544,17 @@ copy_file_independent()
 	 * so can set environment variables
 	 * for the test
 	 */
+	trace(("mark\n"));
 	cp_bogus = change_alloc(pp, project_next_change_number(pp, 1));
 	change_bind_new(cp_bogus);
 	change_architecture_from_pconf(cp_bogus);
 	cp_bogus->bogus = 1;
 
 	/*
-	 * Copy each file into the destination directory.
+	 * Copy each file into the development directory.
 	 * Create any necessary directories along the way.
 	 */
+	trace(("mark\n"));
 	for (j = 0; j < wl.nstrings; ++j)
 	{
 		string_ty	*from;
@@ -609,8 +563,6 @@ copy_file_independent()
 		s1 = wl.string[j];
 		if (delta_date != (time_t)-1)
 		{
-			fstate_src	delta_date_implies_edit;
-
 			/*
 			 * find the edit number,
 			 * given fie file name and delta number
@@ -618,32 +570,26 @@ copy_file_independent()
 			 * NULL returned means that the file
 			 * does not exist at the given delta.
 			 */
-			delta_date_implies_edit =
+			delta_date_implies_edit_number =
 				project_delta_date_to_edit(pp2, delta_date, s1);
-			if (delta_date_implies_edit)
+			if (delta_date_implies_edit_number)
 			{
 				fstate_src	psrc_data;
 
-				assert(delta_date_implies_edit->edit);
-				assert(delta_date_implies_edit->edit->revision);
-
 				/*
 				 * Look in the immediate project...
 				 * the other branch may have been completed.
 				 */
 				psrc_data = project_file_find(pp, s1);
 				assert(psrc_data);
-				assert(psrc_data->edit);
-				assert(psrc_data->edit->revision);
+				assert(psrc_data->edit_number);
 				if
 				(
 					psrc_data
 				&&
-					psrc_data->edit
+					psrc_data->edit_number
 				&&
-					psrc_data->edit->revision
-				&&
-					str_equal(psrc_data->edit->revision, delta_date_implies_edit->edit->revision)
+					str_equal(psrc_data->edit_number, delta_date_implies_edit_number)
 				&&
 					psrc_data->action != file_action_remove
 				)
@@ -653,8 +599,8 @@ copy_file_independent()
 					 * from the immediate project
 					 */
 					from = project_file_path(pp, s1);
-					fstate_src_type.free(delta_date_implies_edit);
-					delta_date_implies_edit = 0;
+					str_free(delta_date_implies_edit_number);
+					delta_date_implies_edit_number = 0;
 				}
 				else
 				{
@@ -672,7 +618,8 @@ copy_file_independent()
 					change_run_history_get_command
 					(
 						cp_bogus,
-						delta_date_implies_edit,
+						s1,
+						delta_date_implies_edit_number,
 						from,
 						up
 					);
@@ -684,14 +631,12 @@ copy_file_independent()
 			/*
 			 * figure where to send it
 			 */
-			if (output)
-				to = str_from_c(output);
-			else
-				to = str_format("%S/%S", dd, s1);
+			to = str_format("%S/%S", dd, s1);
 
 			/*
 			 * copy the file
 			 */
+			trace(("mark\n"));
 			os_become_orig();
 			os_mkdir_between(dd, s1, 02755);
 			if (os_exists(to))
@@ -701,10 +646,10 @@ copy_file_independent()
 			/*
 			 * clean up afterwards
 			 */
-			if (delta_date_implies_edit)
+			if (delta_date_implies_edit_number)
 			{
-				fstate_src_type.free(delta_date_implies_edit);
 				os_unlink_errok(from);
+				str_free(delta_date_implies_edit_number);
 			}
 			os_become_undo();
 			str_free(from);
@@ -713,14 +658,12 @@ copy_file_independent()
 		else
 		{
 			from = project_file_path(pp2, s1);
-			if (output)
-				to = str_from_c(output);
-			else
-				to = str_format("%S/%S", dd, s1);
+			to = str_format("%S/%S", dd, s1);
 
 			/*
 			 * copy the file
 			 */
+	trace(("mark\n"));
 			os_become_orig();
 			os_mkdir_between(dd, s1, 02755);
 			if (os_exists(to))
@@ -740,8 +683,8 @@ copy_file_independent()
 	/*
 	 * release the baseline lock
 	 */
-	if (!output)
-		lock_release();
+	trace(("mark\n"));
+	lock_release();
 
 	/*
 	 * verbose success message
@@ -751,7 +694,7 @@ copy_file_independent()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", wl.string[j]);
+		sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 		project_verbose(pp, scp, i18n("copied $filename"));
 		sub_context_delete(scp);
 	}
@@ -789,6 +732,7 @@ copy_file_main()
 	time_t		delta_date;
 	long		delta_number;
 	char		*delta_name;
+	string_ty	*delta_date_implies_edit_number = 0;
 	int		config_seen;
 	string_ty	*config_name;
 	int		number_of_errors;
@@ -800,10 +744,8 @@ copy_file_main()
 	int		based;
 	string_ty	*base;
 	sub_context_ty	*scp;
-	fstate_src	delta_date_implies_edit = 0;
 
 	trace(("copy_file_main()\n{\n"/*}*/));
-	arglex();
 	string_list_constructor(&wl);
 	stomp = 0;
 	project_name = 0;
@@ -861,7 +803,7 @@ copy_file_main()
 			else if (change_number < 1)
 			{
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -896,7 +838,7 @@ copy_file_main()
 				if (delta_number < 0)
 				{
 					scp = sub_context_new();
-					sub_var_set_long(scp, "Number", delta_number);
+					sub_var_set(scp, "Number", "%ld", delta_number);
 					fatal_intl(scp, i18n("delta $number out of range"));
 					/* NOTREACHED */
 					sub_context_delete(scp);
@@ -921,7 +863,7 @@ copy_file_main()
 			if (delta_date == (time_t)-1)
 			{
 				scp = sub_context_new();
-				sub_var_set_charstar(scp, "Name", arglex_value.alv_string);
+				sub_var_set(scp, "Name", "%s", arglex_value.alv_string);
 				fatal_intl(scp, i18n("date $name unknown"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -958,10 +900,6 @@ copy_file_main()
 			case arglex_token_string:
 				branch = arglex_value.alv_string;
 				break;
-
-			case arglex_token_stdio:
-				branch = "";
-				break;
 			}
 			break;
 
@@ -1025,7 +963,7 @@ copy_file_main()
 		if (wl.nstrings != 1)
 		{
 			scp = sub_context_new();
-			sub_var_set_long(scp, "Number", (long)wl.nstrings);
+			sub_var_set(scp, "Number", "%ld", (long)wl.nstrings);
 			sub_var_optional(scp, "Number");
 			fatal_intl(scp, i18n("single file with -Output"));
 			/* NOTREACHED */
@@ -1125,7 +1063,7 @@ copy_file_main()
 		if (delta_date == (time_t)-1)
 		{
 			scp = sub_context_new();
-			sub_var_set_long(scp, "Name", delta_number);
+			sub_var_set(scp, "Name", "%ld", delta_number);
 			change_fatal(cp, scp, i18n("no delta $name"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -1202,13 +1140,13 @@ copy_file_main()
 		if (!s2)
 		{
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", wl.string[j]);
+			sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 			change_error(cp, scp, i18n("$filename unrelated"));
 			sub_context_delete(scp);
 			++number_of_errors;
 			continue;
 		}
-		project_file_directory_query(pp2, s2, &wl_in, &wl_out);
+		project_file_dir(pp2, s2, &wl_in, &wl_out);
 		if (delta_date != (time_t)-1)
 			string_list_append_list(&wl_in, &wl_out);
 		if (wl_in.nstrings)
@@ -1223,7 +1161,7 @@ copy_file_main()
 			if (output)
 			{
 				scp = sub_context_new();
-				sub_var_set_charstar(scp, "Name", arglex_token_name(arglex_token_output));
+				sub_var_set(scp, "Name", "%s", arglex_token_name(arglex_token_output));
 				error_intl(scp, i18n("no dir with $name"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -1239,7 +1177,7 @@ copy_file_main()
 					if (string_list_member(&wl2, s3))
 					{
 						scp = sub_context_new();
-						sub_var_set_string(scp, "File_Name", s3);
+						sub_var_set(scp, "File_Name", "%S", s3);
 						change_error(cp, scp, i18n("too many $filename"));
 						sub_context_delete(scp);
 						++number_of_errors;
@@ -1255,10 +1193,10 @@ copy_file_main()
 			{
 				scp = sub_context_new();
 				if (s2->str_length)
-					sub_var_set_string(scp, "File_Name", s2);
+					sub_var_set(scp, "File_Name", "%S", s2);
 				else
-					sub_var_set_charstar(scp, "File_Name", ".");
-				sub_var_set_long(scp, "Number", (long)wl_in.nstrings);
+					sub_var_set(scp, "File_Name", ".");
+				sub_var_set(scp, "Number", "%ld", (long)wl_in.nstrings);
 				sub_var_optional(scp, "Number");
 				change_error(cp, scp, i18n("directory $filename contains no relevant files"));
 				sub_context_delete(scp);
@@ -1270,7 +1208,7 @@ copy_file_main()
 			if (string_list_member(&wl2, s2))
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s2);
+				sub_var_set(scp, "File_Name", "%S", s2);
 				change_error(cp, scp, i18n("too many $filename"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -1302,7 +1240,7 @@ copy_file_main()
 		if (change_file_find(cp, s1) && !stomp && !output)
 		{
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", s1);
+			sub_var_set(scp, "File_Name", "%S", s1);
 			change_error(cp, scp, i18n("bad cp, file $filename dup"));
 			sub_context_delete(scp);
 			++number_of_errors;
@@ -1337,10 +1275,10 @@ copy_file_main()
 		{
 			scp = sub_context_new();
 			src_data = project_file_find_fuzzy(pp2, s1);
-			sub_var_set_string(scp, "File_Name", s1);
+			sub_var_set(scp, "File_Name", "%S", s1);
 			if (src_data)
 			{
-				sub_var_set_string(scp, "Guess", src_data->file_name);
+				sub_var_set(scp, "Guess", "%S", src_data->file_name);
 				project_error
 				(
 					pp2,
@@ -1357,7 +1295,7 @@ copy_file_main()
 		if (src_data && src_data->usage == file_usage_build && !output)
 		{
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", s1);
+			sub_var_set(scp, "File_Name", "%S", s1);
 			change_error(cp, scp, i18n("$filename is built"));
 			sub_context_delete(scp);
 			++number_of_errors;
@@ -1366,7 +1304,7 @@ copy_file_main()
 	if (number_of_errors)
 	{
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", number_of_errors);
+		sub_var_set(scp, "Number", "%d", number_of_errors);
 		sub_var_optional(scp, "Number");
 		change_fatal(cp, scp, i18n("no files copied"));
 		sub_context_delete(scp);
@@ -1391,11 +1329,9 @@ copy_file_main()
 		string_ty	*to;
 
 		s1 = wl.string[j];
-		delta_date_implies_edit = 0;
+		delta_date_implies_edit_number = 0;
 		if (delta_date != (time_t)-1)
 		{
-			int unlink_from = 0;
-
 			/*
 			 * find the edit number,
 			 * given the file name and delta number
@@ -1403,9 +1339,9 @@ copy_file_main()
 			 * NULL returned means that the file
 			 * does not exist at the given delta.
 			 */
-			delta_date_implies_edit =
+			delta_date_implies_edit_number =
 				project_delta_date_to_edit(pp2, delta_date, s1);
-			if (delta_date_implies_edit)
+			if (delta_date_implies_edit_number)
 			{
 				fstate_src	psrc_data;
 
@@ -1418,11 +1354,9 @@ copy_file_main()
 				(
 					psrc_data
 				&&
-					psrc_data->edit
+					psrc_data->edit_number
 				&&
-					psrc_data->edit->revision
-				&&
-					str_equal(psrc_data->edit->revision, delta_date_implies_edit->edit->revision)
+					str_equal(psrc_data->edit_number, delta_date_implies_edit_number)
 				&&
 					psrc_data->action != file_action_remove
 				)
@@ -1432,6 +1366,8 @@ copy_file_main()
 					 * from the immediate project
 					 */
 					from = project_file_path(pp, s1);
+					str_free(delta_date_implies_edit_number);
+					delta_date_implies_edit_number = 0;
 				}
 				else
 				{
@@ -1439,7 +1375,6 @@ copy_file_main()
 					 * make a temporary file
 					 */
 					from = os_edit_filename(0);
-					unlink_from = 1;
 					user_become(up);
 					undo_unlink_errok(from);
 					user_become_undo();
@@ -1450,7 +1385,8 @@ copy_file_main()
 					change_run_history_get_command
 					(
 						cp,
-						delta_date_implies_edit,
+						s1,
+						delta_date_implies_edit_number,
 						from,
 						up
 					);
@@ -1487,7 +1423,7 @@ copy_file_main()
 			/*
 			 * clean up afterwards
 			 */
-			if (unlink_from)
+			if (delta_date_implies_edit_number)
 				os_unlink_errok(from);
 			user_become_undo();
 			str_free(from);
@@ -1536,36 +1472,19 @@ copy_file_main()
 
 			p_src_data = project_file_find(pp2, s1);
 			assert(p_src_data);
-			assert(p_src_data->edit);
-			assert(p_src_data->edit->revision);
-			assert(p_src_data->edit_origin);
-			assert(p_src_data->edit_origin->revision);
+			assert(p_src_data->edit_number);
+			assert(p_src_data->edit_number_origin);
 			c_src_data = change_file_find(cp, s1);
 			if (!c_src_data)
 			{
 				c_src_data = change_file_new(cp, s1);
 				c_src_data->action =
 					(
-						/*
-						 * NULL means the file
-						 * did not exist at the
-						 * specified delta.
-						 */
-						(
-							delta_date != (time_t)-1
-						&&
-							!delta_date_implies_edit
-						)
+						read_only
 					?
-						file_action_remove
+						file_action_insulate
 					:
-						(
-							read_only
-						?
-							file_action_insulate
-						:
-							file_action_modify
-						)
+						file_action_modify
 					);
 				c_src_data->usage = p_src_data->usage;
 
@@ -1591,53 +1510,45 @@ copy_file_main()
 			}
 
 			/*
-			 * p_src_data->edit
+			 * p_src_data->edit_number
 			 *	The head revision of the branch.
-			 * p_src_data->edit_origin
+			 * p_src_data->edit_number_origin
 			 *	The version originally copied.
 			 *
-			 * c_src_data->edit
+			 * c_src_data->edit_number
 			 *	Not meaningful until after integrate pass.
-			 * c_src_data->edit_origin
+			 * c_src_data->edit_number_origin
 			 *	The version originally copied.
-			 * c_src_data->edit_origin_new
-			 *	Updates branch edit_origin on
+			 * c_src_data->edit_number_origin_new
+			 *	Updates branch edit_number_origin on
 			 *	integrate pass.
 			 */
-			if (c_src_data->edit)
+			if (c_src_data->edit_number)
 			{
-				assert(c_src_data->edit->revision);
-				history_version_type.free(c_src_data->edit);
-				c_src_data->edit = 0;
+				str_free(c_src_data->edit_number);
+				c_src_data->edit_number = 0;
 			}
-			if (c_src_data->edit_origin)
+			if (c_src_data->edit_number_origin)
 			{
-				assert(c_src_data->edit_origin->revision);
-				history_version_type.free(c_src_data->edit_origin);
-				c_src_data->edit_origin = 0;
+				str_free(c_src_data->edit_number_origin);
+				c_src_data->edit_number_origin = 0;
 			}
-			if (c_src_data->edit_origin_new)
+			if (c_src_data->edit_number_origin_new)
 			{
-				assert(c_src_data->edit_origin_new->revision);
-				history_version_type.free(c_src_data->edit_origin_new);
-				c_src_data->edit_origin_new = 0;
+				str_free(c_src_data->edit_number_origin_new);
+				c_src_data->edit_number_origin_new = 0;
 			}
-			assert(p_src_data->edit);
-			assert(p_src_data->edit->revision);
-			assert(p_src_data->edit_origin);
-			assert(p_src_data->edit_origin->revision);
-			if (delta_date_implies_edit)
+			assert(p_src_data->edit_number);
+			assert(p_src_data->edit_number_origin);
+			if (delta_date_implies_edit_number)
 			{
-				c_src_data->edit_origin =
-					history_version_copy
-					(
-						delta_date_implies_edit->edit
-					);
+				c_src_data->edit_number_origin =
+				     str_copy(delta_date_implies_edit_number);
 			}
 			else
 			{
-				c_src_data->edit_origin =
-					history_version_copy(p_src_data->edit);
+				c_src_data->edit_number_origin =
+					str_copy(p_src_data->edit_number);
 			}
 
 			/*
@@ -1653,14 +1564,14 @@ copy_file_main()
 				c_src_data->file_fp = 0;
 			}
 		}
-		if (delta_date_implies_edit)
-			fstate_src_type.free(delta_date_implies_edit);
+		if (delta_date_implies_edit_number)
+			str_free(delta_date_implies_edit_number);
 
 		/*
 		 * verbose progress message
 		 */
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", s1);
+		sub_var_set(scp, "File_Name", "%S", s1);
 		change_verbose(cp, scp, i18n("copied $filename"));
 		sub_context_delete(scp);
 	}
@@ -1700,7 +1611,7 @@ copy_file_main()
 	 * verbose success message
 	 */
 	scp = sub_context_new();
-	sub_var_set_long(scp, "Number", (long)wl.nstrings);
+	sub_var_set(scp, "Number", "%ld", (long)wl.nstrings);
 	sub_var_optional(scp, "Number");
 	change_verbose(cp, scp, i18n("copy file complete"));
 	sub_context_delete(scp);
@@ -1719,14 +1630,24 @@ copy_file_main()
 void
 copy_file()
 {
-	static arglex_dispatch_ty dispatch[] =
-	{
-		{ arglex_token_help,		copy_file_help,		}, 
-		{ arglex_token_list,		copy_file_list,		}, 
-		{ arglex_token_independent,	copy_file_independent,	},
-	};
-
 	trace(("copy_file()\n{\n"/*}*/));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), copy_file_main);
+	switch (arglex())
+	{
+	default:
+		copy_file_main();
+		break;
+
+	case arglex_token_help:
+		copy_file_help();
+		break;
+
+	case arglex_token_list:
+		copy_file_list();
+		break;
+
+	case arglex_token_independent:
+		copy_file_independent();
+		break;
+	}
 	trace((/*{*/"}\n"));
 }
