@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,17 +20,17 @@
  * MANIFEST: functions to impliment copy file undo
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/unistd.h>
 #include <ac/libintl.h>
 
 #include <aecpu.h>
-#include <ael/change/files.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <commit.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <error.h>
 #include <file.h>
 #include <help.h>
@@ -39,7 +39,7 @@
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <sub.h>
 #include <trace.h>
 #include <undo.h>
@@ -117,7 +117,7 @@ copy_file_undo_list()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -169,7 +169,6 @@ copy_file_undo_main()
 	string_ty	*base;
 
 	trace(("copy_file_undo_main()\n{\n"/*}*/));
-	arglex();
 	string_list_constructor(&wl);
 	project_name = 0;
 	change_number = 0;
@@ -221,7 +220,7 @@ copy_file_undo_main()
 			else if (change_number < 1)
 			{
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -376,13 +375,13 @@ copy_file_undo_main()
 		if (!s2)
 		{
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", wl.string[j]);
+			sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 			change_error(cp, scp, i18n("$filename unrelated"));
 			sub_context_delete(scp);
 			++number_of_errors;
 			continue;
 		}
-		change_file_directory_query(cp, s2, &wl_in, 0);
+		change_file_dir(cp, s2, &wl_in, 0);
 		if (wl_in.nstrings)
 		{
 			int	used;
@@ -411,7 +410,7 @@ copy_file_undo_main()
 						if (string_list_member(&wl2, s3))
 						{
 							scp = sub_context_new();
-							sub_var_set_string(scp, "File_Name", s3);
+							sub_var_set(scp, "File_Name", "%S", s3);
 							change_error(cp, scp, i18n("too many $filename"));
 							sub_context_delete(scp);
 							++number_of_errors;
@@ -433,10 +432,10 @@ copy_file_undo_main()
 			{
 				scp = sub_context_new();
 				if (s2->str_length)
-					sub_var_set_string(scp, "File_Name", s2);
+					sub_var_set(scp, "File_Name", "%S", s2);
 				else
-					sub_var_set_charstar(scp, "File_Name", ".");
-				sub_var_set_long(scp, "Number", (long)wl_in.nstrings);
+					sub_var_set(scp, "File_Name", ".");
+				sub_var_set(scp, "Number", "%ld", (long)wl_in.nstrings);
 				sub_var_optional(scp, "Number");
 				change_error
 				(
@@ -453,7 +452,7 @@ copy_file_undo_main()
 			if (string_list_member(&wl2, s2))
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s2);
+				sub_var_set(scp, "File_Name", "%S", s2);
 				change_error(cp, scp, i18n("too many $filename"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -486,10 +485,10 @@ copy_file_undo_main()
 		{
 			scp = sub_context_new();
 			src_data = change_file_find_fuzzy(cp, s1);
-			sub_var_set_string(scp, "File_Name", s1);
+			sub_var_set(scp, "File_Name", "%S", s1);
 			if (src_data)
 			{
-				sub_var_set_string(scp, "Guess", src_data->file_name);
+				sub_var_set(scp, "Guess", "%S", src_data->file_name);
 				change_error
 				(
 					cp,
@@ -512,7 +511,7 @@ copy_file_undo_main()
 		case file_action_create:
 		case file_action_remove:
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", s1);
+			sub_var_set(scp, "File_Name", "%S", s1);
 			change_error(cp, scp, i18n("bad cp undo $filename"));
 			sub_context_delete(scp);
 			++number_of_errors;
@@ -527,7 +526,7 @@ copy_file_undo_main()
 	if (number_of_errors)
 	{
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", number_of_errors);
+		sub_var_set(scp, "Number", "%d", number_of_errors);
 		sub_var_optional(scp, "Number");
 		change_fatal(cp, scp, i18n("no files uncopied"));
 		sub_context_delete(scp);
@@ -569,7 +568,6 @@ copy_file_undo_main()
 			string_ty	*blf;
 			int		different;
 			fstate_src	src_data;
-			fstate_src	psrc_data;
 
 			/*
 			 * Leave cross branch merges alone, even if they
@@ -577,36 +575,9 @@ copy_file_undo_main()
 			 * about the merge, not the file contents.
 			 */
 			src_data = change_file_find(cp, s1);
-			if (!src_data)
-				goto not_this_one;
-			if (src_data->edit_origin_new)
-			{
-				assert(src_data->edit_origin_new->revision);
-				goto not_this_one;
-			}
-			if (src_data->action == file_action_create)
-				goto not_this_one;
-			if (src_data->action == file_action_remove)
+			if (src_data && src_data->edit_number_origin_new)
 				goto not_this_one;
 
-			/*
-			 * The file could have vanished from under us,
-			 * so make sure this is sensable.
-			 */
-			psrc_data = project_file_find(pp, s1);
-			if
-			(
-				!psrc_data
-			||
-				psrc_data->deleted_by
-			||
-				psrc_data->about_to_be_created_by
-			)
-				goto not_this_one;
-
-			/*
-			 * Compare the files.
-			 */
 			blf = project_file_path(pp, s1);
 			assert(blf);
 			user_become(up);
@@ -717,7 +688,7 @@ copy_file_undo_main()
 	 * run the change file command
 	 * and the project file command if necessary
 	 */
-	change_run_change_file_undo_command(cp, &wl, up);
+	change_run_change_file_command(cp, &wl, up);
 	change_run_project_file_command(cp, up);
 
 	/*
@@ -733,7 +704,7 @@ copy_file_undo_main()
 	for (j = 0; j < wl.nstrings; ++j)
 	{
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", wl.string[j]);
+		sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 		change_verbose(cp, scp, i18n("$filename gone"));
 		sub_context_delete(scp);
 	}
@@ -749,13 +720,20 @@ copy_file_undo_main()
 void
 copy_file_undo()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("copy_file_undo()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		copy_file_undo_help,	},
-		{ arglex_token_list,		copy_file_undo_list,	},
-	};
+	default:
+		copy_file_undo_main();
+		break;
 
-	trace(("copy_file_undo()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), copy_file_undo_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		copy_file_undo_help();
+		break;
+
+	case arglex_token_list:
+		copy_file_undo_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
