@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,16 +20,16 @@
  * MANIFEST: difference a change
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/time.h>
 #include <ac/unistd.h>
 
 #include <aed.h>
-#include <ael/change/files.h>
+#include <ael.h>
 #include <arglex2.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <col.h>
 #include <commit.h>
 #include <error.h>
@@ -39,7 +39,7 @@
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <sub.h>
 #include <trace.h>
 #include <undo.h>
@@ -119,7 +119,7 @@ difference_list()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -153,7 +153,7 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 	char		*branch;
 	long		cn2;
 	log_style_ty	log_style;
-	string_list_ty	*wl;
+	string_list_ty		*wl;
 {
 	string_ty	*dd1;
 	string_ty	*dd2;
@@ -297,7 +297,7 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_error(cp, scp, i18n("$filename unrelated"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -327,7 +327,7 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_error(cp, scp, i18n("no $filename"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -338,7 +338,7 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_error(cp, scp, i18n("bad cp undo $filename"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -350,7 +350,7 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_error(acp, scp, i18n("no $filename"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -361,7 +361,7 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_error(acp, scp, i18n("bad cp undo $filename"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -377,7 +377,7 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_long(scp, "Number", number_of_errors);
+			sub_var_set(scp, "Number", "%d", number_of_errors);
 			sub_var_optional(scp, "Number");
 			change_fatal(cp, scp, i18n("diff fail"));
 			/* NOTREACHED */
@@ -414,9 +414,11 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 			output = change_file_path(cp, s1);
 			assert(output);
 			input = str_format("%S,B", output);
-			user_become(up);
+			change_become(cp);
 			os_rename(output, input);
-			user_become_undo();
+			undo_unlink_errok(output);
+			undo_rename(input, output);
+			change_become_undo();
 		}
 		else
 		{
@@ -446,14 +448,24 @@ anticipate(project_name, change_number, branch, cn2, log_style, wl)
 			undo_unlink_errok(original);
 			user_become_undo();
 
-			assert(src1_data->edit);
-			assert(src1_data->edit->revision);
-			assert(src1_data->edit_origin);
-			assert(src1_data->edit_origin->revision);
+			if
+			(
+				src1_data->edit_number
+			&&
+				!src1_data->edit_number_origin
+			)
+			{
+				/* Historical 2.3 -> 3.0 transition. */
+				src1_data->edit_number_origin =
+					str_copy(src1_data->edit_number);
+			}
+
+			assert(src1_data->edit_number_origin);
 			change_run_history_get_command
 			(
 				cp,
-				src1_data,
+				s1,
+				src1_data->edit_number_origin,
 				original,
 				up
 			);
@@ -555,7 +567,6 @@ difference_main()
 	int		grandparent;
 
 	trace(("difference_main()\n{\n"/*}*/));
-	arglex();
 	string_list_constructor(&wl);
 	string_list_constructor(&need_new_build);
 	project_name = 0;
@@ -596,7 +607,7 @@ difference_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				fatal_intl(scp, i18n("too many $filename"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -622,7 +633,7 @@ difference_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -656,7 +667,7 @@ difference_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", cn2);
+				sub_var_set(scp, "Number", "%ld", cn2);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -708,10 +719,6 @@ difference_main()
 			case arglex_token_string:
 				branch = arglex_value.alv_string;
 				break;
-
-			case arglex_token_stdio:
-				branch = "";
-				break;
 			}
 			break;
 
@@ -956,7 +963,7 @@ difference_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_error(cp, scp, i18n("$filename unrelated"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -981,7 +988,7 @@ difference_main()
 			string_list_ty		wl_in;
 
 			s1 = wl.string[j];
-			change_file_directory_query(cp, s1, &wl_in, 0);
+			change_file_dir(cp, s1, &wl_in, 0);
 			if (wl_in.nstrings)
 				string_list_append_list_unique(&wl2, &wl_in);
 			else if (change_file_find(cp, s1))
@@ -991,7 +998,7 @@ difference_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_error(cp, scp, i18n("no $filename"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -1009,7 +1016,7 @@ difference_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_long(scp, "Number", number_of_errors);
+			sub_var_set(scp, "Number", "%d", number_of_errors);
 			sub_var_optional(scp, "Number");
 			change_fatal(cp, scp, i18n("diff fail"));
 			sub_context_delete(scp);
@@ -1138,7 +1145,6 @@ difference_main()
 			string_ty	*curfile;
 			string_ty	*outname;
 			string_ty	*most_recent;
-			fstate_src	reconstruct;
 
 			/*
 			 * find the relevant change src data
@@ -1204,7 +1210,7 @@ difference_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_fatal
 				(
 					cp,
@@ -1227,6 +1233,8 @@ difference_main()
 				trace_string(curfile->str_text);
 				user_become(diff_user_p);
 				os_rename(outname, curfile);
+				undo_unlink_errok(outname);
+				undo_rename(curfile, outname);
 				user_become_undo();
 			}
 			else
@@ -1245,55 +1253,30 @@ difference_main()
 			undo_unlink_errok(original);
 			user_become_undo();
 
+			if
+			(
+				src1_data->edit_number
+			&&
+				!src1_data->edit_number_origin
+			)
+			{
+				/* Historical 2.3 -> 3.0 transition. */
+				src1_data->edit_number_origin =
+					str_copy(src1_data->edit_number);
+			}
+
 			/*
 			 * get the version out of history
-			 *
-			 * For cross branch merges, use the project
-			 * file's edit origin, rather then the
-			 * change file's edit origin.
 			 */
-			assert(src1_data->edit_origin);
-			assert(src1_data->edit_origin->revision);
-			reconstruct = fstate_src_type.alloc();
-			reconstruct->file_name = str_copy(s1);
-			reconstruct->edit =
-				history_version_copy(src1_data->edit_origin);
-			if (cp->pp != pp2)
-			{
-				fstate_src	p_src_data;
-
-				p_src_data = project_file_find(cp->pp, s1);
-				assert(!p_src_data->edit_origin || p_src_data->edit_origin->revision);
-				if
-				(
-					p_src_data
-				&&
-					p_src_data->edit_origin
-				&&
-					!p_src_data->deleted_by
-				&&
-					!p_src_data->about_to_be_created_by
-				)
-				{
-					history_version_type.free(reconstruct->edit);
-					reconstruct->edit =
-						history_version_copy
-						(
-							p_src_data->edit_origin
-						);
-				}
-			}
-			assert(reconstruct);
-			assert(reconstruct->edit);
-			assert(reconstruct->edit->revision);
+			assert(src1_data->edit_number_origin);
 			change_run_history_get_command
 			(
 				cp,
-				reconstruct,
+				s1,
+				src1_data->edit_number_origin,
 				original,
 				diff_user_p
 			);
-			history_version_type.free(reconstruct);
 
 			/*
 			 * use the appropriate merge command
@@ -1336,46 +1319,38 @@ difference_main()
 			str_free(original);
 
 			/*
-			 * p_src_data->edit
+			 * p_src_data->edit_number
 			 *	The head revision of the branch.
-			 * p_src_data->edit_origin
+			 * p_src_data->edit_number_origin
 			 *	The version originally copied.
 			 *
-			 * c_src_data->edit
+			 * c_src_data->edit_number
 			 *	Not meaningful until after integrate pass.
-			 * c_src_data->edit_origin
+			 * c_src_data->edit_number_origin
 			 *	The version originally copied.
-			 * c_src_data->edit_origin_new
-			 *	Updates branch edit_origin on
+			 * c_src_data->edit_number_origin_new
+			 *	Updates branch edit_number_origin on
 			 *	integrate pass.
 			 */
-			assert(src2_data->edit);
-			assert(src2_data->edit->revision);
+			assert(src2_data->edit_number);
 			if (cp->pp == pp2)
 			{
 				/* normal merge */
-				if (src1_data->edit_origin)
-				{
-					history_version_type.free
-					(
-						src1_data->edit_origin
-					);
-				}
-				src1_data->edit_origin =
-					history_version_copy(src2_data->edit);
+				if (src1_data->edit_number_origin)
+					str_free(src1_data->edit_number_origin);
+				src1_data->edit_number_origin =
+					str_copy(src2_data->edit_number);
 			}
 			else
 			{
 				/* cross branch merge */
-				if (src1_data->edit_origin_new)
-				{
-					history_version_type.free
+				if (src1_data->edit_number_origin_new)
+					str_free
 					(
-						src1_data->edit_origin_new
+					       src1_data->edit_number_origin_new
 					);
-				}
-				src1_data->edit_origin_new =
-					history_version_copy(src2_data->edit);
+				src1_data->edit_number_origin_new =
+					str_copy(src2_data->edit_number);
 			}
 
 			/*
@@ -1419,7 +1394,7 @@ difference_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", need_new_build.string[j]);
+			sub_var_set(scp, "File_Name", "%S", need_new_build.string[j]);
 			if (change_has_merge_command(cp))
 				change_error(cp, scp, i18n("$filename merged"));
 			else
@@ -1432,7 +1407,7 @@ difference_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_long(scp, "Number", (long)need_new_build.nstrings);
+			sub_var_set(scp, "Number", "%ld", (long)need_new_build.nstrings);
 			sub_var_optional(scp, "Number");
 			change_error(cp, scp, i18n("merge complete"));
 			sub_context_delete(scp);
@@ -1446,7 +1421,7 @@ difference_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_long(scp, "Number", mergable_files);
+			sub_var_set(scp, "Number", "%ld", mergable_files);
 			sub_var_optional(scp, "Number");
 			change_verbose(cp, scp, i18n("warning: mergable files"));
 			sub_context_delete(scp);
@@ -1507,12 +1482,7 @@ difference_main()
 			 * changed.
 			 */
 			if (src1_data->action != file_action_remove && !integrating)
-			{
 				change_file_fingerprint_check(cp, src1_data);
-				assert(src1_data->file_fp);
-				assert(src1_data->file_fp->youngest > 0);
-				assert(src1_data->file_fp->oldest > 0);
-			}
 
 			/*
 			 * All change files have a difference file,
@@ -1521,9 +1491,9 @@ difference_main()
 			 */
 			user_become(diff_user_p);
 			if (integrating)
-				ignore = change_fingerprint_same(src1_data->idiff_file_fp, path_d, 0);
+				ignore = change_fingerprint_same(src1_data->idiff_file_fp, path_d);
 			else
-				ignore = change_fingerprint_same(src1_data->diff_file_fp, path_d, 0);
+				ignore = change_fingerprint_same(src1_data->diff_file_fp, path_d);
 			user_become_undo();
 			if (ignore)
 			{
@@ -1559,7 +1529,7 @@ difference_main()
 					sub_context_ty	*scp;
 
 					scp = sub_context_new();
-					sub_var_set_string(scp, "File_Name", s1);
+					sub_var_set(scp, "File_Name", "%S", s1);
 					change_verbose
 					(
 						cp,
@@ -1568,12 +1538,12 @@ difference_main()
 					);
 					sub_context_delete(scp);
 					src1_data->action = file_action_modify;
-					if (src2_data->edit_origin)
+					if (src2_data->edit_number_origin)
 					{
-						src1_data->edit_origin =
-							history_version_copy
+						src1_data->edit_number_origin =
+							str_copy
 							(
-								src2_data->edit
+							  src2_data->edit_number
 							);
 					}
 					goto modifying_file;
@@ -1624,7 +1594,7 @@ difference_main()
 						src1_data->idiff_file_fp =
 						       fingerprint_type.alloc();
 					src1_data->idiff_file_fp->youngest = 0;
-					change_fingerprint_same(src1_data->idiff_file_fp, path_d, 0);
+					change_fingerprint_same(src1_data->idiff_file_fp, path_d);
 				}
 				else
 				{
@@ -1632,7 +1602,7 @@ difference_main()
 						src1_data->diff_file_fp =
 						       fingerprint_type.alloc();
 					src1_data->diff_file_fp->youngest = 0;
-					change_fingerprint_same(src1_data->diff_file_fp, path_d, 0);
+					change_fingerprint_same(src1_data->diff_file_fp, path_d);
 				}
 				user_become_undo();
 				break;
@@ -1646,7 +1616,7 @@ difference_main()
 					sub_context_ty	*scp;
 
 					scp = sub_context_new();
-					sub_var_set_string(scp, "File_Name", s1);
+					sub_var_set(scp, "File_Name", "%S", s1);
 					change_fatal
 					(
 						cp,
@@ -1711,7 +1681,7 @@ difference_main()
 					sub_context_ty	*scp;
 
 					scp = sub_context_new();
-					sub_var_set_string(scp, "File_Name", s1);
+					sub_var_set(scp, "File_Name", "%S", s1);
 					change_verbose
 					(
 						cp,
@@ -1801,13 +1771,20 @@ difference_main()
 void
 difference()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("difference()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		difference_help,	},
-		{ arglex_token_list,		difference_list,	},
-	};
+	default:
+		difference_main();
+		break;
 
-	trace(("difference()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), difference_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		difference_help();
+		break;
+
+	case arglex_token_list:
+		difference_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
