@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions to implement develop begin
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/string.h>
 #include <ac/time.h>
@@ -29,7 +29,7 @@
 #include <sys/stat.h>
 
 #include <aedb.h>
-#include <ael/change/by_state.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <change.h>
 #include <col.h>
@@ -145,7 +145,6 @@ develop_begin_main()
 	log_style_ty	log_style;
 
 	trace(("develop_begin_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	devdir = 0;
@@ -175,7 +174,7 @@ develop_begin_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -306,7 +305,7 @@ develop_begin_main()
 		scp = sub_context_new();
 		if (up2)
 		{
-			sub_var_set_string(scp, "User", user_name(up));
+			sub_var_set(scp, "User", "%S", user_name(up));
 			sub_var_optional(scp, "User");
 			sub_var_override(scp, "User");
 		}
@@ -328,7 +327,7 @@ develop_begin_main()
 
 		scp = sub_context_new();
 		devdir = change_development_directory_template(cp, up);
-		sub_var_set_string(scp, "File_Name", devdir);
+		sub_var_set(scp, "File_Name", "%S", devdir);
 		change_verbose(cp, scp, i18n("development directory \"$filename\""));
 		sub_context_delete(scp);
 	}
@@ -424,13 +423,20 @@ develop_begin_main()
 void
 develop_begin()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("develop_begin()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		develop_begin_help,	},
-		{ arglex_token_list,		develop_begin_list,	},
-	};
+	default:
+		develop_begin_main();
+		break;
 
-	trace(("develop_begin()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), develop_begin_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		develop_begin_help();
+		break;
+
+	case arglex_token_list:
+		develop_begin_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
