@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions to implement develop begin undo
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/string.h>
 #include <ac/time.h>
@@ -29,11 +29,10 @@
 #include <sys/stat.h>
 
 #include <aedbu.h>
-#include <ael/change/by_state.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <change.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_file.h>
 #include <col.h>
 #include <commit.h>
 #include <common.h>
@@ -134,7 +133,6 @@ develop_begin_undo_main()
 	string_ty	*usr_name;
 
 	trace(("develop_begin_undo_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	usr_name = 0;
@@ -168,7 +166,7 @@ develop_begin_undo_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -251,12 +249,6 @@ develop_begin_undo_main()
 	cp = change_alloc(pp, change_number);
 	change_bind_existing(cp);
 
-	/*
-	 * Make sure it is a change we are manipulating, not a branch.
-	 */
-	if (change_is_a_branch(cp))
-		change_fatal(cp, 0, i18n("use aenbru instead"));
-
 	/*
 	 * Take an advisory write lock on the appropriate row of the change
 	 * table.  Take an advisory write lock on the appropriate row of the
@@ -368,13 +360,20 @@ develop_begin_undo_main()
 void
 develop_begin_undo()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("develop_begin_undo()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		develop_begin_undo_help, },
-		{ arglex_token_list,		develop_begin_undo_list, },
-	};
+	default:
+		develop_begin_undo_main();
+		break;
 
-	trace(("develop_begin_undo()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), develop_begin_undo_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		develop_begin_undo_help();
+		break;
+
+	case arglex_token_list:
+		develop_begin_undo_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
