@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions to implement develop end
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/string.h>
 #include <ac/time.h>
@@ -29,10 +29,10 @@
 #include <sys/stat.h>
 
 #include <aede.h>
-#include <ael/change/by_state.h>
+#include <ael.h>
 #include <arglex2.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <col.h>
 #include <commit.h>
 #include <common.h>
@@ -42,8 +42,7 @@
 #include <progname.h>
 #include <os.h>
 #include <project.h>
-#include <project/active.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <project_hist.h>
 #include <sub.h>
 #include <trace.h>
@@ -142,7 +141,6 @@ develop_end_main()
 	int		is_a_branch;
 
 	trace(("develop_end_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	while (arglex_token != arglex_token_eoln)
@@ -167,7 +165,7 @@ develop_end_main()
 			else if (change_number < 1)
 			{
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -347,13 +345,9 @@ develop_end_main()
 		{
 			if (!c_src_data->file_fp)
 				c_src_data->file_fp = fingerprint_type.alloc();
-			assert(c_src_data->file_fp->youngest >= 0);
-			assert(c_src_data->file_fp->oldest >= 0);
 			user_become(up);
-			same = change_fingerprint_same(c_src_data->file_fp, path, 0);
+			same = change_fingerprint_same(c_src_data->file_fp, path);
 			user_become_undo();
-			assert(c_src_data->file_fp->youngest > 0);
-			assert(c_src_data->file_fp->oldest > 0);
 			trace(("same = %d\n", same));
 
 			if
@@ -364,7 +358,8 @@ develop_end_main()
 			)
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", c_src_data->file_name);
+				trace(("mark\n"));
+				sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
 				change_error(cp, scp, i18n("$filename not found"));
 				sub_context_delete(scp);
 				str_free(path);
@@ -397,7 +392,7 @@ develop_end_main()
 			if (e)
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "MeSsaGe", e);
+				sub_var_set(scp, "MeSsaGe", "%S", e);
 				str_free(e);
 				change_error(cp, scp, i18n("$message"));
 				sub_context_delete(scp);
@@ -414,7 +409,7 @@ develop_end_main()
 			if (!c_src_data->diff_file_fp)
 				c_src_data->diff_file_fp = fingerprint_type.alloc();
 			user_become(up);
-			same_d = change_fingerprint_same(c_src_data->diff_file_fp, path_d, 0);
+			same_d = change_fingerprint_same(c_src_data->diff_file_fp, path_d);
 			user_become_undo();
 			trace(("same_d = %d\n", same_d));
 			str_free(path_d);
@@ -427,7 +422,8 @@ develop_end_main()
 			)
 			{
 				scp = sub_context_new();
-				sub_var_set_format(scp, "File_Name", "%S,D", c_src_data->file_name);
+				trace(("mark\n"));
+				sub_var_set(scp, "File_Name", "%S,D", c_src_data->file_name);
 				change_error(cp, scp, i18n("$filename not found"));
 				sub_context_delete(scp);
 				errs++;
@@ -446,7 +442,7 @@ develop_end_main()
 			if (file_required && !same && c_src_data->file_fp->oldest)
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", c_src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
 				change_error(cp, scp, i18n("$filename changed after diff"));
 				sub_context_delete(scp);
 				diff_whine++;
@@ -455,7 +451,7 @@ develop_end_main()
 			else if (diff_file_required && !same_d && c_src_data->diff_file_fp->youngest)
 			{
 				scp = sub_context_new();
-				sub_var_set_format(scp, "File_Name", "%S,D", c_src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S,D", c_src_data->file_name);
 				change_error(cp, scp, i18n("$filename changed after diff"));
 				sub_context_delete(scp);
 				diff_whine++;
@@ -514,7 +510,7 @@ develop_end_main()
 			)
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", c_src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
 				change_error(cp, scp, i18n("no $filename in baseline"));
 				sub_context_delete(scp);
 				errs++;
@@ -539,19 +535,19 @@ develop_end_main()
 				p_src_data->usage = c_src_data->usage;
 				p_src_data->about_to_be_created_by =
 					change_number;
-				assert(c_src_data->edit
-					|| c_src_data->edit_origin);
-				p_src_data->edit =
-					history_version_copy
+				assert(c_src_data->edit_number
+					|| c_src_data->edit_number_origin);
+				p_src_data->edit_number =
+					str_copy
 					(
-						c_src_data->edit
+						c_src_data->edit_number
 					?
-						c_src_data->edit
+						c_src_data->edit_number
 					:
-						c_src_data->edit_origin
+						c_src_data->edit_number_origin
 					);
-				p_src_data->edit_origin =
-					history_version_copy(p_src_data->edit);
+				p_src_data->edit_number_origin =
+					str_copy(p_src_data->edit_number);
 				break;
 			}
 
@@ -568,7 +564,7 @@ develop_end_main()
 			)
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", c_src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
 				change_error(cp, scp, i18n("baseline $filename changed"));
 				sub_context_delete(scp);
 				errs++;
@@ -580,8 +576,8 @@ develop_end_main()
 			if (p_src_data->locked_by)
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", c_src_data->file_name);
-				sub_var_set_long(scp, "Number", p_src_data->locked_by);
+				sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
+				sub_var_set(scp, "Number", "%ld", p_src_data->locked_by);
 				change_error(cp, scp, i18n("file \"$filename\" locked for change $number"));
 				sub_context_delete(scp);
 				errs++;
@@ -596,60 +592,21 @@ develop_end_main()
 			 */
 			if
 			(
-				!is_a_branch
-			&&
-				(
-					!p_src_data
-				||
-					p_src_data->deleted_by
-				||
-					p_src_data->about_to_be_created_by
-				)
+				!p_src_data
+			||
+				p_src_data->deleted_by
+			||
+				p_src_data->about_to_be_created_by
 			)
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", c_src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
 				change_error(cp, scp, i18n("no $filename in baseline"));
 				sub_context_delete(scp);
 				errs++;
 				continue;
 			}
 
-			/*
-			 * Make sure the file exists in the project.
-			 *
-			 * This can happen for aede on branches which
-			 * have had a new file created and then modified;
-			 * thus the file will not exist in the branch's
-			 * project.
-			 */
-			if (!p_src_data)
-			{
-				p_src_data =
-					project_file_new
-					(
-						pp,
-						c_src_data->file_name
-					);
-				p_src_data->usage = c_src_data->usage;
-				p_src_data->about_to_be_created_by =
-					change_number;
-				assert(c_src_data->edit
-					|| c_src_data->edit_origin);
-				p_src_data->edit =
-					history_version_copy
-					(
-						c_src_data->edit
-					?
-						c_src_data->edit
-					:
-						c_src_data->edit_origin
-					);
-				p_src_data->edit_origin =
-					history_version_copy(p_src_data->edit);
-				break;
-			}
-
 			/*
 			 * Make sure the edit numbers match.  If it
 			 * matches any of the ancestral edits, it does
@@ -658,7 +615,7 @@ develop_end_main()
 			if (!change_file_up_to_date(pp, c_src_data))
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", c_src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
 				change_error(cp, scp, i18n("baseline $filename changed"));
 				sub_context_delete(scp);
 				errs++;
@@ -670,8 +627,8 @@ develop_end_main()
 			if (p_src_data->locked_by)
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", c_src_data->file_name);
-				sub_var_set_long(scp, "Number", p_src_data->locked_by);
+				sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
+				sub_var_set(scp, "Number", "%ld", p_src_data->locked_by);
 				change_error(cp, scp, i18n("file \"$filename\" locked for change $number"));
 				sub_context_delete(scp);
 				errs++;
@@ -689,7 +646,7 @@ develop_end_main()
 				if (!p_src_data->deleted_by)
 				{
 					scp = sub_context_new();
-					sub_var_set_string(scp, "File_Name", c_src_data->file_name);
+					sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
 					change_error(cp, scp, i18n("$filename in baseline"));
 					sub_context_delete(scp);
 					++errs;
@@ -722,7 +679,7 @@ develop_end_main()
 			 * overlooked.
 			 */
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", c_src_data->file_name);
+			sub_var_set(scp, "File_Name", "%S", c_src_data->file_name);
 			change_error(cp, scp, i18n("$filename is insulation"));
 			sub_context_delete(scp);
 			errs++;
@@ -736,7 +693,53 @@ develop_end_main()
 	 * changes outstanding on the branch.
 	 */
 	if (is_a_branch)
-		project_active_check_branch(cp, 0);
+	{
+		project_ty	*sub_pp;
+		int		num_err;
+
+		trace(("mark\n"));
+		sub_pp = project_bind_branch(pp, change_copy(cp));
+		num_err = 0;
+		trace(("mark\n"));
+		for (j = 0; ; ++j)
+		{
+			long            sub_cn;
+			change_ty       *sub_cp;
+			cstate          sub_cstate_data;
+		
+			if (!project_change_nth(sub_pp, j, &sub_cn))
+				break;
+			trace(("mark\n"));
+			sub_cp = change_alloc(sub_pp, sub_cn);
+			change_bind_existing(sub_cp);
+			sub_cstate_data = change_cstate_get(sub_cp);
+			if (sub_cstate_data->state != cstate_state_completed)
+			{
+				change_error
+				(
+					sub_cp,
+					0,
+					i18n("outstanding change")
+				);
+				++num_err;
+			}
+			change_free(sub_cp);
+			trace(("mark\n"));
+		}
+		trace(("mark\n"));
+		if (num_err)
+		{
+			scp = sub_context_new();
+			sub_var_set(scp, "Number", "%d", num_err);
+			sub_var_optional(scp, "Number");
+			fatal_intl(scp, i18n("outstanding changes"));
+			/* NOTREACHED */
+		}
+		trace(("mark\n"));
+		project_free(sub_pp);
+		trace(("mark\n"));
+	}
+	trace(("mark\n"));
 
 	/*
 	 * if the config file changes,
@@ -763,7 +766,7 @@ develop_end_main()
 			if (e)
 			{
 				scp = sub_context_new();
-				sub_var_set_string(scp, "Message", e);
+				sub_var_set(scp, "Message", "%S", e);
 				str_free(e);
 				change_error(cp, scp, i18n("project $message"));
 				sub_context_delete(scp);
@@ -771,6 +774,7 @@ develop_end_main()
 			}
 		}
 	}
+	trace(("mark\n"));
 
 	/*
 	 * verify that the youngest file is older than the
@@ -781,22 +785,23 @@ develop_end_main()
 		if (youngest_name && cstate_data->build_time)
 		{
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "Outstanding", change_outstanding_builds(cp, youngest));
+			sub_var_set(scp, "Outstanding", "%s", change_outstanding_builds(cp, youngest));
 			sub_var_optional(scp, "Outstanding");
-			sub_var_set_string(scp, "File_Name", youngest_name);
+			sub_var_set(scp, "File_Name", "%S", youngest_name);
 			change_error(cp, scp, i18n("$filename changed after build"));
 			sub_context_delete(scp);
 		}
 		else
 		{
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "Outstanding", change_outstanding_builds(cp, youngest));
+			sub_var_set(scp, "Outstanding", "%s", change_outstanding_builds(cp, youngest));
 			sub_var_optional(scp, "Outstanding");
 			change_error(cp, scp, i18n("build required"));
 			sub_context_delete(scp);
 		}
 		++errs;
 	}
+	trace(("mark\n"));
 	if
 	(
 		!cstate_data->test_exempt
@@ -809,12 +814,13 @@ develop_end_main()
 	)
 	{
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Outstanding", change_outstanding_tests(cp, youngest));
+		sub_var_set(scp, "Outstanding", "%s", change_outstanding_tests(cp, youngest));
 		sub_var_optional(scp, "Outstanding");
 		change_error(cp, scp, i18n("test required"));
 		sub_context_delete(scp);
 		++errs;
 	}
+	trace(("mark\n"));
 	if
 	(
 		!cstate_data->test_baseline_exempt
@@ -827,12 +833,13 @@ develop_end_main()
 	)
 	{
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Outstanding", change_outstanding_tests_baseline(cp, youngest));
+		sub_var_set(scp, "Outstanding", "%s", change_outstanding_tests_baseline(cp, youngest));
 		sub_var_optional(scp, "Outstanding");
 		change_error(cp, scp, i18n("test -bl required"));
 		sub_context_delete(scp);
 		++errs;
 	}
+	trace(("mark\n"));
 	if
 	(
 		!cstate_data->regression_test_exempt
@@ -845,12 +852,13 @@ develop_end_main()
 	)
 	{
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Outstanding", change_outstanding_tests_regression(cp, youngest));
+		sub_var_set(scp, "Outstanding", "%s", change_outstanding_tests_regression(cp, youngest));
 		sub_var_optional(scp, "Outstanding");
 		change_error(cp, scp, i18n("test -reg required"));
 		sub_context_delete(scp);
 		++errs;
 	}
+	trace(("mark\n"));
 
 	/*
 	 * if there was any problem,
@@ -859,12 +867,16 @@ develop_end_main()
 	if (errs)
 	{
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", errs);
+		sub_var_set(scp, "Number", "%d", errs);
 		sub_var_optional(scp, "Number");
 		change_fatal(cp, scp, i18n("develop end fail"));
 		sub_context_delete(scp);
 	}
-	dd = str_copy(change_development_directory_get(cp, 1));
+	trace(("mark\n"));
+	if (change_is_a_branch(cp))
+		dd = str_format("%S/baseline", change_development_directory_get(cp, 1));
+	else	
+		dd = str_copy(change_development_directory_get(cp, 1));
 	str_free(dd);
 
 	/*
@@ -881,22 +893,17 @@ develop_end_main()
 				user_name(up_admin)
 			);
 	}
+	trace(("mark\n"));
 
 	/*
 	 * Advance the change to the being-reviewed state.
+	 * Clear the build-time field.
+	 * Clear the test-time field.
+	 * Clear the test-baseline-time field.
+	 * Clear the regression-test-time field.
 	 */
 	cstate_data->state = cstate_state_being_reviewed;
-
-	/*
-	 * It is tempting to call
-	 *
 	change_build_times_clear(cp);
-	 *
-	 * at this point, but we don't.  This is so that in the event
-	 * of an aedeu (to get out of the way of another change, maybe)
-	 * a full build-and-test cycle is only required of they actually
-	 * edit something.
-	 */
 
 	/*
 	 * Remove the change from the list of assigned changes in the user
@@ -923,9 +930,13 @@ develop_end_main()
 	/*
 	 * verbose success message
 	 */
+	trace(("mark\n"));
 	change_verbose(cp, 0, i18n("development completed"));
+	trace(("mark\n"));
 	change_free(cp);
+	trace(("mark\n"));
 	project_free(pp);
+	trace(("mark\n"));
 	user_free(up);
 	trace((/*{*/"}\n"));
 }
@@ -934,13 +945,20 @@ develop_end_main()
 void
 develop_end()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("develop_end()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		develop_end_help,	},
-		{ arglex_token_list,		develop_end_list,	},
-	};
+	default:
+		develop_end_main();
+		break;
 
-	trace(("develop_end()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), develop_end_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		develop_end_help();
+		break;
+
+	case arglex_token_list:
+		develop_end_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
