@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,10 +20,10 @@
  * MANIFEST: functions to implement the 'aegis -Delta_Name' command
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 
 #include <aedn.h>
-#include <ael/project/history.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <commit.h>
 #include <error.h>
@@ -108,7 +108,7 @@ delta_name_list()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -146,7 +146,6 @@ delta_name_main()
 	user_ty		*up;
 
 	trace(("delta_name_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	delta_number = 0;
 	delta_name = 0;
@@ -184,7 +183,7 @@ delta_name_main()
 			if (delta_number < 1)
 			{
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", delta_number);
+				sub_var_set(scp, "Number", "%ld", delta_number);
 				fatal_intl(scp, i18n("delta $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -246,7 +245,7 @@ delta_name_main()
 		if (!project_history_delta_validate(pp, delta_number))
 		{
 			scp = sub_context_new();
-			sub_var_set_long(scp, "Number", delta_number);
+			sub_var_set(scp, "Number", "%ld", delta_number);
 			project_fatal(pp, scp, i18n("no delta $number"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -267,10 +266,10 @@ delta_name_main()
 		if (other && other != delta_number)
 		{
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", delta_name);
-			sub_var_set_long(scp, "Number", delta_number);
+			sub_var_set(scp, "Name", "%S", delta_name);
+			sub_var_set(scp, "Number", "%ld", delta_number);
 			sub_var_optional(scp, "Number");
-			sub_var_set_long(scp, "Other", other);
+			sub_var_set(scp, "Other", "%ld", other);
 			sub_var_optional(scp, "Other");
 			project_fatal(pp, scp, i18n("delta $name in use"));
 			/* NOTREACHED */
@@ -295,9 +294,9 @@ delta_name_main()
 	 * verbose success message
 	 */
 	scp = sub_context_new();
-	sub_var_set_string(scp, "Name", delta_name);
+	sub_var_set(scp, "Name", "%S", delta_name);
 	sub_var_optional(scp, "Name");
-	sub_var_set_long(scp, "Number", delta_number);
+	sub_var_set(scp, "Number", "%ld", delta_number);
 	sub_var_optional(scp, "Number");
 	project_verbose(pp, scp, i18n("delta name complete"));
 	sub_context_delete(scp);
@@ -311,13 +310,20 @@ delta_name_main()
 void
 delta_name_assignment()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("delta_name()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		delta_name_help,	},
-		{ arglex_token_list,		delta_name_list,	},
-	};
+	default:
+		delta_name_main();
+		break;
 
-	trace(("delta_name_assignment()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), delta_name_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		delta_name_help();
+		break;
+
+	case arglex_token_list:
+		delta_name_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
