@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions for implementing integrate fail
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/string.h>
 
@@ -28,10 +28,10 @@
 #include <sys/stat.h>
 
 #include <aeif.h>
-#include <ael/change/by_state.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <commit.h>
-#include <change/file.h>
+#include <change_file.h>
 #include <error.h>
 #include <file.h>
 #include <help.h>
@@ -40,7 +40,7 @@
 #include <progname.h>
 #include <os.h>
 #include <project.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <project_hist.h>
 #include <sub.h>
 #include <trace.h>
@@ -70,14 +70,15 @@ static void integrate_fail_help _((void));
 static void
 integrate_fail_help()
 {
-	help("aeifail", integrate_fail_usage);
+	help("aeif", integrate_fail_usage);
 }
 
 
-static void integrate_fail_list _((void));
+static void integrate_fail_list _((void (*)(void)));
 
 static void
-integrate_fail_list()
+integrate_fail_list(usage)
+	void		(*usage)_((void));
 {
 	string_ty	*project_name;
 
@@ -89,14 +90,14 @@ integrate_fail_list()
 		switch (arglex_token)
 		{
 		default:
-			generic_argument(integrate_fail_usage);
+			generic_argument(usage);
 			continue;
 
 		case arglex_token_project:
 			if (arglex() != arglex_token_string)
-				option_needs_name(arglex_token_project, integrate_fail_usage);
+				option_needs_name(arglex_token_project, usage);
 			if (project_name)
-				duplicate_option_by_name(arglex_token_project, integrate_fail_usage);
+				duplicate_option_by_name(arglex_token_project, usage);
 			project_name = str_from_c(arglex_value.alv_string);
 			break;
 		}
@@ -113,22 +114,6 @@ integrate_fail_list()
 }
 
 
-static void check_directory _((change_ty *));
-
-static void
-check_directory(cp)
-	change_ty	*cp;
-{
-	string_ty	*dir;
-
-	dir = change_integration_directory_get(cp, 1);
-	os_become_orig();
-	if (os_below_dir(dir, os_curdir()))
-		change_fatal(cp, 0, i18n("leave int dir"));
-	os_become_undo();
-}
-
-
 static void check_permissions _((change_ty *, user_ty *));
 
 static void
@@ -155,7 +140,6 @@ static void integrate_fail_main _((void));
 static void
 integrate_fail_main()
 {
-	string_ty	*s;
 	sub_context_ty	*scp;
 	cstate		cstate_data;
 	cstate_history	history_data;
@@ -174,7 +158,6 @@ integrate_fail_main()
 	edit_ty		edit;
 
 	trace(("integrate_fail_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	edit = edit_not_set;
@@ -188,42 +171,22 @@ integrate_fail_main()
 
 		case arglex_token_string:
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "Name", arglex_token_name(arglex_token_file));
+			sub_var_set(scp, "Name", "%s", arglex_token_name(arglex_token_file));
 			error_intl(scp, i18n("warning: use $name option"));
 			sub_context_delete(scp);
 			if (comment)
-				fatal_too_many_files();
+				fatal_intl(0, i18n("too many files"));
 			goto read_reason_file;
 
 		case arglex_token_file:
 			if (comment)
 				duplicate_option(integrate_fail_usage);
-			switch (arglex())
-			{
-			default:
-				option_needs_file
-				(
-					arglex_token_file,
-					integrate_fail_usage
-				);
-				/*NOTREACHED*/
-
-			case arglex_token_string:
-				read_reason_file:
-				os_become_orig();
-				s = str_from_c(arglex_value.alv_string);
-				comment = read_whole_file(s);
-				str_free(s);
-				os_become_undo();
-				break;
-
-			case arglex_token_stdio:
-				os_become_orig();
-				comment = read_whole_file((string_ty *)0);
-				os_become_undo();
-				break;
-			}
-			assert(comment);
+			if (arglex() != arglex_token_string)
+				option_needs_file(arglex_token_file, integrate_fail_usage);
+			read_reason_file:
+			os_become_orig();
+			comment = read_whole_file(arglex_value.alv_string);
+			os_become_undo();
 			break;
 
 		case arglex_token_reason:
@@ -248,7 +211,7 @@ integrate_fail_main()
 			else if (change_number < 1)
 			{
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -321,8 +284,8 @@ integrate_fail_main()
 	if (edit == edit_not_set && !(comment || reason))
 	{
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name1", arglex_token_name(arglex_token_file));
-		sub_var_set_charstar(scp, "Name2", arglex_token_name(arglex_token_edit));
+		sub_var_set(scp, "Name1", "%s", arglex_token_name(arglex_token_file));
+		sub_var_set(scp, "Name2", "%s", arglex_token_name(arglex_token_edit));
 		error_intl(scp, i18n("warning: no $name1, assuming $name2"));
 		sub_context_delete(scp);
 		edit = edit_foreground;
@@ -357,12 +320,6 @@ integrate_fail_main()
 	 */
 	if (edit != edit_not_set)
 	{
-		/*
-		 * make sure they are not in the integration directory,
-		 * to avoid a wasted edit
-		 */
-		check_directory(cp);
-
 		/*
 		 * make sure they are allowed to first,
 		 * to avoid a wasted edit
@@ -405,7 +362,10 @@ integrate_fail_main()
 	 * Complain if they are in the integration directory,
 	 * because the rmdir at the end can't then run to completion.
 	 */
-	check_directory(cp);
+	os_become_orig();
+	if (os_below_dir(dir, os_curdir()))
+		change_fatal(cp, 0, i18n("leave int dir"));
+	os_become_undo();
 
 	/*
 	 * note that the project has no current integration
@@ -521,13 +481,20 @@ integrate_fail_main()
 void
 integrate_fail()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("integrate_fail()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		integrate_fail_help,	},
-		{ arglex_token_list,		integrate_fail_list,	},
-	};
+	default:
+		integrate_fail_main();
+		break;
 
-	trace(("integrate_fail()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), integrate_fail_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		integrate_fail_help();
+		break;
+
+	case arglex_token_list:
+		integrate_fail_list(integrate_fail_usage);
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
