@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions for implementing integrate pass
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/string.h>
 
@@ -28,25 +28,23 @@
 #include <sys/stat.h>
 
 #include <aeip.h>
-#include <ael/change/by_state.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <commit.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <dir.h>
 #include <error.h>
 #include <file.h>
 #include <help.h>
 #include <lock.h>
 #include <log.h>
-#include <metrics.h>
 #include <mem.h>
 #include <progname.h>
 #include <os.h>
 #include <project.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <project_hist.h>
-#include <str_list.h>
 #include <sub.h>
 #include <trace.h>
 #include <undo.h>
@@ -102,14 +100,15 @@ static void integrate_pass_help _((void));
 static void
 integrate_pass_help()
 {
-	help("aeipass", integrate_pass_usage);
+	help("aeip", integrate_pass_usage);
 }
 
 
-static void integrate_pass_list _((void));
+static void integrate_pass_list _((void (*)(void)));
 
 static void
-integrate_pass_list()
+integrate_pass_list(usage)
+	void		(*usage)_((void));
 {
 	string_ty	*project_name;
 
@@ -121,14 +120,14 @@ integrate_pass_list()
 		switch (arglex_token)
 		{
 		default:
-			generic_argument(integrate_pass_usage);
+			generic_argument(usage);
 			continue;
 
 		case arglex_token_project:
 			if (arglex() != arglex_token_string)
-				option_needs_name(arglex_token_project, integrate_pass_usage);
+				option_needs_name(arglex_token_project, usage);
 			if (project_name)
-				duplicate_option_by_name(arglex_token_project, integrate_pass_usage);
+				duplicate_option_by_name(arglex_token_project, usage);
 			project_name = str_from_c(arglex_value.alv_string);
 			break;
 		}
@@ -281,38 +280,11 @@ time_map_set(p, message, path, st)
 }
 
 
-static metric_list metric_list_copy _((metric_list));
-
-static metric_list
-metric_list_copy(mlp)
-	metric_list	mlp;
-{
-	metric_list	result;
-	size_t		j;
-
-	if (!mlp)
-		return 0;
-	result = metric_list_type.alloc();
-	for (j = 0; j < mlp->length; ++j)
-	{
-		metric		mp;
-		metric		*mpp;
-		type_ty		*bogus;
-
-		mp = mlp->list[j];
-		mpp = metric_list_type.list_parse(result, &bogus);
-		*mpp = metric_copy(mp);
-	}
-	return result;
-}
-
-
 static void integrate_pass_main _((void));
 
 static void
 integrate_pass_main()
 {
-	time_t		mtime;
 	time_t		youngest;
 	string_ty	*hp;
 	string_ty	*id;
@@ -341,10 +313,8 @@ integrate_pass_main()
 	cstate		p_cstate_data;
 	time_map_list_ty tml;
 	time_t		time_final;
-	string_list_ty	trashed;
 
 	trace(("integrate_pass_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	log_style = log_style_append_default;
@@ -373,7 +343,7 @@ integrate_pass_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -491,8 +461,6 @@ integrate_pass_main()
 	}
 	assert(tml.time_aeib);
 
-	id = change_integration_directory_get(cp, 1);
-
 	/*
 	 * Walk the change files, making sure
 	 *	1. the change has been diffed (except for the lowest b.l.)
@@ -560,48 +528,6 @@ integrate_pass_main()
 		if (!p_src_data)
 			this_is_a_bug();
 
-		/*
-		 * remove the file metrics, if any
-		 */
-		if (c_src_data->metrics)
-		{
-			metric_list_type.free(c_src_data->metrics);
-			c_src_data->metrics = 0;
-		}
-		if (p_src_data->metrics)
-		{
-			metric_list_type.free(p_src_data->metrics);
-			p_src_data->metrics = 0;
-		}
-
-		/*
-		 * Grab the file metrics,
-		 * if they were produced by the build.
-		 *
-		 * Only do this for primary source files, and only for
-		 * creates and modifies.
-		 */
-		if
-		(
-			c_src_data->usage != file_usage_build
-		&&
-			(
-				c_src_data->action == file_action_create
-			||
-				c_src_data->action == file_action_modify
-			)
-		)
-		{
-			metric_list	mlp;
-
-			mlp = change_file_metrics_get(cp, c_src_data->file_name);
-			if (mlp)
-			{
-				c_src_data->metrics = mlp;
-				p_src_data->metrics = metric_list_copy(mlp);
-			}
-		}
-
 		/*
 		 * don't do any of the transfers
 		 * if the file is built
@@ -703,11 +629,10 @@ integrate_pass_main()
 			/*
 			 * Transfer the file fingerprint.
 			 *
-			 * Note: the fp->youngest will be wrong, because
-			 * the file was copied into the integration
-			 * directory.  This will be fixed next time some
-			 * operation is done on this file, because the
-			 * crypto will be correct.
+			 * Note: the fp->youngest will be wrong, because the
+			 * file was copied into the integration directory.  This
+			 * will be fixed next time some operation is done on this
+			 * file, because the crypto will be correct.
 			 */
 			assert(c_src_data->file_fp);
 			if (!p_src_data->file_fp)
@@ -759,39 +684,44 @@ integrate_pass_main()
 		 * The edit number origin *must* be up-to-date, or the
 		 * change could not have got this far.
 		 *
-		 * As a branch advances, the edit field tracks the
-		 * history, but the edit_origin field is the number when
+		 * As a branch advances, the edit_number tracks the
+		 * history, but the edit_number_origin is the number when
 		 * the file was first created or copied into the branch.
 		 * By definition, a file in a change is out of date when
-		 * it's edit_origin field does not equal the edit field
+		 * it's edit_number_origin does not equal the edit_number
 		 * of its project.
 		 *
 		 * In order to merge branches, this must be done as a
 		 * cross branch merge in a change to that branch; the
-		 * edit_origin_new field of the change is copied
-		 * into the edit_origin field of the branch.
+		 * edit_number_origin_new field of the change is copied
+		 * into the edit_number_origin origin field of the branch.
 		 *
-		 * p_src_data->edit
+		 * p_src_data->edit_number
 		 *	The head revision of the branch.
-		 * p_src_data->edit_origin
+		 * p_src_data->edit_number_origin
 		 *	The version originally copied.
 		 *
-		 * c_src_data->edit
+		 * c_src_data->edit_number
 		 *	Not meaningful until after integrate pass.
-		 * c_src_data->edit_origin
+		 * c_src_data->edit_number_origin
 		 *	The version originally copied.
-		 * c_src_data->edit_origin_new
-		 *	Updates branch edit_origin on
+		 * c_src_data->edit_number_origin_new
+		 *	Updates branch edit_number_origin on
 		 *	integrate pass.
 		 */
-		if (c_src_data->edit_origin_new)
+		if (c_src_data->edit_number && !c_src_data->edit_number_origin)
 		{
-			assert(c_src_data->edit_origin_new->revision);
-			if (p_src_data->edit_origin)
-				history_version_type.free(p_src_data->edit_origin);
-			p_src_data->edit_origin =
-				c_src_data->edit_origin_new;
-			c_src_data->edit_origin_new = 0;
+			/* Historical 2.3 -> 3.0 transition.  */
+			c_src_data->edit_number_origin =
+				str_copy(c_src_data->edit_number);
+		}
+		if (c_src_data->edit_number_origin_new)
+		{
+			if (p_src_data->edit_number_origin)
+				str_free(p_src_data->edit_number_origin);
+			p_src_data->edit_number_origin =
+				c_src_data->edit_number_origin_new;
+			c_src_data->edit_number_origin_new = 0;
 		}
 
 		/*
@@ -889,7 +819,7 @@ integrate_pass_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Outstanding", change_outstanding_builds(cp, youngest));
+		sub_var_set(scp, "Outstanding", "%s", change_outstanding_builds(cp, youngest));
 		sub_var_optional(scp, "Outstanding");
 		change_error(cp, scp, i18n("bad ip, build required"));
 		sub_context_delete(scp);
@@ -900,7 +830,7 @@ integrate_pass_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Outstanding", change_outstanding_tests(cp, youngest));
+		sub_var_set(scp, "Outstanding", "%s", change_outstanding_tests(cp, youngest));
 		sub_var_optional(scp, "Outstanding");
 		change_error(cp, scp, i18n("bad ip, test required"));
 		sub_context_delete(scp);
@@ -916,7 +846,7 @@ integrate_pass_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Outstanding", change_outstanding_tests_baseline(cp, youngest));
+		sub_var_set(scp, "Outstanding", "%s", change_outstanding_tests_baseline(cp, youngest));
 		sub_var_optional(scp, "Outstanding");
 		change_error(cp, scp, i18n("bad ip, test -bl required"));
 		++nerr;
@@ -931,10 +861,11 @@ integrate_pass_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_charstar
+		sub_var_set
 		(
 			scp,
 			"Outstanding",
+			"%s",
 			change_outstanding_tests_regression(cp, youngest)
 		);
 		sub_var_optional(scp, "Outstanding");
@@ -951,7 +882,7 @@ integrate_pass_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", nerr);
+		sub_var_set(scp, "Number", "%d", nerr);
 		sub_var_optional(scp, "Number");
 		change_fatal(cp, scp, i18n("integrate pass fail"));
 		sub_context_delete(scp);
@@ -1014,6 +945,7 @@ integrate_pass_main()
 	os_become_undo();
 	if (os_below_dir(change_development_directory_get(cp, 1), cwd))
 		change_fatal(cp, 0, i18n("leave dev dir"));
+	id = change_integration_directory_get(cp, 1);
 	if (os_below_dir(id, cwd))
 		change_fatal(cp, 0, i18n("leave int dir"));
 	if (os_below_dir(project_baseline_path_get(pp, 1), cwd))
@@ -1058,10 +990,9 @@ integrate_pass_main()
 		if (c_src_data)
 			continue;
 		c_src_data = change_file_new(cp, p_src_data->file_name);
-		assert(p_src_data->edit);
-		assert(p_src_data->edit->revision);
-		c_src_data->edit_origin =
-			history_version_copy(p_src_data->edit);
+		assert(p_src_data->edit_number);
+		c_src_data->edit_number_origin =
+			str_copy(p_src_data->edit_number);
 		c_src_data->action = file_action_modify;
 		c_src_data->usage = p_src_data->usage;
 	}
@@ -1075,12 +1006,10 @@ integrate_pass_main()
 	log_open(change_logfile_get(cp), pup, log_style);
 	ncmds = 0;
 	hp = project_history_path_get(pp);
-	string_list_constructor(&trashed);
 	for (j = 0; ; ++j)
 	{
 		fstate_src	c_src_data;
 		fstate_src	p_src_data;
-		string_ty	*absfn;
 
 		c_src_data = change_file_nth(cp, j);
 		if (!c_src_data)
@@ -1115,8 +1044,8 @@ integrate_pass_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "File_Name", "fstate file");
-			sub_var_set_charstar(scp, "FieLD_Name", "src");
+			sub_var_set(scp, "File_Name", "fstate file");
+			sub_var_set(scp, "FieLD_Name", "src");
 			project_fatal
 			(
 				pp,
@@ -1140,19 +1069,15 @@ integrate_pass_main()
 			if (p_src_data->deleted_by)
 			{
 				p_src_data->deleted_by = 0;
+				p_src_data->about_to_be_created_by = 0;
 				goto reusing_an_old_file;
 			}
 
 			/*
-			 * Remember the last-modified-time, so we can
-			 * restore it if the history tool messes with it.
+			 * it exists, now
 			 */
-			absfn = change_file_path(cp, c_src_data->file_name);
-			if (!absfn)
-				absfn = str_format("%S/%S", id, c_src_data->file_name);
-			project_become(pp);
-			mtime = os_mtime_actual(absfn);
-			project_become_undo();
+			trace(("create\n"));
+			p_src_data->about_to_be_created_by = 0;
 
 			/*
 			 * create the history
@@ -1160,162 +1085,86 @@ integrate_pass_main()
 			change_run_history_create_command
 			(
 				cp,
-				c_src_data
+				c_src_data->file_name
 			);
 
 			/*
 			 * Update the head revision number.
-			 * (Create also sets edit_origin field,
+			 * (Create also sets edit_number_origin,
 			 * if not already set)
 			 */
-			if (p_src_data->edit)
-				history_version_type.free(p_src_data->edit);
-			p_src_data->edit =
-				history_version_copy(c_src_data->edit);
-			if (!p_src_data->edit_origin)
-				p_src_data->edit_origin =
-					history_version_copy(p_src_data->edit);
-			
-			/*
-			 * Set the last-modified-time, just in case the
-			 * history tool changed it, even if it didn't
-			 * change the file content.  This reduces the
-			 * build burden imposed by an integration.
-			 *
-			 * We do this before we check the fingerprint.
-			 * This has the side-effect of forcing the
-			 * fingerprint, but it also gets the fingerprint
-			 * right in the project file's attributes.
-			 */
-			project_become(pp);
-			os_mtime_set_errok(absfn, mtime);
+			if (p_src_data->edit_number)
+				str_free(p_src_data->edit_number);
+			p_src_data->edit_number =
+				change_run_history_query_command
+				(
+					cp,
+					c_src_data->file_name
+				);
+			if (!p_src_data->edit_number_origin)
+				p_src_data->edit_number_origin =
+					str_copy(p_src_data->edit_number);
 
 			/*
-			 * Many history tools (e.g. RCS) can modify the
-			 * contents of the file when it is committed.
-			 * While there are usually options to turn this
-			 * off, they are seldom used.  The problem is:
-			 * if the commit changes the file, the source
-			 * in the repository now no longer matches the
-			 * object file in the repository - i.e. the
-			 * history tool has compromised the referential
-			 * integrity of the repository.
-			 *
-			 * Keep track of them, we will generate an
-			 * error message after all of the commands have
-			 * been run.
+			 * In the completed state, edit_number
+			 * of a change is the version of the file.
+			 * Leave edit_number_origin alone, as a record
+			 * of where it came from.
+			 * (Create also sets edit_number_origin,
+			 * if not already set)
 			 */
-			if (p_src_data->file_fp)
-			{
-				assert(p_src_data->file_fp->youngest >= 0);
-				assert(p_src_data->file_fp->oldest >= 0);
-				if (!change_fingerprint_same(p_src_data->file_fp, absfn, 1))
-				{
-					string_list_append
-					(
-						&trashed,
-						c_src_data->file_name
-					);
-				}
-				assert(p_src_data->file_fp->youngest > 0);
-				assert(p_src_data->file_fp->oldest > 0);
-			}
-			str_free(absfn);
-			project_become_undo();
+			if (c_src_data->edit_number)
+				str_free(c_src_data->edit_number);
+			c_src_data->edit_number =
+				str_copy(p_src_data->edit_number);
+			if (!p_src_data->edit_number_origin)
+				p_src_data->edit_number_origin =
+					str_copy(p_src_data->edit_number);
 			break;
 
 		case file_action_modify:
 			reusing_an_old_file:
 			trace(("modify\n"));
 
-			if (p_src_data->edit)
+			if (p_src_data->edit_number)
 			{
-				history_version_type.free(p_src_data->edit);
-				p_src_data->edit = 0;
+				str_free(p_src_data->edit_number);
+				p_src_data->edit_number = 0;
 			}
-			if (c_src_data->edit)
+			if (c_src_data->edit_number)
 			{
-				history_version_type.free(c_src_data->edit);
-				c_src_data->edit = 0;
+				str_free(c_src_data->edit_number);
+				c_src_data->edit_number = 0;
 			}
 
-			/*
-			 * Remember the last-modified-time, so we can
-			 * restore it if the history tool messes with it.
-			 */
-			absfn = change_file_path(cp, c_src_data->file_name);
-			if (!absfn)
-				absfn = str_format("%S/%S", id, c_src_data->file_name);
-			project_become(pp);
-			mtime = os_mtime_actual(absfn);
-			project_become_undo();
-
 			/*
 			 * update the history
 			 */
 			change_run_history_put_command
 			(
 				cp,
-				c_src_data
+				c_src_data->file_name
 			);
 			
 			/*
 			 * Update the head revision number.
-			 * (Leave edit_origin field alone.)
+			 * (Leave edit_number_origin alone.)
 			 */
-			if (!p_src_data->edit_origin && p_src_data->edit)
-				p_src_data->edit_origin =
-					history_version_copy(p_src_data->edit);
-			p_src_data->edit =
-				history_version_copy(c_src_data->edit);
-			if (!p_src_data->edit_origin)
-				p_src_data->edit_origin =
-					history_version_copy(p_src_data->edit);
+			p_src_data->edit_number =
+				change_run_history_query_command
+				(
+					cp,
+					c_src_data->file_name
+				);
 
 			/*
-			 * Set the last-modified-time, just in case the
-			 * history tool changed it, even if it didn't
-			 * change the file content.  This reduces the
-			 * build burden imposed by an integration.
-			 *
-			 * We do this before we check the fingerprint.
-			 * This has the side-effect of forcing the
-			 * fingerprint, but it also gets the fingerprint
-			 * right in the project file's attributes.
+			 * In the completed state, edit_number
+			 * of a change is the version of the file.
+			 * Leave edit_number_origin alone, as a record
+			 * of where it came from.
 			 */
-			project_become(pp);
-			os_mtime_set_errok(absfn, mtime);
-
-			/*
-			 * Many history tools (e.g. RCS) can modify the
-			 * contents of the file when it is committed.
-			 * While there are usually options to turn this
-			 * off, they are seldom used.  The problem is:
-			 * if the commit changes the file, the source
-			 * in the repository now no longer matches the
-			 * object file in the repository - i.e. the
-			 * history tool has compromised the referential
-			 * integrity of the repository.
-			 *
-			 * Keep track of them, we will generate an
-			 * error message after all of the commands have
-			 * been run.
-			 */
-			if (p_src_data->file_fp)
-			{
-				if (!change_fingerprint_same(p_src_data->file_fp, absfn, 1))
-				{
-					string_list_append
-					(
-						&trashed,
-						c_src_data->file_name
-					);
-				}
-				assert(p_src_data->file_fp->youngest > 0);
-				assert(p_src_data->file_fp->oldest > 0);
-			}
-			str_free(absfn);
-			project_become_undo();
+			c_src_data->edit_number =
+				str_copy(p_src_data->edit_number);
 			break;
 
 		case file_action_remove:
@@ -1325,6 +1174,12 @@ integrate_pass_main()
 			 */
 			trace(("remove\n"));
 			p_src_data->deleted_by = change_number;
+
+			/*
+			 * This can need clearing when a branch creates
+			 * and then deletes a new file.
+			 */
+			p_src_data->about_to_be_created_by = 0;
 			break;
 
 		case file_action_insulate:
@@ -1336,17 +1191,6 @@ integrate_pass_main()
 			break;
 		}
 
-		/*
-		 * The file exists, now, so clear the "about to be
-		 * created" flag.
-		 *
-		 * This flag can require clearing even if the file action
-		 * isn't "create", for various branch manipulations of
-		 * files created on the branch.  Clearing it redundantly
-		 * is harmless.
-		 */
-		p_src_data->about_to_be_created_by = 0;
-
 		/*
 		 * make sure the branch action is appropriate
 		 */
@@ -1382,43 +1226,27 @@ integrate_pass_main()
 		 */
 		if (!pp->parent)
 		{
-			assert(p_src_data->edit);
-			assert(p_src_data->edit->revision);
-			assert(p_src_data->edit_origin);
-			assert(p_src_data->edit_origin->revision);
+			/* Historical 2.3 -> 3.0 transition. */
+			if (!p_src_data->edit_number_origin)
+				p_src_data->edit_number_origin =
+					str_copy(p_src_data->edit_number);
+			assert(p_src_data->edit_number);
 			if
 			(
 				!str_equal
 				(
-					p_src_data->edit->revision,
-					p_src_data->edit_origin->revision
+					p_src_data->edit_number,
+					p_src_data->edit_number_origin
 				)
 			)
 			{
-				history_version_type.free(p_src_data->edit_origin);
-				p_src_data->edit_origin =
-					history_version_copy(p_src_data->edit);
+				str_free(p_src_data->edit_number_origin);
+				p_src_data->edit_number_origin =
+					str_copy(p_src_data->edit_number);
 			}
 		}
 	}
 
-	/*
-	 * Many history tools (e.g. RCS) can modify the contents of the
-	 * file when it is committed.  While there are usually options to
-	 * turn this off, they are seldom used.  The problem is: if the
-	 * commit changes the file, the source in the repository now no
-	 * longer matches the object file in the repository - i.e. the
-	 * history tool has compromised the referential integrity of
-	 * the repository.
-	 *
-	 * Check here if this is the case, and emit an error message if
-	 * so.	(It could be a fatal error, just a warning, or completely
-	 * ignored, depending on the history_put_trashes_file field of
-	 * the project config file.
-	 */
-	change_history_trashed_fingerprints(cp, &trashed);
-	string_list_destructor(&trashed);
-
 	/*
 	 * Advance the change to the 'completed' state.
 	 * Clear the build-time field.
@@ -1427,7 +1255,7 @@ integrate_pass_main()
 	 */
 	cstate_data->state = cstate_state_completed;
 	change_build_times_clear(cp);
-	dev_dir = str_copy(change_top_path_get(cp, 1));
+	dev_dir = str_copy(change_development_directory_get(cp, 1));
 	change_development_directory_clear(cp);
 	new_baseline = str_copy(change_integration_directory_get(cp, 1));
 	change_integration_directory_clear(cp);
@@ -1535,13 +1363,6 @@ integrate_pass_main()
 	dir_walk(id, time_map_set, &tml);
 	project_become_undo();
 
-	/*
-	 * Give the user a chance to re-sync any database associated
-	 * with the build tool.  (This is different to the integrate
-	 * pass notify command.)
-	 */
-	change_run_build_time_adjust_notify_command(cp);
-
 	/*
 	 * Write the change table row.
 	 * Write the user table row.
@@ -1565,7 +1386,7 @@ integrate_pass_main()
 
 		scp = sub_context_new();
 		nsec = tml.list[tml.len - 1].new - time_final;
-		sub_var_set_long(scp, "Number", nsec);
+		sub_var_set(scp, "Number", "%ld", nsec);
 		sub_var_optional(scp, "Number");
 		error_intl(scp, i18n("warning: file times in future"));
 		sub_context_delete(scp);
@@ -1597,13 +1418,20 @@ integrate_pass_main()
 void
 integrate_pass()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("integrate_pass()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		integrate_pass_help,	},
-		{ arglex_token_list,		integrate_pass_list,	},
-	};
+	default:
+		integrate_pass_main();
+		break;
 
-	trace(("integrate_pass()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), integrate_pass_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		integrate_pass_help();
+		break;
+
+	case arglex_token_list:
+		integrate_pass_list(integrate_pass_usage);
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
