@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1993-1999, 2001 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,13 +20,13 @@
  * MANIFEST: functions to implement move file
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 
-#include <ael/project/files.h>
+#include <ael.h>
 #include <aemv.h>
 #include <arglex2.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <commit.h>
 #include <error.h>
 #include <file.h>
@@ -36,7 +36,7 @@
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <sub.h>
 #include <trace.h>
 #include <undo.h>
@@ -114,7 +114,7 @@ move_file_list()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -170,7 +170,7 @@ move_file_innards(up, cp, old_name, new_name)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", old_name);
+		sub_var_set(scp, "File_Name", "%S", old_name);
 		change_fatal(cp, scp, i18n("file $filename dup"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -195,8 +195,8 @@ move_file_innards(up, cp, old_name, new_name)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", old_name);
-			sub_var_set_string(scp, "Guess", p_src_data->file_name);
+			sub_var_set(scp, "File_Name", "%S", old_name);
+			sub_var_set(scp, "Guess", "%S", p_src_data->file_name);
 			project_fatal(pp, scp, i18n("no $filename, closest is $guess"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -206,7 +206,7 @@ move_file_innards(up, cp, old_name, new_name)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", old_name);
+			sub_var_set(scp, "File_Name", "%S", old_name);
 			project_fatal(pp, scp, i18n("no $filename"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -221,7 +221,7 @@ move_file_innards(up, cp, old_name, new_name)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", config_name);
+		sub_var_set(scp, "File_Name", "%S", config_name);
 		project_fatal(pp, scp, i18n("no move $filename"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -235,7 +235,7 @@ move_file_innards(up, cp, old_name, new_name)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", old_name);
+		sub_var_set(scp, "File_Name", "%S", old_name);
 		change_fatal(cp, scp, i18n("nil move $filename"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -249,7 +249,7 @@ move_file_innards(up, cp, old_name, new_name)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", new_name);
+		sub_var_set(scp, "File_Name", "%S", new_name);
 		change_fatal(cp, scp, i18n("file $filename dup"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -271,7 +271,7 @@ move_file_innards(up, cp, old_name, new_name)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", new_name);
+		sub_var_set(scp, "File_Name", "%S", new_name);
 		project_fatal(pp, scp, i18n("$filename in baseline"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -285,11 +285,10 @@ move_file_innards(up, cp, old_name, new_name)
 	c_src_data->action = file_action_remove;
 	c_src_data->usage = p_src_data->usage;
 	c_src_data->move = str_copy(new_name);
-	assert(p_src_data->edit);
-	assert(p_src_data->edit->revision);
-	if (p_src_data->edit)
-		c_src_data->edit_origin =
-			history_version_copy(p_src_data->edit);
+	assert(p_src_data->edit_number);
+	if (p_src_data->edit_number)
+		c_src_data->edit_number_origin =
+			str_copy(p_src_data->edit_number);
 
 	c_src_data = change_file_new(cp, new_name);
 	c_src_data->action = file_action_create;
@@ -325,14 +324,18 @@ move_file_innards(up, cp, old_name, new_name)
 	if (os_exists(to))
 		os_unlink(to);
 	copy_whole_file(from, to, 0);
+	str_free(from);
+	os_mkdir_between(dd, old_name, 02755);
+	user_become_undo();
+	from = change_file_path(cp, old_name);
+	user_become(up);
+	undo_unlink_errok(from);
+	if (os_exists(from))
+		os_unlink(from);
+	os_junkfile(from, mode);
 	user_become_undo();
 	str_free(from);
 	str_free(to);
-
-	/*
-	 * remove the old file
-	 */
-	change_file_whiteout_write(cp, old_name, up);
 }
 
 
@@ -357,11 +360,8 @@ move_file_main()
 	size_t		k;
 	string_list_ty	search_path;
 	string_list_ty	wl_in;
-	int		based;
-	string_ty	*base;
 
 	trace(("move_file_main()\n{\n"/*}*/));
-	arglex();
 	old_name = 0;
 	new_name = 0;
 	project_name = 0;
@@ -377,12 +377,16 @@ move_file_main()
 
 		case arglex_token_string:
 			s1 = str_from_c(arglex_value.alv_string);
+			os_become_orig();
+			s2 = os_pathname(s1, 1);
+			os_become_undo();
+			str_free(s1);
 			if (!old_name)
-				old_name = s1;
+				old_name = s2;
 			else if (!new_name)
-				new_name = s1;
+				new_name = s2;
 			else
-				fatal_too_many_files();
+				fatal_intl(0, i18n("too many files"));
 			break;
 
 		case arglex_token_change:
@@ -399,7 +403,7 @@ move_file_main()
 			else if (change_number < 1)
 			{
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -424,16 +428,6 @@ move_file_main()
 		case arglex_token_wait_not:
 			user_lock_wait_argument(move_file_usage);
 			break;
-
-		case arglex_token_whiteout:
-		case arglex_token_whiteout_not:
-			user_whiteout_argument(move_file_usage);
-			break;
-
-		case arglex_token_base_relative:
-		case arglex_token_current_relative:
-			user_relative_filename_preference_argument(move_file_usage);
-			break;
 		}
 		arglex();
 	}
@@ -498,52 +492,9 @@ move_file_main()
 	 */
 
 	change_search_path_get(cp, &search_path, 1);
+	assert(old_name->str_text[0] == '/');
+	assert(new_name->str_text[0] == '/');
 
-	/*
-	 * Find the base for relative filenames.
-	 */
-	based =
-		(
-			search_path.nstrings >= 1
-		&&
-			(
-				user_relative_filename_preference
-				(
-					up,
-				      uconf_relative_filename_preference_current
-				)
-			==
-				uconf_relative_filename_preference_base
-			)
-		);
-	if (based)
-		base = search_path.string[0];
-	else
-	{
-		os_become_orig();
-		base = os_curdir();
-		os_become_undo();
-	}
-
-	/*
-	 * Make the old name absolute, now we know where to make it
-	 * relative to.
-	 */
-	if (old_name->str_text[0] != '/')
-	{
-		s1 = str_format("%S/%S", base, old_name);
-		str_free(old_name);
-		old_name = s1;
-	}
-	user_become(up);
-	s1 = os_pathname(old_name, 1);
-	user_become_undo();
-	str_free(old_name);
-	old_name = s1;
-
-	/*
-	 * Find the old name, relative to the project tree.
-	 */
 	s2 = 0;
 	for (k = 0; k < search_path.nstrings; ++k)
 	{
@@ -554,7 +505,7 @@ move_file_main()
 	if (!s2)
 	{
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", old_name);
+		sub_var_set(scp, "File_Name", "%S", old_name);
 		change_fatal(cp, scp, i18n("$filename unrelated"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -562,25 +513,6 @@ move_file_main()
 	str_free(old_name);
 	old_name = s2;
 
-	/*
-	 * Make the new name absolute, now we know where to make it
-	 * relative to.
-	 */
-	if (new_name->str_text[0] != '/')
-	{
-		s1 = str_format("%S/%S", base, new_name);
-		str_free(new_name);
-		new_name = s1;
-	}
-	user_become(up);
-	s1 = os_pathname(new_name, 1);
-	user_become_undo();
-	str_free(new_name);
-	new_name = s1;
-
-	/*
-	 * Find the new name, relative to the project tree.
-	 */
 	s2 = 0;
 	for (k = 0; k < search_path.nstrings; ++k)
 	{
@@ -591,7 +523,7 @@ move_file_main()
 	if (!s2)
 	{
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", new_name);
+		sub_var_set(scp, "File_Name", "%S", new_name);
 		change_fatal(cp, scp, i18n("$filename unrelated"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -606,7 +538,7 @@ move_file_main()
 	 * directory, just move it.  All checks to see if the action is
 	 * valid are done in the inner function.
 	 */
-	project_file_directory_query(pp, old_name, &wl_in, 0);
+	project_file_dir(pp, old_name, &wl_in, 0);
 	if (wl_in.nstrings)
 	{
 		size_t		j;
@@ -669,8 +601,8 @@ move_file_main()
 	 * verbose success message
 	 */
 	scp = sub_context_new();
-	sub_var_set_string(scp, "File_Name1", old_name);
-	sub_var_set_string(scp, "File_Name2", new_name);
+	sub_var_set(scp, "File_Name1", "%S", old_name);
+	sub_var_set(scp, "File_Name2", "%S", new_name);
 	change_verbose(cp, scp, i18n("move $filename1 to $filename2 complete"));
 	sub_context_delete(scp);
 
@@ -695,13 +627,20 @@ move_file_main()
 void
 move_file()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("move_file()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		move_file_help,	},
-		{ arglex_token_list,		move_file_list,	},
-	};
+	default:
+		move_file_main();
+		break;
 
-	trace(("move_file()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), move_file_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		move_file_help();
+		break;
+
+	case arglex_token_list:
+		move_file_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
