@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,11 +20,11 @@
  * MANIFEST: functions to implement new administrator
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 
 #include <aena.h>
-#include <ael/project/administrato.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <commit.h>
 #include <error.h>
@@ -112,7 +112,6 @@ new_administrator_main()
 	user_ty		*up;
 
 	trace(("new_administrator_main()\n{\n"/*}*/));
-	arglex();
 	string_list_constructor(&wl);
 	project_name = 0;
 	while (arglex_token != arglex_token_eoln)
@@ -135,7 +134,7 @@ new_administrator_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "Name", s1);
+				sub_var_set(scp, "Name", "%S", s1);
 				error_intl(scp, i18n("too many user $name"));
 				sub_context_delete(scp);
 				new_administrator_usage();
@@ -207,7 +206,7 @@ new_administrator_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", user_name(candidate));
+			sub_var_set(scp, "Name", "%S", user_name(candidate));
 			project_fatal(pp, scp, i18n("$name already administrator"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -219,7 +218,15 @@ new_administrator_main()
 		 * this is to avoid security holes
 		 */
 		if (!user_uid_check(user_name(candidate)))
-			fatal_user_too_privileged(user_name(candidate));
+		{
+			sub_context_ty	*scp;
+
+			scp = sub_context_new();
+			sub_var_set(scp,"Name", "%S", user_name(candidate));
+			fatal_intl(scp, i18n("user \"$name\" is too privileged"));
+			/* NOTREACHED */
+			sub_context_delete(scp);
+		}
 
 		/*
 		 * add it to the list
@@ -243,7 +250,7 @@ new_administrator_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Name", wl.string[j]);
+		sub_var_set(scp, "Name", "%S", wl.string[j]);
 		project_verbose(pp, scp, i18n("new administrator $name complete"));
 		sub_context_delete(scp);
 	}
@@ -256,13 +263,20 @@ new_administrator_main()
 void
 new_administrator()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("new_administrator()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		new_administrator_help,	},
-		{ arglex_token_list,		new_administrator_list,	},
-	};
+	default:
+		new_administrator_main();
+		break;
 
-	trace(("new_administrator()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), new_administrator_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		new_administrator_help();
+		break;
+
+	case arglex_token_list:
+		new_administrator_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
