@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,24 +20,21 @@
  * MANIFEST: functions to implement new change
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/time.h>
 
 #include <aeca.h>
-#include <ael/change/changes.h>
 #include <aenc.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <cattr.h>
 #include <change.h>
-#include <change/attributes.h>
-#include <change/verbose.h>
-#include <change/branch.h>
+#include <change_bran.h>
 #include <col.h>
 #include <commit.h>
 #include <common.h>
 #include <error.h>
-#include <file.h>
 #include <help.h>
 #include <io.h>
 #include <lock.h>
@@ -45,10 +42,10 @@
 #include <progname.h>
 #include <project.h>
 #include <project_hist.h>
-#include <str_list.h>
 #include <sub.h>
 #include <trace.h>
 #include <user.h>
+#include <str_list.h>
 
 
 static void new_change_usage _((void));
@@ -127,6 +124,90 @@ new_change_list()
 }
 
 
+static void cattr_defaults _((cattr, project_ty *, pconf));
+
+static void
+cattr_defaults(a, pp, pc)
+	cattr		a;
+	project_ty	*pp;
+	pconf		pc;
+{
+	trace(("cattr_defaults(a = %08lX, pp = %08lX, pc = %08lX)\n{\n"/*}*/,
+		(long)a, (long)pp, (long)pc));
+	if
+	(
+		a->cause == change_cause_internal_improvement
+	||
+		a->cause == change_cause_internal_improvement
+	)
+	{
+		if (!(a->mask & cattr_test_exempt_mask))
+		{
+			a->test_exempt = 1;
+			a->mask |= cattr_test_exempt_mask;
+		}
+		if (!(a->mask & cattr_test_baseline_exempt_mask))
+		{
+			a->test_baseline_exempt = 1;
+			a->mask |= cattr_test_baseline_exempt_mask;
+		}
+		if (!(a->mask & cattr_regression_test_exempt_mask))
+		{
+			a->regression_test_exempt = 0;
+			a->mask |= cattr_regression_test_exempt_mask;
+		}
+	}
+	else
+	{
+		if (!(a->mask & cattr_regression_test_exempt_mask))
+		{
+			a->regression_test_exempt = 1;
+			a->mask |= cattr_regression_test_exempt_mask;
+		}
+	}
+	if (!(a->mask & cattr_test_exempt_mask))
+	{
+		a->test_exempt = project_default_test_exemption_get(pp);
+		a->mask |= cattr_test_exempt_mask;
+	}
+	if (!(a->mask & cattr_test_baseline_exempt_mask))
+	{
+		a->test_baseline_exempt =
+			project_default_test_exemption_get(pp);
+		a->mask |= cattr_test_baseline_exempt_mask;
+	}
+
+	if (!a->architecture)
+		a->architecture =
+			(cattr_architecture_list)
+			cattr_architecture_list_type.alloc();
+	assert(pc->architecture);
+	assert(pc->architecture->length);
+	if (!a->architecture->length)
+	{
+		long		j;
+
+		for (j = 0; j < pc->architecture->length; ++j)
+		{
+			type_ty		*type_p;
+			string_ty	**str_p;
+			pconf_architecture pca;
+
+			str_p =
+				cattr_architecture_list_type.list_parse
+				(
+					a->architecture,
+					&type_p
+				);
+			assert(type_p == &string_type);
+			pca = pc->architecture->list[j];
+			*str_p = str_copy(pca->name);
+		}
+	}
+	trace((/*{*/"}\n"));
+}
+
+
 void
 new_change_check_permission(pp, up)
 	project_ty	*pp;
@@ -169,19 +250,15 @@ new_change_main()
 	edit_ty		edit;
 	long		j;
 	pconf		pconf_data;
-	string_list_ty	carch;
-	string_list_ty	darch;
-	string_list_ty	parch;
-	char		*output;
-	string_ty	*input;
+	string_list_ty		carch;
+	string_list_ty		darch;
+	string_list_ty		parch;
 
 	trace(("new_change_main()\n{\n"/*}*/));
-	arglex();
 	cattr_data = 0;
 	project_name = 0;
 	edit = edit_not_set;
 	change_number = 0;
-	output = 0;
 	while (arglex_token != arglex_token_eoln)
 	{
 		switch (arglex_token)
@@ -204,7 +281,7 @@ new_change_main()
 			else if (change_number < 1)
 			{
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ls", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -213,41 +290,23 @@ new_change_main()
 
 		case arglex_token_string:
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "Name", arglex_token_name(arglex_token_file));
+			sub_var_set(scp, "Name", "%s", arglex_token_name(arglex_token_file));
 			error_intl(scp, i18n("warning: use $name option"));
 			sub_context_delete(scp);
 			if (cattr_data)
-				fatal_too_many_files();
+				fatal_intl(0, i18n("too many files"));
 			goto read_input_file;
 
 		case arglex_token_file:
 			if (cattr_data)
 				duplicate_option(new_change_usage);
-			input = 0;
-			switch (arglex())
-			{
-			default:
-				option_needs_file
-				(
-					arglex_token_file,
-					new_change_usage
-				);
-				/* NOTREACHED*/
-
-			case arglex_token_string:
-				read_input_file:
-				input = str_from_c(arglex_value.alv_string);
-				break;
-
-			case arglex_token_stdio:
-				input = str_from_c("");
-				break;
-			}
+			if (arglex() != arglex_token_string)
+				option_needs_file(arglex_token_file, new_change_usage);
+			read_input_file:
 			os_become_orig();
-			cattr_data = cattr_read_file(input);
+			cattr_data = cattr_read_file(arglex_value.alv_string);
 			os_become_undo();
-			assert(cattr_data);
-			change_attributes_verify(input, cattr_data);
+			cattr_verify(arglex_value.alv_string, cattr_data);
 			break;
 
 		case arglex_token_project:
@@ -286,37 +345,9 @@ new_change_main()
 		case arglex_token_wait_not:
 			user_lock_wait_argument(new_change_usage);
 			break;
-
-		case arglex_token_output:
-			if (output)
-				duplicate_option(new_change_usage);
-			switch (arglex())
-			{
-			default:
-				option_needs_file(arglex_token_output, new_change_usage);
-				/* NOTREACHED */
-
-			case arglex_token_string:
-				output = arglex_value.alv_string;
-				break;
-
-			case arglex_token_stdio:
-				output = "";
-				break;
-			}
-			break;
 		}
 		arglex();
 	}
-	if (change_number && output)
-	{
-		mutually_exclusive_options
-		(
-			arglex_token_change,
-			arglex_token_output,
-			new_change_usage
-		);
-	}
 	if (edit != edit_not_set && cattr_data)
 	{
 		mutually_exclusive_options
@@ -335,8 +366,8 @@ new_change_main()
 	if (edit == edit_not_set && !cattr_data)
 	{
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name1", arglex_token_name(arglex_token_file));
-		sub_var_set_charstar(scp, "Name2", arglex_token_name(arglex_token_edit));
+		sub_var_set(scp, "Name1", "%s", arglex_token_name(arglex_token_file));
+		sub_var_set(scp, "Name2", "%s", arglex_token_name(arglex_token_edit));
 		error_intl(scp, i18n("warning: no $name1, assuming $name2"));
 		sub_context_delete(scp);
 		edit = edit_foreground;
@@ -395,18 +426,18 @@ new_change_main()
 		cstate_data = change_cstate_get(cp);
 		cstate_data->state = cstate_state_awaiting_development;
 		pconf_data = change_pconf_get(cp, 0);
-		change_attributes_default(cattr_data, pp, pconf_data);
+		cattr_defaults(cattr_data, pp, pconf_data);
 		change_free(cp);
 
 		/*
 		 * edit the attributes
 		 */
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Name", project_name_get(pp));
+		sub_var_set(scp, "Name", "%S", project_name_get(pp));
 		io_comment_append(scp, i18n("Project $name"));
 		io_comment_append(scp, i18n("nc dflt hint"));
 		sub_context_delete(scp);
-		change_attributes_edit(&cattr_data, edit);
+		cattr_edit(&cattr_data, edit);
 	}
 
 	/*
@@ -432,7 +463,7 @@ new_change_main()
 		if (project_change_number_in_use(pp, change_number))
 		{
 			scp = sub_context_new();
-			sub_var_set_long(scp, "Number", magic_zero_decode(change_number));
+			sub_var_set(scp, "Number", "%ld", magic_zero_decode(change_number));
 			project_fatal(pp, scp, i18n("change $number used"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -443,49 +474,24 @@ new_change_main()
 	cstate_data = change_cstate_get(cp);
 	cstate_data->state = cstate_state_awaiting_development;
 	pconf_data = change_pconf_get(cp, 0);
-	if (!pconf_data->build_command)
+	if (project_change_nth(pp, 0L, &j) == 0)
 	{
-		/*
-		 * There is no build command.  This means that the project
-		 * does not yet have a ``config'' file.  From this,
-		 * infer that this is the first change of the project.
-		 *
-		 * It has to be the first change because: aeb will fail
-		 * when it can't find a build_command in the non-existent
-		 * config file, so you can't aede until there is a
-		 * valid config file, so you can't have a baseline with
-		 * *anything* in it unless it also has a valid config
-		 * file.  Ergo, there have been no integrations yet;
-		 * we must be the first change.
-		 *
-		 * There could be a couple of changes created before one
-		 * of them is sucessfully integrated, but it doesn't
-		 * happen all that often, so I'm not going to worry
-		 * about it.
-		 */
+		/* this is the first change */
 		cattr_data->cause = change_cause_internal_enhancement;
 		cattr_data->test_baseline_exempt = 1;
 		cattr_data->mask |= cattr_test_baseline_exempt_mask;
 		cattr_data->regression_test_exempt = 1;
 		cattr_data->mask |= cattr_regression_test_exempt_mask;
 	}
-	change_attributes_default(cattr_data, pp, pconf_data);
+	cattr_defaults(cattr_data, pp, pconf_data);
 
 	/*
 	 * when developers create changes,
 	 * they may not give themselves a testing exemption,
 	 * or a architecture exemption,
 	 * only administrators may do that.
-	 *
-	 * Don't worry about this stuff for the very first change of
-	 * a project.
 	 */
-	if
-	(
-		pconf_data->build_command
-	&&
-		!project_administrator_query(pp, user_name(up))
-	)
+	if (!project_administrator_query(pp, user_name(up)))
 	{
 		/*
 		 * If they are asking for default behaviour, don't complain.
@@ -493,7 +499,7 @@ new_change_main()
 		 */
 		cattr dflt = cattr_type.alloc();
 		dflt->cause = cattr_data->cause;
-		change_attributes_default(dflt, pp, pconf_data);
+		cattr_defaults(dflt, pp, pconf_data);
 
 		if
 		(
@@ -614,30 +620,6 @@ new_change_main()
 	 */
 	project_change_append(pp, change_number, 0);
 
-	/*
-	 * If there is an output option,
-	 * write the change number to the file.
-	 */
-	if (output)
-	{
-		string_ty	*content;
-
-		content = str_format("%ld", magic_zero_decode(change_number));
-		if (*output)
-		{
-			string_ty	*fn;
-			
-			user_become(up);
-			fn = str_from_c(output);
-			file_from_string(fn, content, 0644);
-			str_free(fn);
-			user_become_undo();
-		}
-		else
-			cat_string_to_stdout(content);
-		str_free(content);
-	}
-
 	/*
 	 * Unlock the pstate file.
 	 */
@@ -648,7 +630,7 @@ new_change_main()
 	/*
 	 * verbose success message
 	 */
-	change_verbose_new_change_complete(cp);
+	change_verbose(cp, 0, i18n("new change complete"));
 	project_free(pp);
 	change_free(cp);
 	user_free(up);
@@ -659,13 +641,20 @@ new_change_main()
 void
 new_change()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("new_change()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		new_change_help,	},
-		{ arglex_token_list,		new_change_list,	},
-	};
+	default:
+		new_change_main();
+		break;
 
-	trace(("new_change()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), new_change_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		new_change_help();
+		break;
+
+	case arglex_token_list:
+		new_change_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
