@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,12 @@
  * MANIFEST: functions to implement new change undo
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/time.h>
 
 #include <aeca.h>
-#include <ael/change/by_state.h>
+#include <ael.h>
 #include <aencu.h>
 #include <arglex2.h>
 #include <cattr.h>
@@ -121,7 +121,6 @@ new_change_undo_main()
 	cstate		cstate_data;
 
 	trace(("new_change_undo_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	while (arglex_token != arglex_token_eoln)
@@ -148,7 +147,7 @@ new_change_undo_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -217,18 +216,7 @@ new_change_undo_main()
 	 */
 	if (cstate_data->state != cstate_state_awaiting_development)
 		change_fatal(cp, 0, i18n("bad ncu state"));
-	if
-	(
-		!project_administrator_query(pp, user_name(up))
-	&&
-		(
-			!project_developers_may_create_changes_get(pp)
-		||
-			!project_developer_query(pp, user_name(up))
-		||
-			!str_equal(change_developer_name(cp), user_name(up))
-		)
-	)
+	if (!project_administrator_query(pp, user_name(up)))
 		project_fatal(pp, 0, i18n("not an administrator"));
 
 	/*
@@ -267,13 +255,20 @@ new_change_undo_main()
 void
 new_change_undo()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("new_change_undo()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		new_change_undo_help,	},
-		{ arglex_token_list,		new_change_undo_list,	},
-	};
+	default:
+		new_change_undo_main();
+		break;
 
-	trace(("new_change_undo()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), new_change_undo_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		new_change_undo_help();
+		break;
+
+	case arglex_token_list:
+		new_change_undo_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
