@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,11 +20,11 @@
  * MANIFEST: functions to implement new integrator
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 
-#include <ael/project/integrators.h>
 #include <aeni.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <commit.h>
 #include <error.h>
@@ -34,10 +34,10 @@
 #include <progname.h>
 #include <project.h>
 #include <project_hist.h>
-#include <str_list.h>
 #include <sub.h>
 #include <trace.h>
 #include <user.h>
+#include <str_list.h>
 
 
 static void new_integrator_usage _((void));
@@ -64,10 +64,11 @@ new_integrator_help()
 }
 
 
-static void new_integrator_list _((void));
+static void new_integrator_list _((void (*)(void)));
 
 static void
-new_integrator_list()
+new_integrator_list(usage)
+	void		(*usage)_((void));
 {
 	string_ty	*project_name;
 
@@ -79,14 +80,14 @@ new_integrator_list()
 		switch (arglex_token)
 		{
 		default:
-			generic_argument(new_integrator_usage);
+			generic_argument(usage);
 			continue;
 
 		case arglex_token_project:
 			if (arglex() != arglex_token_string)
-				option_needs_name(arglex_token_project, new_integrator_usage);
+				option_needs_name(arglex_token_project, usage);
 			if (project_name)
-				duplicate_option_by_name(arglex_token_project, new_integrator_usage);
+				duplicate_option_by_name(arglex_token_project, usage);
 			project_name = str_from_c(arglex_value.alv_string);
 			break;
 		}
@@ -112,7 +113,6 @@ new_integrator_main()
 	user_ty		*up;
 
 	trace(("new_integrator_main()\n{\n"/*}*/));
-	arglex();
 	string_list_constructor(&wl);
 	project_name = 0;
 	while (arglex_token != arglex_token_eoln)
@@ -135,7 +135,7 @@ new_integrator_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "Name", s1);
+				sub_var_set(scp, "Name", "%S", s1);
 				fatal_intl(scp, i18n("too many user $name"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -207,7 +207,7 @@ new_integrator_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", user_name(candidate));
+			sub_var_set(scp, "Name", "%S", user_name(candidate));
 			project_fatal(pp, scp, i18n("$name already integrator"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -219,7 +219,15 @@ new_integrator_main()
 		 * this is to avoid security holes
 		 */
 		if (!user_uid_check(user_name(candidate)))
-			fatal_user_too_privileged(user_name(candidate));
+		{
+			sub_context_ty	*scp;
+
+			scp = sub_context_new();
+			sub_var_set(scp, "Name", "%S", user_name(candidate));
+			fatal_intl(scp, i18n("user \"$name\" is too privileged"));
+			/* NOTREACHED */
+			sub_context_delete(scp);
+		}
 
 		/*
 		 * add it to the list
@@ -243,7 +251,7 @@ new_integrator_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Name", wl.string[j]);
+		sub_var_set(scp, "Name", "%S", wl.string[j]);
 		project_verbose(pp, scp, i18n("new integrator $name complete"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -257,13 +265,20 @@ new_integrator_main()
 void
 new_integrator()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("new_integrator()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		new_integrator_help,	},
-		{ arglex_token_list,		new_integrator_list,	},
-	};
+	default:
+		new_integrator_main();
+		break;
 
-	trace(("new_integrator()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), new_integrator_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		new_integrator_help();
+		break;
+
+	case arglex_token_list:
+		new_integrator_list(new_integrator_usage);
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
