@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,28 +21,24 @@
  */
 
 #include <ac/ctype.h>
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/string.h>
 
-#include <ael/project/projects.h>
+#include <ael.h>
+#include <aenbr.h>
 #include <aenpr.h>
 #include <arglex2.h>
 #include <change.h>
-#include <change/branch.h>
+#include <change_bran.h>
 #include <commit.h>
 #include <error.h>
 #include <gonzo.h>
 #include <help.h>
-#include <io.h>
 #include <lock.h>
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project/pattr/edit.h>
-#include <project/pattr/get.h>
-#include <project/pattr/set.h>
-#include <project/verbose.h>
 #include <project_hist.h>
 #include <sub.h>
 #include <trace.h>
@@ -91,7 +87,6 @@ static void new_project_main _((void));
 static void
 new_project_main()
 {
-	string_ty	*s;
 	sub_context_ty	*scp;
 	string_ty	*home;
 	string_ty	*s1;
@@ -106,20 +101,14 @@ new_project_main()
 	int		version_number_length;
 	project_ty	*version_pp[SIZEOF(version_number)];
 	string_ty	*version_string;
+	string_ty	*s;
 	long		j;
-	int		keep;
-	pattr		pattr_data;
-	edit_ty		edit;
 
 	trace(("new_project_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	home = 0;
 	version_number_length = 0;
 	version_string = 0;
-	keep = -1;
-	pattr_data = 0;
-	edit = edit_not_set;
 	while (arglex_token != arglex_token_eoln)
 	{
 		switch (arglex_token)
@@ -154,66 +143,12 @@ new_project_main()
 			home = str_from_c(arglex_value.alv_string);
 			break;
 
-		case arglex_token_edit:
-			if (edit == edit_foreground)
-				duplicate_option(new_project_usage);
-			if (edit != edit_not_set)
-			{
-				too_many_edits:
-				mutually_exclusive_options
-				(
-					arglex_token_edit,
-					arglex_token_edit_bg,
-					new_project_usage
-				);
-			}
-			edit = edit_foreground;
-			break;
-
-		case arglex_token_edit_bg:
-			if (edit == edit_background)
-				duplicate_option(new_project_usage);
-			if (edit != edit_not_set)
-				goto too_many_edits;
-			edit = edit_background;
-			break;
-
-		case arglex_token_file:
-			if (pattr_data)
-				duplicate_option(new_project_usage);
-			switch (arglex())
-			{
-			default:
-				option_needs_file
-				(
-					arglex_token_file,
-					new_project_usage
-				);
-				/*NOTREACHED*/
-
-			case arglex_token_string:
-				os_become_orig();
-				s = str_from_c(arglex_value.alv_string);
-				pattr_data = pattr_read_file(s);
-				str_free(s);
-				os_become_undo();
-				break;
-
-			case arglex_token_stdio:
-				os_become_orig();
-				pattr_data = pattr_read_file((string_ty *)0);
-				os_become_undo();
-				break;
-			}
-			assert(pattr_data);
-			break;
-
 		case arglex_token_major:
 			if (version_number_length > 0 && version_number[0])
 				duplicate_option(new_project_usage);
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "Name1", arglex_token_name(arglex_token_major));
-			sub_var_set_charstar(scp, "Name2", arglex_token_name(arglex_token_version));
+			sub_var_set(scp, "Name1", "%s", arglex_token_name(arglex_token_major));
+			sub_var_set(scp, "Name2", "%s", arglex_token_name(arglex_token_version));
 			error_intl(scp, i18n("warning: $name1 obsolete, use $name2 option"));
 			sub_context_delete(scp);
 			if (arglex() != arglex_token_number)
@@ -229,8 +164,8 @@ new_project_main()
 			if (version_number_length >= 2 && version_number[1])
 				duplicate_option(new_project_usage);
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "Name1", arglex_token_name(arglex_token_minor));
-			sub_var_set_charstar(scp, "Name2", arglex_token_name(arglex_token_version));
+			sub_var_set(scp, "Name1", "%s", arglex_token_name(arglex_token_minor));
+			sub_var_set(scp, "Name2", "%s", arglex_token_name(arglex_token_version));
 			error_intl(scp, i18n("warning: $name1 obsolete, use $name2 option"));
 			sub_context_delete(scp);
 			if (arglex() != arglex_token_number)
@@ -254,49 +189,18 @@ new_project_main()
 
 			case arglex_token_number:
 			case arglex_token_string:
-				version_string =
-					str_from_c(arglex_value.alv_string);
-				break;
-
-			case arglex_token_stdio:
-				version_string = str_from_c("");
 				break;
 			}
+			version_string = str_from_c(arglex_value.alv_string);
 			break;
 
 		case arglex_token_wait:
 		case arglex_token_wait_not:
 			user_lock_wait_argument(new_project_usage);
 			break;
-
-		case arglex_token_keep:
-			if (keep > 0)
-				duplicate_option(new_project_usage);
-			if (keep >= 0)
-			{
-				mut_exc_keep:
-				mutually_exclusive_options
-				(
-					arglex_token_no_keep,
-					arglex_token_keep,
-					new_project_usage
-				);
-			}
-			keep = 1;
-			break;
-
-		case arglex_token_no_keep:
-			if (keep == 0)
-				duplicate_option(new_project_usage);
-			if (keep >= 0)
-				goto mut_exc_keep;
-			keep = 0;
-			break;
 		}
 		arglex();
 	}
-	if (keep < 0)
-		keep = 0;
 	if (!project_name)
 	{
 		error_intl(0, i18n("no project name"));
@@ -309,21 +213,6 @@ new_project_main()
 			error_intl(0, i18n("don't mix old and new version options"));
 			new_project_usage();
 		}
-		if (keep)
-		{
-			mutually_exclusive_options
-			(
-				arglex_token_keep,
-				(
-					version_number_length < 2
-				?
-					arglex_token_major
-				:
-					arglex_token_minor
-				),
-				new_project_usage
-			);
-		}
 		while (version_number_length < 2)
 			version_number[version_number_length++] = 0;
 		if (version_number[0] == 0)
@@ -337,8 +226,14 @@ new_project_main()
 		&version_number_length
 	);
 	if (!project_name_ok(project_name))
-		fatal_bad_project_name(project_name);
-	if (!keep && !version_number_length && !version_string)
+	{
+		scp = sub_context_new();
+		sub_var_set(scp, "Name", "%S", project_name);
+		fatal_intl(scp, i18n("bad project $name"));
+		/* NOTREACHED */
+		sub_context_delete(scp);
+	}
+	if (!version_number_length && !version_string)
 	{
 		/*
 		 * Only do this if there is no version number implicit
@@ -356,15 +251,6 @@ new_project_main()
 	{
 		int	err;
 
-		if (keep)
-		{
-			mutually_exclusive_options
-			(
-				arglex_token_keep,
-				arglex_token_version,
-				new_project_usage
-			);
-		}
 		err =
 			break_up_version_string
 			(
@@ -377,69 +263,12 @@ new_project_main()
 		if (err)
 		{
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Number", version_string);
+			sub_var_set(scp, "Number", "%S", version_string);
 			fatal_intl(scp, i18n("bad version $number"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
 		}
 	}
-	if (keep && edit == edit_foreground)
-	{
-		mutually_exclusive_options
-		(
-			arglex_token_edit,
-			arglex_token_keep,
-			new_project_usage
-		);
-	}
-	if (keep && edit == edit_background)
-	{
-		mutually_exclusive_options
-		(
-			arglex_token_edit_bg,
-			arglex_token_keep,
-			new_project_usage
-		);
-	}
-	if (keep && pattr_data)
-	{
-		mutually_exclusive_options
-		(
-			arglex_token_file,
-			arglex_token_keep,
-			new_project_usage
-		);
-	}
-	if (!pattr_data)
-		pattr_data = pattr_type.alloc(); 
-	if (!pattr_data->description)
-		pattr_data->description =
-			str_format("The \"%S\" program.", project_name);
-	if (!(pattr_data->mask & pattr_reuse_change_numbers_mask))
-	{
-		pattr_data->reuse_change_numbers = 1;
-		pattr_data->mask |= pattr_reuse_change_numbers_mask;
-	}
-	if (edit != edit_not_set)
-	{
-		scp = sub_context_new();
-		sub_var_set_string(scp, "Name", project_name);
-		io_comment_append(scp, "Project $name");
-		sub_context_delete(scp);
-		project_pattr_edit(&pattr_data, edit);
-
-		/*
-		 * You can't have no description.
-		 */
-		if (!pattr_data->description)
-			pattr_data->description =
-				str_format("The \"%S\" program.", project_name);
-		if (!(pattr_data->mask & pattr_reuse_change_numbers_mask))
-		{
-			pattr_data->reuse_change_numbers = 1;
-			pattr_data->mask |= pattr_reuse_change_numbers_mask;
-		}
-	}
 
 	/*
 	 * locate user data
@@ -447,7 +276,7 @@ new_project_main()
 	up = user_executing((project_ty *)0);
 
 	/*
-	 * read in the project table
+	 * read in the table
 	 */
 	gonzo_gstate_lock_prepare_new();
 	lock_take();
@@ -456,37 +285,28 @@ new_project_main()
 	 * make sure not too privileged
 	 */
 	if (!user_uid_check(up->name))
-		fatal_user_too_privileged(user_name(up));
+	{
+		scp = sub_context_new();
+		sub_var_set(scp, "Name", "%S", user_name(up));
+		fatal_intl(scp, i18n("user \"$name\" is too privileged"));
+		/* NOTREACHED */
+		sub_context_delete(scp);
+	}
 	if (!user_gid_check(up->group))
-		fatal_group_too_privileged(user_group(up));
+	{
+		scp = sub_context_new();
+		sub_var_set(scp, "Name", "%S", user_group(up));
+		fatal_intl(scp, i18n("group \"$name\" is too privileged"));
+		/* NOTREACHED */
+		sub_context_delete(scp);
+	}
 
 	/*
 	 * it is an error if the name is already in use
 	 */
-	if (gonzo_alias_to_actual(project_name))
-		fatal_project_alias_exists(project_name);
 	pp = project_alloc(project_name);
 	str_free(project_name);
-	if (keep)
-	{
-		if (gonzo_project_home_path_from_name(project_name))
-		{
-			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", pp->name);
-			fatal_intl(scp, i18n("project $name exists"));
-			/* NOTREACHED */
-			sub_context_delete(scp);
-		}
-		if (!home)
-		{
-			error_intl(0, i18n("aenpr -keep needs -dir"));
-			new_project_usage();
-			/* NOTREACHED */
-		}
-		project_home_path_set(pp, home);
-	}
-	else
-		project_bind_new(pp);
+	project_bind_new(pp);
 
 	/*
 	 * the user who ran the command is the project administrator.
@@ -508,14 +328,24 @@ new_project_main()
 		max = os_pathconf_name_max(s1);
 		os_become_undo();
 		if (project_name_get(pp)->str_length > max)
-			fatal_project_name_too_long(project_name_get(pp), max);
+		{
+			scp = sub_context_new();
+			sub_var_set(scp, "Name", "%S", project_name_get(pp));
+			sub_var_set(scp, "Number", "%d", (int)(project_name_get(pp)->str_length - max));
+			sub_var_optional(scp, "Number");
+			fatal_intl(scp, i18n("project \"$name\" too long"));
+			/* NOTREACHED */
+			sub_context_delete(scp);
+		}
 		home = str_format("%S/%S", s1, project_name_get(pp));
 		str_free(s1);
 
-		project_verbose_directory(pp, home);
+		scp = sub_context_new();
+		sub_var_set(scp, "File_Name", "%S", home);
+		project_verbose(pp, scp, i18n("proj dir $filename"));
+		sub_context_delete(scp);
 	}
-	if (!keep)
-		project_home_path_set(pp, home);
+	project_home_path_set(pp, home);
 	str_free(home);
 
 	/*
@@ -526,19 +356,16 @@ new_project_main()
 	bl = project_baseline_path_get(pp, 0);
 	hp = project_history_path_get(pp);
 	ip = project_info_path_get(pp);
-	if (!keep)
-	{
-		project_become(pp);
-		os_mkdir(home, 02755);
-		undo_rmdir_errok(home);
-		os_mkdir(bl, 02755);
-		undo_rmdir_errok(bl);
-		os_mkdir(hp, 02755);
-		undo_rmdir_errok(hp);
-		os_mkdir(ip, 02755);
-		undo_rmdir_errok(ip);
-		project_become_undo();
-	}
+	project_become(pp);
+	os_mkdir(home, 02755);
+	undo_rmdir_errok(home);
+	os_mkdir(bl, 02755);
+	undo_rmdir_errok(bl);
+	os_mkdir(hp, 02755);
+	undo_rmdir_errok(hp);
+	os_mkdir(ip, 02755);
+	undo_rmdir_errok(ip);
+	project_become_undo();
 
 	/*
 	 * add a row to the table
@@ -546,24 +373,24 @@ new_project_main()
 	gonzo_project_add(pp);
 
 	/*
-	 * copy the attributes into the project
+	 * copy the description into the change state
 	 */
-	if (!keep)
-		project_pattr_set(pp, pattr_data);
-	pattr_type.free(pattr_data);
+	s = str_format("The \"%S\" program.", project_name_get(pp));
+	project_description_set(pp, s);
+	str_free(s);
 
 	/*
 	 * create each of the branches
 	 */
 	ppp = pp;
-	for (j = 0; !keep && j < version_number_length; ++j)
+	for (j = 0; j < version_number_length; ++j)
 	{
 		long		change_number;
 
 		trace(("ppp = %8.8lX\n", (long)ppp));
 		change_number = magic_zero_encode(version_number[j]);
 		trace(("change_number = %ld;\n", change_number));
-		ppp = project_new_branch(ppp, up, change_number, (string_ty *)0);
+		ppp = new_branch_internals(up, ppp, change_number, (string_ty *)0);
 		version_pp[j] = ppp;
 	}
 
@@ -589,9 +416,9 @@ new_project_main()
 	/*
 	 * verbose success message
 	 */
-	project_verbose_new_project_complete(pp);
+	project_verbose(pp, 0, i18n("new project complete"));
 	for (j = 0; j < version_number_length; ++j)
-		project_verbose_new_branch_complete(version_pp[j]);
+		project_verbose(version_pp[j], 0, i18n("new branch complete"));
 
 	project_free(pp);
 	user_free(up);
@@ -602,13 +429,20 @@ new_project_main()
 void
 new_project()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("new_project()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		new_project_help,	},
-		{ arglex_token_list,		new_project_list,	},
-	};
+	default:
+		new_project_main();
+		break;
 
-	trace(("new_project()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), new_project_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		new_project_help();
+		break;
+
+	case arglex_token_list:
+		new_project_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
