@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -26,22 +26,22 @@
 #include <ac/fcntl.h>
 #include <ac/unistd.h>
 
-#include <ael/project/files.h>
+#include <ael.h>
 #include <aent.h>
 #include <arglex2.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <col.h>
 #include <commit.h>
 #include <error.h>
-#include <file.h>
+#include <glue.h>
 #include <help.h>
 #include <lock.h>
 #include <log.h>
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <project_hist.h>
 #include <sub.h>
 #include <trace.h>
@@ -110,7 +110,7 @@ new_test_list()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -151,25 +151,21 @@ new_test_main()
 	long		change_number;
 	change_ty	*cp;
 	user_ty		*up;
+	int		mode;
 	long		n;
 	string_list_ty	wl;
 	size_t		j, k;
 	int		nerrs;
 	string_ty	*config_name;
 	log_style_ty	log_style;
-	char		*output;
-	int		use_template;
 
 	trace(("new_test_main()\n{\n"/*}*/));
-	arglex();
 	manual_flag = 0;
 	automatic_flag = 0;
 	project_name = 0;
 	change_number = 0;
 	log_style = log_style_append_default;
 	string_list_constructor(&wl);
-	output = 0;
-	use_template = -1;
 	while (arglex_token != arglex_token_eoln)
 	{
 		switch (arglex_token)
@@ -206,7 +202,7 @@ new_test_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -247,44 +243,9 @@ new_test_main()
 		case arglex_token_current_relative:
 			user_relative_filename_preference_argument(new_test_usage);
 			break;
-
-		case arglex_token_output:
-			if (output)
-				duplicate_option(new_test_usage);
-			switch (arglex())
-			{
-			default:
-				option_needs_file(arglex_token_output, new_test_usage);
-				/* NOTREACHED */
-
-			case arglex_token_string:
-				output = arglex_value.alv_string;
-				break;
-
-			case arglex_token_stdio:
-				output = "";
-				break;
-			}
-			break;
-
-		case arglex_token_template:
-		case arglex_token_template_not:
-			if (use_template >= 0)
-				duplicate_option(new_test_usage);
-			use_template = (arglex_token == arglex_token_template);
-			break;
 		}
 		arglex();
 	}
-	if (change_number && output)
-	{
-		mutually_exclusive_options
-		(
-			arglex_token_change,
-			arglex_token_output,
-			new_test_usage
-		);
-	}
 	if (automatic_flag && manual_flag)
 	{
 		mutually_exclusive_options
@@ -408,7 +369,7 @@ new_test_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", wl.string[j]);
+				sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 				change_fatal(cp, scp, i18n("$filename unrelated"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -418,7 +379,7 @@ new_test_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s2);
+				sub_var_set(scp, "File_Name", "%S", s2);
 				change_error(cp, scp, i18n("too many $filename"));
 				sub_context_delete(scp);
 				++nerrs;
@@ -444,7 +405,7 @@ new_test_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_error(cp, scp, i18n("file $filename dup"));
 				sub_context_delete(scp);
 				++nerrs;
@@ -464,7 +425,7 @@ new_test_main()
 					sub_context_ty	*scp;
 
 					scp = sub_context_new();
-					sub_var_set_string(scp, "File_Name", s1);
+					sub_var_set(scp, "File_Name", "%S", s1);
 					project_error
 					(
 						pp,
@@ -512,48 +473,18 @@ new_test_main()
 	for (j = 0; j < wl.nstrings; ++j)
 	{
 		string_ty	*e;
-		string_ty	*file_name;
-		string_ty	*other;
 
-		file_name = wl.string[j];
-		if (str_equal(file_name, config_name))
+		if (str_equal(wl.string[j], config_name))
 		{
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", file_name);
+			sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 			change_error(cp, scp, i18n("may not test $filename"));
 			sub_context_delete(scp);
 			++nerrs;
 		}
-		other = change_file_directory_conflict(cp, file_name);
-		if (other)
-		{
-			sub_context_ty	*scp;
-
-			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", file_name);
-			sub_var_set_string(scp, "File_Name2", other);
-			sub_var_optional(scp, "File_Name2");
-			change_error(cp, scp, i18n("file $filename directory name conflict"));
-			sub_context_delete(scp);
-			++nerrs;
-			continue;
-		}
-		other = project_file_directory_conflict(pp, file_name);
-		if (other)
-		{
-			sub_context_ty	*scp;
-
-			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", file_name);
-			sub_var_set_string(scp, "File_Name2", other);
-			sub_var_optional(scp, "File_Name2");
-			project_error(pp, scp, i18n("file $filename directory name conflict"));
-			sub_context_delete(scp);
-			++nerrs;
-		}
-		e = change_filename_check(cp, file_name, 1);
+		e = change_filename_check(cp, wl.string[j], 1);
 		if (e)
 		{
 			sub_context_ty	*scp;
@@ -564,7 +495,7 @@ new_test_main()
 			 * change_filename_check function.
 			 */
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Message", e);
+			sub_var_set(scp, "Message", "%S", e);
 			change_error(cp, scp, i18n("$message"));
 			sub_context_delete(scp);
 			++nerrs;
@@ -577,7 +508,7 @@ new_test_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", nerrs);
+		sub_var_set(scp, "Number", "%d", nerrs);
 		sub_var_optional(scp, "Number");
 		change_fatal(cp, scp, i18n("new test failed"));
 		/* NOTREACHED */
@@ -593,10 +524,65 @@ new_test_main()
 	/*
 	 * create the files
 	 */
+	mode = 0644 & ~change_umask(cp);
+	user_become(up);
 	for (j = 0; j < wl.nstrings; ++j)
 	{
-		change_file_template(cp, wl.string[j], up, use_template);
+		s1 = wl.string[j];
+
+		os_mkdir_between(dd, s1, 02755);
+		s2 = str_format("%S/%S", dd, s1);
+		if (!os_exists(s2))
+		{
+			int		fd;
+			string_ty	*template;
+	
+			user_become_undo();
+			template = change_file_template(cp, s1);
+			user_become(up);
+			fd = glue_creat(s2->str_text, mode);
+			if (fd < 0)
+			{
+				sub_context_ty	*scp;
+
+				scp = sub_context_new();
+				sub_errno_set(scp);
+				sub_var_set(scp, "File_Name", "%S", s2);
+				fatal_intl(scp, i18n("create $filename: $errno"));
+				/* NOTREACHED */
+				sub_context_delete(scp);
+			}
+			undo_unlink_errok(s2);
+			if (template)
+			{
+				glue_write
+				(
+					fd,
+					template->str_text,
+					template->str_length
+				);
+				if
+				(
+					template->str_length
+				&&
+					(
+						template->str_text
+						[
+							template->str_length - 1
+						]
+					!=
+						'\n'
+					)
+				)
+					glue_write(fd, "\n", 1);
+				str_free(template);
+			}
+			glue_close(fd);
+			os_chmod(s2, mode);
+		}
+		str_free(s2);
 	}
+	user_become_undo();
 
 	/*
 	 * Add the files to the change.
@@ -639,30 +625,6 @@ new_test_main()
 	change_run_change_file_command(cp, &wl, up);
 	change_run_project_file_command(cp, up);
 
-	/*
-	 * If there is an output option,
-	 * write the change number to the file.
-	 */
-	if (output)
-	{
-		string_ty	*content;
-
-		content = wl2str(&wl, 0, wl.nstrings, "\n");
-		if (*output)
-		{
-			string_ty	*fn;
-
-			fn = str_from_c(output);
-			user_become(up);
-			file_from_string(fn, content, 0644);
-			user_become_undo();
-			str_free(fn);
-		}
-		else
-			cat_string_to_stdout(content);
-		str_free(content);
-	}
-
 	/*
 	 * update the state files
 	 * release the locks
@@ -681,7 +643,7 @@ new_test_main()
 
 		scp = sub_context_new();
 		s1 = wl.string[j];
-		sub_var_set_string(scp, "File_Name", s1);
+		sub_var_set(scp, "File_Name", "%S", s1);
 		change_verbose(cp, scp, i18n("new test $filename complete"));
 		sub_context_delete(scp);
 	}
@@ -696,13 +658,20 @@ new_test_main()
 void
 new_test()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("new_test()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		new_test_help,	},
-		{ arglex_token_list,		new_test_list,	},
-	};
+	default:
+		new_test_main();
+		break;
 
-	trace(("new_test()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), new_test_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		new_test_help();
+		break;
+
+	case arglex_token_list:
+		new_test_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
