@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,15 +20,15 @@
  * MANIFEST: functions to implement new test undo
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 #include <ac/unistd.h>
 
-#include <ael/change/files.h>
+#include <ael.h>
 #include <aentu.h>
 #include <arglex2.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <col.h>
 #include <commit.h>
 #include <error.h>
@@ -39,10 +39,10 @@
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <str_list.h>
 #include <sub.h>
 #include <trace.h>
 #include <user.h>
+#include <str_list.h>
 
 
 static void new_test_undo_usage _((void));
@@ -105,7 +105,7 @@ new_test_undo_list()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -151,7 +151,6 @@ new_test_undo_main()
 	string_ty	*base;
 
 	trace(("new_test_undo_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	log_style = log_style_append_default;
@@ -198,7 +197,7 @@ new_test_undo_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -345,13 +344,13 @@ new_test_undo_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", wl.string[j]);
+			sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 			change_error(cp, scp, i18n("$filename unrelated"));
 			sub_context_delete(scp);
 			++number_of_errors;
 			continue;
 		}
-		change_file_directory_query(cp, s2, &wl_in, 0);
+		change_file_dir(cp, s2, &wl_in, 0);
 		if (wl_in.nstrings)
 		{
 			int	used;
@@ -388,7 +387,7 @@ new_test_undo_main()
 						sub_context_ty	*scp;
 
 						scp = sub_context_new();
-						sub_var_set_string(scp, "File_Name", s3);
+						sub_var_set(scp, "File_Name", "%S", s3);
 						change_error(cp, scp, i18n("too many $filename"));
 						sub_context_delete(scp);
 						++number_of_errors;
@@ -404,10 +403,10 @@ new_test_undo_main()
 
 				scp = sub_context_new();
 				if (s2->str_length)
-					sub_var_set_string(scp, "File_Name", s2);
+					sub_var_set(scp, "File_Name", "%S", s2);
 				else
-					sub_var_set_charstar(scp, "File_Name", ".");
-				sub_var_set_long(scp, "Number", (long)wl_in.nstrings);
+					sub_var_set(scp, "File_Name", ".");
+				sub_var_set(scp, "Number", "%ld", (long)wl_in.nstrings);
 				sub_var_optional(scp, "Number");
 				change_error
 				(
@@ -426,7 +425,7 @@ new_test_undo_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s2);
+				sub_var_set(scp, "File_Name", "%S", s2);
 				change_error(cp, scp, i18n("too many $filename"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -460,8 +459,8 @@ new_test_undo_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
-				sub_var_set_string(scp, "Guess", src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S", s1);
+				sub_var_set(scp, "Guess", "%S", src_data->file_name);
 				change_error(cp, scp, i18n("no $filename, closest is $guess"));
 				sub_context_delete(scp);
 			}
@@ -470,7 +469,7 @@ new_test_undo_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				change_error(cp, scp, i18n("no $filename"));
 				sub_context_delete(scp);
 			}
@@ -491,7 +490,7 @@ new_test_undo_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", s1);
+			sub_var_set(scp, "File_Name", "%S", s1);
 			change_error(cp, scp, i18n("bad nt undo $filename"));
 			sub_context_delete(scp);
 			++number_of_errors;
@@ -502,7 +501,7 @@ new_test_undo_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", number_of_errors);
+		sub_var_set(scp, "Number", "%d", number_of_errors);
 		sub_var_optional(scp, "Number");
 		change_fatal(cp, scp, i18n("new test undo fail"));
 	}
@@ -555,7 +554,7 @@ new_test_undo_main()
 	 * run the change file command
 	 * and the project file command if necessary
 	 */
-	change_run_change_file_undo_command(cp, &wl, up);
+	change_run_change_file_command(cp, &wl, up);
 	change_run_project_file_command(cp, up);
 
 	/*
@@ -573,7 +572,7 @@ new_test_undo_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", wl.string[j]);
+		sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 		change_verbose(cp, scp, i18n("new test undo $filename complete"));
 		sub_context_delete(scp);
 	}
@@ -588,13 +587,20 @@ new_test_undo_main()
 void
 new_test_undo()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("new_test_undo()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		new_test_undo_help,	},
-		{ arglex_token_list,		new_test_undo_list,	},
-	};
+	default:
+		new_test_undo_main();
+		break;
 
-	trace(("new_test_undo()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), new_test_undo_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		new_test_undo_help();
+		break;
+
+	case arglex_token_list:
+		new_test_undo_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
