@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,11 +20,11 @@
  * MANIFEST: functions to implement remove administrator
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 
 #include <aera.h>
-#include <ael/project/administrato.h>
+#include <ael.h>
 #include <arglex2.h>
 #include <commit.h>
 #include <error.h>
@@ -112,7 +112,6 @@ remove_administrator_main()
 	user_ty		*up;
 
 	trace(("remove_administrator_main()\n{\n"/*}*/));
-	arglex();
 	string_list_constructor(&wl);
 	project_name = 0;
 	while (arglex_token != arglex_token_eoln)
@@ -135,7 +134,7 @@ remove_administrator_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "Name", s1);
+				sub_var_set(scp, "Name", "%S", s1);
 				fatal_intl(scp, i18n("too many user $name"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -196,15 +195,15 @@ remove_administrator_main()
 	 */
 	for (j = 0; j < wl.nstrings; ++j)
 	{
-		string_ty	*name;
+		user_ty	*candidate;
 
-		name = wl.string[j];
-		if (!project_administrator_query(pp, name))
+		candidate = user_symbolic(pp, wl.string[j]);
+		if (!project_administrator_query(pp, user_name(candidate)))
 		{
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", name);
+			sub_var_set(scp, "Name", "%S", user_name(candidate));
 			project_fatal
 			(
 				pp,
@@ -214,7 +213,8 @@ remove_administrator_main()
 			/* NOTREACHED */
 			sub_context_delete(scp);
 		}
-		project_administrator_remove(pp, name);
+		project_administrator_remove(pp, user_name(candidate));
+		user_free(candidate);
 	}
 
 	/*
@@ -238,7 +238,7 @@ remove_administrator_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Name", wl.string[j]);
+		sub_var_set(scp, "Name", "%S", wl.string[j]);
 		project_verbose(pp, scp, i18n("remove administrator $name complete"));
 		sub_context_delete(scp);
 	}
@@ -251,13 +251,20 @@ remove_administrator_main()
 void
 remove_administrator()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("remove_administrator()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		remove_administrator_help, },
-		{ arglex_token_list,		remove_administrator_list, },
-	};
+	default:
+		remove_administrator_main();
+		break;
 
-	trace(("remove_administrator()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), remove_administrator_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		remove_administrator_help();
+		break;
+
+	case arglex_token_list:
+		remove_administrator_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
