@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,24 +20,23 @@
  * MANIFEST: functions to implement remove file
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 
-#include <ael/project/files.h>
+#include <ael.h>
 #include <aerm.h>
 #include <arglex2.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <commit.h>
 #include <error.h>
-#include <file.h>
 #include <help.h>
 #include <lock.h>
 #include <log.h>
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <sub.h>
 #include <trace.h>
 #include <undo.h>
@@ -152,7 +151,7 @@ remove_file_list()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -220,7 +219,6 @@ remove_file_main()
 	string_ty	*base;
 
 	trace(("remove_file_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	string_list_constructor(&wl);
@@ -261,7 +259,7 @@ remove_file_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Name", change_number);
+				sub_var_set(scp, "Name", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -287,11 +285,6 @@ remove_file_main()
 			user_lock_wait_argument(remove_file_usage);
 			break;
 
-		case arglex_token_whiteout:
-		case arglex_token_whiteout_not:
-			user_whiteout_argument(remove_file_usage);
-			break;
-
 		case arglex_token_base_relative:
 		case arglex_token_current_relative:
 			user_relative_filename_preference_argument(remove_file_usage);
@@ -413,13 +406,13 @@ remove_file_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", wl.string[j]);
+			sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 			change_error(cp, scp, i18n("$filename unrelated"));
 			sub_context_delete(scp);
 			++number_of_errors;
 			continue;
 		}
-		project_file_directory_query(pp, s2, &wl_in, 0);
+		project_file_dir(pp, s2, &wl_in, 0);
 		if (wl_in.nstrings)
 		{
 			int	used;
@@ -442,7 +435,7 @@ remove_file_main()
 						sub_context_ty	*scp;
 
 						scp = sub_context_new();
-						sub_var_set_string(scp, "File_Name", s3);
+						sub_var_set(scp, "File_Name", "%S", s3);
 						change_error(cp, scp, i18n("too many $filename"));
 						sub_context_delete(scp);
 						++number_of_errors;
@@ -460,10 +453,10 @@ remove_file_main()
 
 				scp = sub_context_new();
 				if (s2->str_length)
-					sub_var_set_string(scp, "File_Name", s2);
+					sub_var_set(scp, "File_Name", "%S", s2);
 				else
-					sub_var_set_charstar(scp, "File_Name", ".");
-				sub_var_set_long(scp, "Number", (long)wl_in.nstrings);
+					sub_var_set(scp, "File_Name", ".");
+				sub_var_set(scp, "Number", "%ld", (long)wl_in.nstrings);
 				sub_var_optional(scp, "Number");
 				change_error
 				(
@@ -484,7 +477,7 @@ remove_file_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s2);
+				sub_var_set(scp, "File_Name", "%S", s2);
 				change_error(cp, scp, i18n("too many $filename"));
 				sub_context_delete(scp);
 				++number_of_errors;
@@ -503,7 +496,7 @@ remove_file_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", config_name);
+		sub_var_set(scp, "File_Name", "%S", config_name);
 		change_error(cp, scp, i18n("may not remove $filename"));
 		sub_context_delete(scp);
 		++number_of_errors;
@@ -524,7 +517,7 @@ remove_file_main()
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", s1);
+			sub_var_set(scp, "File_Name", "%S", s1);
 			change_error(cp, scp, i18n("file $filename dup"));
 			sub_context_delete(scp);
 			++number_of_errors;
@@ -546,8 +539,8 @@ remove_file_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
-				sub_var_set_string(scp, "Guess", p_src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S", s1);
+				sub_var_set(scp, "Guess", "%S", p_src_data->file_name);
 				project_error
 				(
 					pp,
@@ -561,7 +554,7 @@ remove_file_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", s1);
+				sub_var_set(scp, "File_Name", "%S", s1);
 				project_error(pp, scp, i18n("no $filename"));
 				sub_context_delete(scp);
 			}
@@ -586,17 +579,16 @@ remove_file_main()
 		 *	Updates branch edit_number_origin on
 		 *	integrate pass.
 		 */
-		assert(p_src_data->edit);
-		assert(p_src_data->edit->revision);
-		c_src_data->edit_origin =
-			history_version_copy(p_src_data->edit);
+		assert(p_src_data->edit_number);
+		c_src_data->edit_number_origin =
+			str_copy(p_src_data->edit_number);
 	}
 	if (number_of_errors)
 	{
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", number_of_errors);
+		sub_var_set(scp, "Number", "%d", number_of_errors);
 		sub_var_optional(scp, "Number");
 		change_fatal(cp, scp, i18n("remove file fail"));
 		/* NOTREACHED */
@@ -611,16 +603,36 @@ remove_file_main()
 	dd = change_development_directory_get(cp, 0);
 	for (j = 0; j < wl.nstrings; ++j)
 	{
+		string_ty	*s3;
+		time_t		mtime_oldest;
+		time_t		mtime_youngest;
+
 		/*
 		 * Find the mod-time of the file in the project
 		 */
 		s1 = wl.string[j];
+		s3 = project_file_path(pp, s1);
+		assert(s3);
+		user_become(up);
+		os_mtime_range(s3, &mtime_oldest, &mtime_youngest);
+		str_free(s3);
 
 		/*
-		 * Remove any existing file (this cleans up junk, and
-		 * breaks the link if we are using symlink trees).
+		 * create a junk file in the change
 		 */
-		change_file_whiteout_write(cp, s1, up);
+		os_mkdir_between(dd, s1, 02755);
+		s2 = str_format("%S/%S", dd, s1);
+		if (os_exists(s2))
+			os_unlink(s2);
+		undo_unlink_errok(s2);
+		os_junkfile(s2, 0644 & ~change_umask(cp));
+
+		/*
+		 * update the mod-time to match the project
+		 */
+		os_mtime_set_errok(s2, mtime_oldest);
+		str_free(s2);
+		user_become_undo();
 	}
 
 	/*
@@ -651,7 +663,7 @@ remove_file_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", wl.string[j]);
+		sub_var_set(scp, "File_Name", "%S", wl.string[j]);
 		change_verbose(cp, scp, i18n("remove file $filename complete"));
 		sub_context_delete(scp);
 	}
@@ -679,13 +691,20 @@ remove_file_main()
 void
 remove_file()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("remove_file()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		remove_file_help,	},
-		{ arglex_token_list,		remove_file_list,	},
-	};
+	default:
+		remove_file_main();
+		break;
 
-	trace(("remove_file()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), remove_file_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		remove_file_help();
+		break;
+
+	case arglex_token_list:
+		remove_file_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
