@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
  * MANIFEST: functions to implement remove project
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 
-#include <ael/project/projects.h>
+#include <ael.h>
 #include <aermpr.h>
 #include <arglex2.h>
 #include <change.h>
@@ -34,7 +34,6 @@
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project/active.h>
 #include <project_hist.h>
 #include <sub.h>
 #include <trace.h>
@@ -93,13 +92,15 @@ static void
 remove_project_main()
 {
 	long		nerr;
+	int		j;
 	string_ty	*project_name;
 	project_ty	*pp;
+	change_ty	*cp;
+	cstate		cstate_data;
 	user_ty		*up;
 	int		still_exists;
 
 	trace(("remove_project_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	while (arglex_token != arglex_token_eoln)
 	{
@@ -143,21 +144,8 @@ remove_project_main()
 		remove_project_usage();
 	}
 	pp = project_alloc(project_name);
-	project_bind_existing(pp);
-
-	/*
-	 * Make sure it is a top-level project we are talking about,
-	 * not merely a branch.
-	 */
-	if (pp->parent)
-		project_fatal(pp, 0, i18n("use aenbru instead"));
-
-	/*
-	 * make sure it's not an alias
-	 */
-	if (gonzo_alias_to_actual(project_name))
-		fatal_project_alias_exists(project_name);
 	str_free(project_name);
+	project_bind_existing(pp);
 
 	/*
 	 * see if the user already deleted it
@@ -187,15 +175,33 @@ remove_project_main()
 
 	/*
 	 * it is an error if any of the changes are active
-	 * or any changes on any of the branches
-	 * (project_active reports the error itself)
 	 */
-	project_active_check(pp, 1);
+	nerr = 0;
+	for (j = 0; ; ++j)
+	{
+		long	change_number;
+
+		if (!project_change_nth(pp, j, &change_number))
+			break;
+		cp = change_alloc(pp, change_number);
+		change_bind_existing(cp);
+		cstate_data = change_cstate_get(cp);
+		if
+		(
+			cstate_data->state >= cstate_state_being_developed
+		&& 
+			cstate_data->state <= cstate_state_being_integrated
+		)
+		{
+			change_error(cp, 0, i18n("still active"));
+			++nerr;
+		}
+		change_free(cp);
+	}
 
 	/*
 	 * it is an error if the current user is not an administrator
 	 */
-	nerr = 0;
 	if (!project_administrator_query(pp, user_name(up)))
 	{
 		project_error(pp, 0, i18n("not an administrator"));
@@ -245,13 +251,20 @@ remove_project_main()
 void
 remove_project()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("remove_project()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		remove_project_help,	},
-		{ arglex_token_list,		remove_project_list,	},
-	};
+	default:
+		remove_project_main();
+		break;
 
-	trace(("remove_project()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), remove_project_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		remove_project_help();
+		break;
+
+	case arglex_token_list:
+		remove_project_list();
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
