@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,17 +20,17 @@
  * MANIFEST: functions to implement review pass
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <ael/change/by_state.h>
+#include <ael.h>
 #include <aerp.h>
 #include <arglex2.h>
 #include <change.h>
-#include <change/file.h>
+#include <change_file.h>
 #include <commit.h>
 #include <dir.h>
 #include <error.h>
@@ -41,7 +41,7 @@
 #include <os.h>
 #include <progname.h>
 #include <project.h>
-#include <project/file.h>
+#include <project_file.h>
 #include <project_hist.h>
 #include <sub.h>
 #include <trace.h>
@@ -69,14 +69,15 @@ static void review_pass_help _((void));
 static void
 review_pass_help()
 {
-	help("aerpass", review_pass_usage);
+	help("aerp", review_pass_usage);
 }
 
 
-static void review_pass_list _((void));
+static void review_pass_list _((void (*usage)(void)));
 
 static void
-review_pass_list()
+review_pass_list(usage)
+	void		(*usage)_((void));
 {
 	string_ty	*project_name;
 
@@ -88,17 +89,17 @@ review_pass_list()
 		switch (arglex_token)
 		{
 		default:
-			generic_argument(review_pass_usage);
+			generic_argument(usage);
 			continue;
 
 		case arglex_token_project:
 			if (arglex() != arglex_token_string)
-				option_needs_name(arglex_token_project, review_pass_usage);
+				option_needs_name(arglex_token_project, usage);
 			/* fall through... */
 
 		case arglex_token_string:
 			if (project_name)
-				duplicate_option_by_name(arglex_token_project, review_pass_usage);
+				duplicate_option_by_name(arglex_token_project, usage);
 			project_name = str_from_c(arglex_value.alv_string);
 			break;
 		}
@@ -130,7 +131,6 @@ review_pass_main()
 	long		j;
 
 	trace(("review_pass_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	while (arglex_token != arglex_token_eoln)
@@ -157,7 +157,7 @@ review_pass_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -280,14 +280,14 @@ review_pass_main()
 		if (file_required)
 		{
 			user_become(up);
-			same = change_fingerprint_same(src_data->file_fp, path, 0);
+			same = change_fingerprint_same(src_data->file_fp, path);
 			user_become_undo();
 			if (!same)
 			{
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "File_Name", src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S", src_data->file_name);
 				change_fatal(cp, scp, i18n("$filename altered"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -298,14 +298,14 @@ review_pass_main()
 		if (diff_file_required)
 		{
 			user_become(up);
-			same = change_fingerprint_same(src_data->diff_file_fp, path_d, 0);
+			same = change_fingerprint_same(src_data->diff_file_fp, path_d);
 			user_become_undo();
 			if (!same)
 			{
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_format(scp, "File_Name", "%S,D", src_data->file_name);
+				sub_var_set(scp, "File_Name", "%S,D", src_data->file_name);
 				change_fatal(cp, scp, i18n("$filename altered"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -341,13 +341,20 @@ review_pass_main()
 void
 review_pass()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("review_pass()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		review_pass_help,	},
-		{ arglex_token_list,		review_pass_list,	},
-	};
+	default:
+		review_pass_main();
+		break;
 
-	trace(("review_pass()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), review_pass_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		review_pass_help();
+		break;
+
+	case arglex_token_list:
+		review_pass_list(review_pass_usage);
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
