@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,13 +20,13 @@
  * MANIFEST: functions to implement review pass undo
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <ael/change/by_state.h>
+#include <ael.h>
 #include <aerpu.h>
 #include <arglex2.h>
 #include <change.h>
@@ -70,10 +70,11 @@ review_pass_undo_help()
 }
 
 
-static void review_pass_undo_list _((void));
+static void review_pass_undo_list _((void (*usage)(void)));
 
 static void
-review_pass_undo_list()
+review_pass_undo_list(usage)
+	void		(*usage)_((void));
 {
 	string_ty	*project_name;
 
@@ -85,17 +86,17 @@ review_pass_undo_list()
 		switch (arglex_token)
 		{
 		default:
-			generic_argument(review_pass_undo_usage);
+			generic_argument(usage);
 			continue;
 
 		case arglex_token_project:
 			if (arglex() != arglex_token_string)
-				option_needs_name(arglex_token_project, review_pass_undo_usage);
+				option_needs_name(arglex_token_project, usage);
 			/* fall through... */
 
 		case arglex_token_string:
 			if (project_name)
-				duplicate_option_by_name(arglex_token_project, review_pass_undo_usage);
+				duplicate_option_by_name(arglex_token_project, usage);
 			project_name = str_from_c(arglex_value.alv_string);
 			break;
 		}
@@ -126,7 +127,6 @@ review_pass_undo_main()
 	user_ty		*up;
 
 	trace(("review_pass_undo_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	change_number = 0;
 	while (arglex_token != arglex_token_eoln)
@@ -153,7 +153,7 @@ review_pass_undo_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_long(scp, "Number", change_number);
+				sub_var_set(scp, "Number", "%ld", change_number);
 				fatal_intl(scp, i18n("change $number out of range"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -251,13 +251,20 @@ review_pass_undo_main()
 void
 review_pass_undo()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("review_pass_undo()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		review_pass_undo_help,	},
-		{ arglex_token_list,		review_pass_undo_list,	},
-	};
+	default:
+		review_pass_undo_main();
+		break;
 
-	trace(("review_pass_undo()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), review_pass_undo_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		review_pass_undo_help();
+		break;
+
+	case arglex_token_list:
+		review_pass_undo_list(review_pass_undo_usage);
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
