@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,10 +20,10 @@
  * MANIFEST: functions to implement remove reviewer
  */
 
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/stdlib.h>
 
-#include <ael/project/reviewers.h>
+#include <ael.h>
 #include <aerrv.h>
 #include <arglex2.h>
 #include <commit.h>
@@ -64,10 +64,11 @@ remove_reviewer_help()
 }
 
 
-static void remove_reviewer_list _((void));
+static void remove_reviewer_list _((void (*)(void)));
 
 static void
-remove_reviewer_list()
+remove_reviewer_list(usage)
+	void		(*usage)_((void));
 {
 	string_ty	*project_name;
 
@@ -79,14 +80,14 @@ remove_reviewer_list()
 		switch (arglex_token)
 		{
 		default:
-			generic_argument(remove_reviewer_usage);
+			generic_argument(usage);
 			continue;
 
 		case arglex_token_project:
 			if (arglex() != arglex_token_string)
-				option_needs_name(arglex_token_project, remove_reviewer_usage);
+				option_needs_name(arglex_token_project, usage);
 			if (project_name)
-				duplicate_option_by_name(arglex_token_project, remove_reviewer_usage);
+				duplicate_option_by_name(arglex_token_project, usage);
 			project_name = str_from_c(arglex_value.alv_string);
 			break;
 		}
@@ -112,7 +113,6 @@ remove_reviewer_main()
 	user_ty		*up;
 
 	trace(("remove_reviewer_main()\n{\n"/*}*/));
-	arglex();
 	project_name = 0;
 	string_list_constructor(&wl);
 	while (arglex_token != arglex_token_eoln)
@@ -135,7 +135,7 @@ remove_reviewer_main()
 				sub_context_ty	*scp;
 
 				scp = sub_context_new();
-				sub_var_set_string(scp, "Name", s1);
+				sub_var_set(scp, "Name", "%S", s1);
 				fatal_intl(scp, i18n("too many user $name"));
 				/* NOTREACHED */
 				sub_context_delete(scp);
@@ -196,15 +196,15 @@ remove_reviewer_main()
 	 */
 	for (j = 0; j < wl.nstrings; ++j)
 	{
-		string_ty	*name;
+		user_ty	*candidate;
 
-		name = wl.string[j];
-		if (!project_reviewer_query(pp, name))
+		candidate = user_symbolic(pp, wl.string[j]);
+		if (!project_reviewer_query(pp, user_name(candidate)))
 		{
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", name);
+			sub_var_set(scp, "Name", "%S", user_name(candidate));
 			project_fatal
 			(
 				pp,
@@ -214,7 +214,8 @@ remove_reviewer_main()
 			/* NOTREACHED */
 			sub_context_delete(scp);
 		}
-		project_reviewer_remove(pp, name);
+		project_reviewer_remove(pp, user_name(candidate));
+		user_free(candidate);
 	}
 
 	/*
@@ -232,7 +233,7 @@ remove_reviewer_main()
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Name", wl.string[j]);
+		sub_var_set(scp, "Name", "%S", wl.string[j]);
 		project_verbose(pp, scp, i18n("remove reviewer $name complete"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -246,13 +247,20 @@ remove_reviewer_main()
 void
 remove_reviewer()
 {
-	static arglex_dispatch_ty dispatch[] =
+	trace(("remove_reviewer()\n{\n"/*}*/));
+	switch (arglex())
 	{
-		{ arglex_token_help,		remove_reviewer_help,	},
-		{ arglex_token_list,		remove_reviewer_list,	},
-	};
+	default:
+		remove_reviewer_main();
+		break;
 
-	trace(("remove_reviewer()\n{\n"));
-	arglex_dispatch(dispatch, SIZEOF(dispatch), remove_reviewer_main);
-	trace(("}\n"));
+	case arglex_token_help:
+		remove_reviewer_help();
+		break;
+
+	case arglex_token_list:
+		remove_reviewer_list(remove_reviewer_usage);
+		break;
+	}
+	trace((/*{*/"}\n"));
 }
