@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1996, 1997, 1998, 1999, 2001 Peter Miller;
+ *	Copyright (C) 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 #ifndef COMMON_AC_WCHAR_H
 #define COMMON_AC_WCHAR_H
 
-#include <ac/stddef.h>
+#include <config.h>
 
 #ifdef HAVE_WCHAR_H
 #include <wchar.h>
@@ -36,14 +36,6 @@ typedef wchar_t wint_t;
 #endif
 #endif
 
-#ifndef HAVE_MBSTATE_T
-#define HAVE_MBSTATE_T
-#ifndef _MBSTATE_T
-#define _MBSTATE_T
-typedef int mbstate_t;
-#endif
-#endif
-
 #else
 
 #include <ac/stddef.h>
@@ -62,11 +54,6 @@ size_t wcsrtombs _((char *, const wchar_t **, size_t, mbstate_t *));
 
 #endif
 
-/* Solaris bug 1250837: include wchar.h before widec.h */
-#ifdef HAVE_WIDEC_H
-#include <widec.h>
-#endif
-
 
 /*
  * HAVE_ISWPRINT is only set if (a) there is a have_iswprint function,
