@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1995, 1996, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1995, 1996, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -73,11 +73,11 @@ static	int		changed;
  *	It is important that wstr_hash_ty be unsigned (int or long).
  */
 
-static wstr_hash_ty hash_generate _((const wchar_t *, size_t));
+static wstr_hash_ty hash_generate _((wchar_t *, size_t));
 
 static wstr_hash_ty
 hash_generate(s, n)
-	const wchar_t	*s;
+	wchar_t		*s;
 	size_t		n;
 {
 	wstr_hash_ty	retval;
@@ -161,7 +161,7 @@ split()
 {
 	wstring_ty	*p;
 	wstring_ty	*p2;
-	wstr_hash_ty	idx;
+	wstr_hash_ty	index;
 
 	/*
 	 * get the list to be split across buckets
@@ -193,11 +193,11 @@ split()
 		p2 = p;
 		p = p->wstr_next;
 
-		idx = p2->wstr_hash & hash_cutover_mask;
-		if (idx < hash_split)
-			idx = p2->wstr_hash & hash_cutover_split_mask;
-		p2->wstr_next = hash_table[idx];
-		hash_table[idx] = p2;
+		index = p2->wstr_hash & hash_cutover_mask;
+		if (index < hash_split)
+			index = p2->wstr_hash & hash_cutover_split_mask;
+		p2->wstr_next = hash_table[index];
+		hash_table[index] = p2;
 	}
 }
 
@@ -224,7 +224,7 @@ split()
 
 wstring_ty *
 wstr_from_c(s)
-	const char	*s;
+	char		*s;
 {
 	return wstr_n_from_c(s, strlen(s));
 }
@@ -251,7 +251,7 @@ wstr_from_c(s)
 
 wstring_ty *
 wstr_from_wc(ws)
-	const wchar_t	*ws;
+	wchar_t		*ws;
 {
 	return wstr_n_from_wc(ws, wcslen(ws));
 }
@@ -280,7 +280,7 @@ wstr_from_wc(ws)
 
 wstring_ty *
 wstr_n_from_c(s, length)
-	const char	*s;
+	char		*s;
 	size_t		length;
 {
 #if __STDC__ >= 1
@@ -291,7 +291,7 @@ wstr_n_from_c(s, length)
 	static wchar_t	*buf;
 	static size_t	bufmax;
 	size_t		remainder;
-	const char	*ip;
+	char		*ip;
 	wchar_t		*op;
 
 	/*
@@ -315,7 +315,7 @@ wstr_n_from_c(s, length)
 	/*
 	 * Reset the mbtowc internal state.
 	 */
-	mbtowc((wchar_t *)0, (char *)0, 0);			/*lint !e418 */
+	mbtowc((wchar_t *)0, (char *)0, 0);
 
 	/*
 	 * scan the string and extract the wide characters
@@ -359,7 +359,7 @@ wstr_n_from_c(s, length)
 			 * be "error" or broken, or otherwise useless.
 			 * Reset it so that we can keep going.
 			 */
-			mbtowc((wchar_t *)0, (char *)0, 0);	/*lint !e418 */
+			mbtowc((wchar_t *)0, (char *)0, 0);
 		}
 		else
 		{
@@ -404,29 +404,18 @@ wstr_n_from_c(s, length)
 
 void
 wstr_to_mbs(s, result_p, result_length_p)
-	const wstring_ty *s;
+	wstring_ty	*s;
 	char		**result_p;
 	size_t		*result_length_p;
 {
 	static char	*buf;
 	static size_t	bufmax;
 	int		n;
-	const wchar_t	*ip;
+	wchar_t		*ip;
 	size_t		remainder;
 	char		*op;
 	size_t		buflen;
 
-	/*
-	 * For reasons I don't understand, the MB_CUR_MAX symbol (wich is
-	 * defined as a reference to __mb_cur_max) does not get resolved
-	 * at link time, despite being present in libc.  It's easier to
-	 * just dodge the question.
-	 */
-#ifdef __CYGWIN__
-#undef MB_CUR_MAX
-#define MB_CUR_MAX 8
-#endif
-
 	/*
 	 * Do the conversion "long hand".  This is because the wcstombs
 	 * function barfs when it sees an invalid wchar_t.  This
@@ -456,7 +445,7 @@ wstr_to_mbs(s, result_p, result_length_p)
 	/*
 	 * The wctomb function has internal state.  It needs to be reset.
 	 */
-	wctomb((char *)0, 0);					/*lint !e418 */
+	wctomb((char *)0, 0);
 
 	ip = s->wstr_text;
 	remainder = s->wstr_length;
@@ -480,7 +469,7 @@ wstr_to_mbs(s, result_p, result_length_p)
 			 * be "error" or broken, or otherwise useless.
 			 * Reset it so that we can keep going.
 			 */
-			wctomb((char *)0, 0);			/*lint !e418 */
+			wctomb((char *)0, 0);
 		}
 		else
 		{
@@ -537,22 +526,22 @@ wstr_to_mbs(s, result_p, result_length_p)
 
 wstring_ty *
 wstr_n_from_wc(s, length)
-	const wchar_t	*s;
+	wchar_t		*s;
 	size_t		length;
 {
 	wstr_hash_ty	hash;
-	wstr_hash_ty	idx;
+	wstr_hash_ty	index;
 	wstring_ty	*p;
 
 	if (!hash_modulus)
 		wstr_initialize();
 	hash = hash_generate(s, length);
 
-	idx = hash & hash_cutover_mask;
-	if (idx < hash_split)
-		idx = hash & hash_cutover_split_mask;
+	index = hash & hash_cutover_mask;
+	if (index < hash_split)
+		index = hash & hash_cutover_split_mask;
 
-	for (p = hash_table[idx]; p; p = p->wstr_next)
+	for (p = hash_table[index]; p; p = p->wstr_next)
 	{
 		if
 		(
@@ -572,8 +561,8 @@ wstr_n_from_wc(s, length)
 	p->wstr_hash = hash;
 	p->wstr_length = length;
 	p->wstr_references = 1;
-	p->wstr_next = hash_table[idx];
-	hash_table[idx] = p;
+	p->wstr_next = hash_table[index];
+	hash_table[index] = p;
 	memcpy(p->wstr_text, s, length * sizeof(wchar_t));
 	p->wstr_text[length] = 0;
 
@@ -634,7 +623,7 @@ void
 wstr_free(s)
 	wstring_ty	*s;
 {
-	wstr_hash_ty	idx;
+	wstr_hash_ty	index;
 	wstring_ty	**spp;
 
 	if (!s)
@@ -650,10 +639,10 @@ wstr_free(s)
 	 * find the hash bucket it was in,
 	 * and remove it
 	 */
-	idx = s->wstr_hash & hash_cutover_mask;
-	if (idx < hash_split)
-		idx = s->wstr_hash & hash_cutover_split_mask;
-	for (spp = &hash_table[idx]; *spp; spp = &(*spp)->wstr_next)
+	index = s->wstr_hash & hash_cutover_mask;
+	if (index < hash_split)
+		index = s->wstr_hash & hash_cutover_split_mask;
+	for (spp = &hash_table[index]; *spp; spp = &(*spp)->wstr_next)
 	{
 		if (*spp == s)
 		{
@@ -692,8 +681,8 @@ wstr_free(s)
 
 wstring_ty *
 wstr_catenate(s1, s2)
-	const wstring_ty *s1;
-	const wstring_ty *s2;
+	wstring_ty	*s1;
+	wstring_ty	*s2;
 {
 	static wchar_t	*tmp;
 	static size_t	tmplen;
@@ -734,9 +723,9 @@ wstr_catenate(s1, s2)
 
 wstring_ty *
 wstr_cat_three(s1, s2, s3)
-	const wstring_ty *s1;
-	const wstring_ty *s2;
-	const wstring_ty *s3;
+	wstring_ty	*s1;
+	wstring_ty	*s2;
+	wstring_ty	*s3;
 {
 	static wchar_t	*tmp;
 	static size_t	tmplen;
@@ -767,48 +756,6 @@ wstr_cat_three(s1, s2, s3)
 }
 
 
-wstring_ty *
-wstr_capitalize(ws)
-	const wstring_ty *ws;
-{
-	static wchar_t	*buffer;
-	static size_t	buflen;
-	size_t		j;
-	int		prev_was_alpha;
-
-	if (ws->wstr_length > buflen)
-	{
-		buflen = ws->wstr_length;
-		buffer = mem_change_size(buffer, buflen * sizeof(wchar_t));
-	}
-	language_human();
-	prev_was_alpha = 0;
-	for (j = 0; j < ws->wstr_length; ++j)
-	{
-		wchar_t		c;
-
-		c = ws->wstr_text[j];
-		if (iswlower(c))
-		{
-			if (!prev_was_alpha)
-				c = towupper(c);
-			prev_was_alpha = 1;
-		}
-		else if (iswupper(c))
-		{
-			if (prev_was_alpha)
-				c = towlower(c);
-			prev_was_alpha = 1;
-		}
-		else
-			prev_was_alpha = 0;
-		buffer[j] = c;
-	}
-	language_C();
-	return wstr_n_from_wc(buffer, ws->wstr_length);
-}
-
-
 wstring_ty *
 wstr_to_upper(ws)
 	const wstring_ty *ws;
@@ -919,8 +866,8 @@ wstr_to_ident(ws)
 
 int
 wstr_equal(s1, s2)
-	const wstring_ty *s1;
-	const wstring_ty *s2;
+	wstring_ty	*s1;
+	wstring_ty	*s2;
 {
 	return (s1 == s2);
 }
@@ -930,7 +877,7 @@ wstr_equal(s1, s2)
 
 wstring_ty *
 str_to_wstr(s)
-	const string_ty	*s;
+	string_ty	*s;
 {
 	return wstr_n_from_c(s->str_text, s->str_length);
 }
@@ -938,7 +885,7 @@ str_to_wstr(s)
 
 string_ty *
 wstr_to_str(ws)
-	const wstring_ty *ws;
+	wstring_ty	*ws;
 {
 	char		*text;
 	size_t		length;
