@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1998, 1999, 2001 Peter Miller;
+#	Copyright (C) 1998 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -21,11 +21,7 @@
 # MANIFEST: shell script to rpm-build
 #
 case $# in
-3)
-	icon=$3
-	;;
 2)
-	icon=
 	;;
 *)
 	echo "Usage: $0 tmp-dir tarball" 1>&2
@@ -37,32 +33,19 @@ tmp=$1
 tarball=$2
 
 mkdir -p $tmp/BUILD $tmp/BUILD_ROOT $tmp/RPMS/i386 \
-	/tmp/aegis-build-root/etc/httpd/conf \
-	/tmp/aegis-build-root/home/httpd/cgi-bin \
 	$tmp/SOURCES $tmp/SPECS $tmp/SRPMS
 
-
-# copy the Apache config file into the build root
-# so that ./configure can find it.
-cp /etc/httpf/conf/httpd.conf /tmp/aegis-build-root/etc/httpf/conf/httpd.conf
-
 here=`pwd`/$tmp
-
-cat > $tmp/macros << fubar
-%_builddir	$here/BUILD
-%_buildroot	$here/BUILD_ROOT
-%_rpmdir	$here/RPMS
-%_sourcedir	$here/SOURCES
-%_specdir	$here/SPECS
-%_srcrpmdir	$here/SRPMS
-fubar
-
-mac=`rpm --showrc | awk '/^macrofile/{print $3}'`
 cat > $tmp/rpmrc << fubar
-macrofiles: ${mac}:$here/macros
+builddir: $here/BUILD
+buildroot: $here/BUILD_ROOT
+rpmdir: $here/RPMS
+sourcedir: $here/SOURCES
+specdir: $here/SPECS
+srcrpmdir: $here/SRPMS
 fubar
 
-rpm -ta --rcfile /usr/lib/rpm/rpmrc:${tmp}/rpmrc --verbose --verbose $2
+rpm -ta --rcfile $tmp/rpmrc --verbose --verbose $2
 test $? -eq 0 || exit 1
 
 exit 0
