@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1997, 1999-2001 Peter Miller;
+#	Copyright (C) 1997 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -21,11 +21,6 @@
 # MANIFEST: shell script to generate RedHat spec file
 #
 version=${version-0.0.0}
-echo '#'
-echo '# This file is GENERATED.  Please DO NOT send the maintainer'
-echo '# patches to this file.  If there is a problemn with this file,'
-echo '# fix etc/spec.sh, and set the etc/spec.sh patch to the maintainer.'
-echo '#'
 echo 'Summary: project change supervisor'
 echo 'Name: aegis'
 echo "Version: ${version}"
@@ -35,7 +30,6 @@ echo 'Group: Development/Version Control'
 echo "Source: http://www.canb.auug.org.au/~millerp/aegis-${version}.tar.gz"
 echo 'URL: http://www.canb.auug.org.au/~millerp/aegis.html'
 echo 'BuildRoot: /tmp/aegis-build-root'
-echo 'Icon: aegis.gif'
 
 prefix=/usr
 #
@@ -96,42 +90,15 @@ files_rx=
 txtdocs=
 psdocs=
 dvidocs=
-dirs=
-name=`echo dir_${prefix} | sed 's/[^a-zA-Z0-9]/_/g'`
-eval "${name}=yes"
-eval "${name}_share=yes"
-eval "${name}_lib=yes"
-eval "${name}_com=yes"
-eval "${name}_man=yes"
-eval "${name}_man_man1=yes"
-eval "${name}_man_man5=yes"
 
 remember_prog()
 {
-	name=`echo ${1} | sed 's/[^a-zA-Z0-9]/_/g'`
-	if eval "test \"\${${name}-no}\" != yes"
+	if eval "test \"\${prog_${1}-no}\" != yes"
 	then
-		eval "${name}=yes"
+		eval "prog_${1}=yes"
 		files_rx="$files_rx $prefix/bin/${1}"
 	fi
 }
-remember_dir()
-{
-	case "${1}" in
-	/)
-		;;
-	*)
-		remember_dir `dirname ${1}`
-
-		name=`echo dir_${1} | sed 's/[^a-zA-Z0-9]/_/g'`
-		if eval "test \"\${${name}-no}\" != yes"
-		then
-			eval "${name}=yes"
-			dirs="$dirs ${1}"
-		fi
-		;;
-	esac
-}
 
 for file in $*
 do
@@ -144,7 +111,7 @@ do
 	case $file in
 
 	aefp/* | etc/* | common/* | find_sizes/* | fmtgen/* | \
-	fstrcmp/* | libaegis/* | test/* | test_*)
+	fstrcmp/* | libaegis/* | test/*)
 		;;
 
 	*/main.c)
@@ -152,21 +119,14 @@ do
 		remember_prog $dir
 		;;
 
-	script/aegis.synpic)
-		;;
-	script/*)
-		prog=`echo $file | sed 's|.*/||'`
-		remember_prog $prog
-		;;
-
-	lib/*/LC_MESSAGES/libaegis.po)
+	lib/*/building/* | lib/*/lsm/* | lib/*/readme/* | \
+	lib/*/release/* | lib/*/LC_MESSAGES/libaegis.po)
 		;;
 
 	lib/*.po)
 		stem=`echo $file | sed 's|^lib/\(.*\)\.po$|\1|'`
 		dst="$prefix/lib/aegis/$stem.mo"
 		files_ro="$files_ro $dst"
-		remember_dir `dirname $dst`
 		;;
 
 	lib/*/*/*.so | lib/*/*/*.bib | lib/*/*/*.pic)
@@ -176,19 +136,13 @@ do
 		;;
 
 	lib/*/man?/*)
-		# Some versions of RPM gzip man pages for free.  This is
-		# a pain in the behind.  Use a pattern to find them.  Sigh.
 		stem=`echo $file | sed 's|^lib/||'`
-		dst="$prefix/share/aegis/${stem}*"
-		files_ro="$files_ro $dst"
-		remember_dir `dirname $dst`
+		files_ro="$files_ro $prefix/share/aegis/$stem"
 
 		case $file in
 		lib/en/*)
 			stem2=`echo $file | sed 's|^lib/en/||'`
-			dst="$prefix/man/${stem2}*"
-			files_ro="$files_ro $dst"
-			remember_dir `dirname $dst`
+			files_ro="$files_ro $prefix/man/$stem2"
 			;;
 		esac
 		;;
@@ -209,21 +163,12 @@ do
 		rest=`echo $file | sed 's|^lib/||'`
 		dst="$prefix/share/aegis/$rest"
 		files_rx="$files_rx $dst"
-		remember_dir `dirname $dst`
-		;;
-
-	lib/cshrc.in | lib/profile.in | lib/cshrc | lib/profile )
-		rest=`echo $file | sed -e 's|^lib/||' -e 's|\.in$||'`
-		dst="$prefix/share/aegis/$rest"
-		files_rx="$files_rx $dst"
-		remember_dir `dirname $dst`
 		;;
 
 	lib/*)
 		rest=`echo $file | sed 's|^lib/||'`
 		dst="$prefix/share/aegis/$rest"
 		files_ro="$files_ro $dst"
-		remember_dir `dirname $dst`
 		;;
 
 	*)
@@ -231,81 +176,51 @@ do
 	esac
 done
 
-grumble()
-{
-	echo '#'
-	echo "# See the comment at the top of this file.  If you don't like"
-	echo '# the file attributes, or there is a file missing, DO NOT send'
-	echo '# the maintainer a patch to this file.  This file is GENERATED.'
-	echo '# If you want different attributes, fix the etc/spec.sh file,'
-	echo '# and send THAT patch to the maintainer.'
-	echo '#'
-}
-
 echo ''
-grumble
 echo '%files'
-for file in $dirs
-do
-	echo "%attr(0755,root,bin) %dir $file"
-done
+echo "%attr(0755,3,3) %dir $prefix/com/aegis"
+echo "%attr(0755,3,3) %dir $prefix/lib/aegis"
+echo "%attr(0755,3,3) %dir $prefix/share/aegis"
 for file in $files_rx
 do
 	case $file in
-	*/bin/aegis | */bin/aeimport)
-		echo "%attr(4755,root,bin) $file"
+	*/bin/aegis)
+		echo "%attr(4755,0,0) $file"
+		;;
+	*/bin/*)
+		echo "%attr(0755,0,0) $file"
 		;;
 	*)
-		echo "%attr(0755,root,bin) $file"
+		echo "%attr(0755,3,3) $file"
 		;;
 	esac
 done
 for file in $files_ro
 do
-	echo "%attr(0644,root,bin) $file"
+	echo "%attr(0644,3,3) $file"
 done
-echo "%attr(0755,root,bin) /etc/profile.d/aegis.sh"
-echo "%attr(0755,root,bin) /etc/profile.d/aegis.csh"
 
 echo ''
-grumble
 echo '%files txtdocs'
-echo "%attr(0755,root,bin) %dir $prefix/share/aegis"
 for file in $txtdocs
 do
-	echo "%attr(0644,root,bin) $file"
+	echo "%attr(0644,0,0) $file"
 done
 
 echo ''
-grumble
 echo '%files psdocs'
-echo "%attr(0755,root,bin) %dir $prefix/share/aegis"
 for file in $psdocs
 do
-	echo "%attr(0644,root,bin) $file"
+	echo "%attr(0644,0,0) $file"
 done
 
 echo ''
-grumble
 echo '%files dvidocs'
-echo "%attr(0755,root,bin) %dir $prefix/share/aegis"
 for file in $dvidocs
 do
-	echo "%attr(0644,root,bin) $file"
+	echo "%attr(0644,0,0) $file"
 done
 
-echo ''
-echo '#'
-echo '# This next bit is done because when using Aegis with NFS, these'
-echo '# files must have EXACTLY the same uid and gid on all systems.'
-echo "# Unfortunately, RPM won't let you give exact numeric uids and gids,"
-echo '# and the names for low-numbered uids and gids are essentially'
-echo '# random across the various Unix implementations.  Sigh.'
-echo '#'
-echo '%post'
-echo "chown -R 3 $prefix/com/aegis $prefix/lib/aegis $prefix/share/aegis"
-echo "chgrp -R 3 $prefix/com/aegis $prefix/lib/aegis $prefix/share/aegis"
-
 echo ''
 echo '%clean'
 echo 'rm -rf $RPM_BUILD_ROOT'
