@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991, 1992, 1993, 1994, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994 Peter Miller.
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -48,7 +48,7 @@ gen_code_declarator(type, name, is_a_list)
 	string_ty	*name;
 	int		is_a_list;
 {
-	indent_printf("integer_write(fp, "/*)*/);
+	indent_printf("integer_write("/*)*/);
 	if (is_a_list)
 		indent_printf("(char *)0");
 	else
@@ -83,5 +83,4 @@ type_method_ty type_integer =
 	gen_code_declarator,
 	gen_free_declarator,
 	0, /* member_add */
-	0, /* in_include_file */
 };
