@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1994, 1995, 1999, 2000, 2001 Peter Miller;
+#	Copyright (C) 1994, 1995 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 # MANIFEST: shell script to notify 'aedb -User' events
 #
 # Suggested project attribute:
-# forced_develop_begin_notify_command = "$datadir/db_forced.sh $p $c $developer";
+# forced_develop_begin_notify_command = "$lib/db_forced.sh $p $c $developer";
 #
 aegis=aegis
 case $# in
@@ -57,14 +57,13 @@ if [ $? -ne 0 ]; then quit; fi
 #
 # include full details of the change
 #
-$aegis -list change_details -project $project -change $change -verbose \
-	-pl=66 -pw=68 >> $tmp
+$aegis -list change_details -project $project -change $change -verbose >> $tmp
 if [ $? -ne 0 ]; then quit; fi
 
 #
 # mail it to all reviewers
 #
-mail -s "Project $project: Change $change: Develop Begin" $developer < $tmp
+mail $developer < $tmp
 if [ $? -ne 0 ]; then quit; fi
 
 #
