@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1992, 1993, 1995, 1999, 2000, 2001 Peter Miller;
+#	Copyright (C) 1992, 1993, 1995 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 # MANIFEST: command used to notify by email that a change has been withdrawn from review
 #
 # Suggested project attribute:
-# develop_end_undo_notify_command = "$datadir/deu.sh $p $c";
+# develop_end_undo_notify_command = "$lib/deu.sh $p $c";
 #
 aegis=aegis
 case $# in
@@ -68,14 +68,13 @@ if [ $? -ne 0 ]; then quit; fi
 #
 # include full details of the change
 #
-$aegis -list change_details -project $project -change $change -verbose \
-	-pl=66 -pw=80 >> $tmp
+$aegis -list change_details -project $project -change $change -verbose >> $tmp
 if [ $? -ne 0 ]; then quit; fi
 
 #
 # mail it to all reviewers
 #
-mail -s "Project $prokect: Change $change: withdrawn from review" $reviewers < $tmp
+mail $reviewers < $tmp
 if [ $? -ne 0 ]; then quit; fi
 
 #
