@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1992, 1993, 1995, 1999, 2000, 2001 Peter Miller;
+#	Copyright (C) 1992, 1993, 1995 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 # MANIFEST: command used to notify by email that a change has passed review
 #
 # Suggested project attribute:
-# review_pass_notify_command = "$datadir/rp.sh $p $c $developer $reviewer";
+# review_pass_notify_command = "$lib/rp.sh $p $c $developer $reviewer";
 #
 aegis=aegis
 case $# in
@@ -70,14 +70,13 @@ if [ $? -ne 0 ]; then quit; fi
 #
 # include full details of the change
 #
-$aegis -list change_details -project $project -change $change -verbose \
-	-pl=66 -pw=80 >> $tmp
+$aegis -list change_details -project $project -change $change -verbose >> $tmp
 if [ $? -ne 0 ]; then quit; fi
 
 #
 # mail it to the developer and all integrators
 #
-mail -s "Project $project: Change $change: passed review" $developer $integrators < $tmp
+mail $developer $integrators < $tmp
 if [ $? -ne 0 ]; then quit; fi
 
 #
