@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1992, 1993, 1995, 1999, 2001 Peter Miller;
+#	Copyright (C) 1992, 1993, 1995 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 # MANIFEST: command used to notify by usenet that a change review passed is rescinded
 #
 # Suggested project attribute:
-# review_pass_undonotify_command = "$datadir/rpu.inews.sh $p $c a.local.newsgroup";
+# review_pass_undonotify_command = "$lib/rpu.inews.sh $p $c a.local.newsgroup";
 #
 aegis=aegis
 case $# in
@@ -61,8 +61,7 @@ if [ $? -ne 0 ]; then quit; fi
 #
 # include full details of the change
 #
-$aegis -list change_details -project $project -change $change -verbose \
-	-pl=66 -pw=80 >> $tmp
+$aegis -list change_details -project $project -change $change -verbose >> $tmp
 if [ $? -ne 0 ]; then quit; fi
 
 #
