@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-1999, 2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions to lock aegis' data
  */
 
-#include <ac/errno.h>
+#include <errno.h>
 #include <ac/fcntl.h>
 #include <ac/stdio.h>
 #include <ac/unistd.h>
@@ -38,13 +38,6 @@
 #include <trace.h>
 #include <user.h>
 
-/*
- * Define this symbol if you want the lock poriority scheme, so
- * that integrate pass has a guarantee of succeeeding eventually.
- * (Without it, aeipass can be blocked indefinitely by rolling builds
- * by multiple developers.)
- */
-#define LOCK_PRIORITY_SCHEME
 
 /*
  * how many bits of the hash to use in the mux
@@ -63,7 +56,6 @@ typedef enum lock_ty lock_ty;
 
 enum lock_mux_ty
 {
-	lock_mux_baseline_priority,
 	lock_mux_ustate,
 	lock_mux_pstate,
 	lock_mux_cstate,
@@ -78,7 +70,6 @@ typedef struct lock_place_ty lock_place_ty;
 struct lock_place_ty
 {
 	struct flock	location;
-	int		release_immediately;
 	lock_callback_ty callback;
 	void		*callback_arg;
 };
@@ -91,14 +82,6 @@ static	int		fd = -1;
 static	long		magic;
 static	int	 	quitregd;
 
-/*
- * Values for the lock_prepare::exclusive argument
- */
-#define LOCK_PREP_SHARED    0
-#define LOCK_PREP_EXCLUSIVE 1
-#define LOCK_PREP_PRIORITY  2
-#define LOCK_PREP_EXCL_PRIO (LOCK_PREP_EXCLUSIVE | LOCK_PREP_PRIORITY)
-
 
 static void flock_construct _((struct flock *, int type, long start,
 	long length));
@@ -167,14 +150,7 @@ lock_prepare(start, length, exclusive, callback, arg)
 		start, length, exclusive));
 	assert(start > lock_master);
 	assert(length > 0);
-	flock_construct
-	(
-		&p.location,
-		((exclusive & LOCK_PREP_EXCLUSIVE) ? F_WRLCK : F_RDLCK),
-		start,
-		length
-	);
-	p.release_immediately = (exclusive & LOCK_PREP_PRIORITY);
+	flock_construct(&p.location, (exclusive ? F_WRLCK : F_RDLCK), start, length);
 	p.callback = callback;
 	p.callback_arg = arg;
 
@@ -279,14 +255,7 @@ lock_prepare_pstate(s, callback, arg)
 	void		*arg;
 {
 	trace(("lock_prepare_pstate(s = \"%s\")\n{\n"/*}*/, s->str_text));
-	lock_prepare_mux
-	(
-		lock_mux_pstate,
-		(long)s->str_hash,
-		LOCK_PREP_EXCLUSIVE,
-		callback,
-		arg
-	);
+	lock_prepare_mux(lock_mux_pstate, (long)s->str_hash, 1, callback, arg);
 	trace((/*{*/"}\n"));
 }
 
@@ -298,21 +267,11 @@ lock_prepare_baseline_read(s, callback, arg)
 	void		*arg;
 {
 	trace(("lock_prepare_pstate(s = \"%s\")\n{\n"/*}*/, s->str_text));
-#ifdef LOCK_PRIORITY_SCHEME
-	lock_prepare_mux
-	(
-		lock_mux_baseline_priority,
-		(long)s->str_hash,
-		LOCK_PREP_EXCL_PRIO,
-		callback,
-		arg
-	);
-#endif
 	lock_prepare_mux
 	(
 		lock_mux_baseline,
 		(long)s->str_hash,
-		LOCK_PREP_SHARED,
+		0,
 		callback,
 		arg
 	);
@@ -327,21 +286,11 @@ lock_prepare_baseline_write(s, callback, arg)
 	void		*arg;
 {
 	trace(("lock_prepare_pstate(s = \"%s\")\n{\n"/*}*/, s->str_text));
-#ifdef LOCK_PRIORITY_SCHEME
-	lock_prepare_mux
-	(
-		lock_mux_baseline_priority,
-		(long)s->str_hash,
-		LOCK_PREP_EXCLUSIVE,
-		callback,
-		arg
-	);
-#endif
 	lock_prepare_mux
 	(
 		lock_mux_baseline,
 		(long)s->str_hash,
-		LOCK_PREP_EXCLUSIVE,
+		1,
 		callback,
 		arg
 	);
@@ -360,7 +309,7 @@ lock_prepare_history(s, callback, arg)
 	(
 		lock_mux_history,
 		(long)s->str_hash,
-		LOCK_PREP_EXCLUSIVE,
+		1,
 		callback,
 		arg
 	);
@@ -379,7 +328,7 @@ lock_prepare_ustate(uid, callback, arg)
 	(
 		lock_mux_ustate,
 		(long)uid,
-		LOCK_PREP_EXCLUSIVE,
+		1,
 		callback,
 		arg
 	);
@@ -393,13 +342,7 @@ lock_prepare_ustate_all(callback, arg)
 	void		*arg;
 {
 	trace(("lock_prepare_ustate_all()\n{\n"/*}*/));
-	lock_prepare_mux_all
-	(
-		lock_mux_ustate,
-		LOCK_PREP_EXCLUSIVE,
-		callback,
-		arg
-	);
+	lock_prepare_mux_all(lock_mux_ustate, 1, callback, arg);
 	trace((/*{*/"}\n"));
 }
 
@@ -417,7 +360,7 @@ lock_prepare_cstate(project_name, change_number, callback, arg)
 	(
 		lock_mux_cstate,
 		change_number + project_name->str_hash,
-		LOCK_PREP_EXCLUSIVE,
+		1,
 		callback,
 		arg
 	);
@@ -505,9 +448,6 @@ lock_description(p)
 	}
 	switch ((p->l_start >> BITS) - 1)
 	{
-	case lock_mux_baseline_priority:
-		return "baseline priority";
-
 	case lock_mux_ustate:
 		return "user";
 
@@ -574,18 +514,14 @@ lock_take()
 	wait_for_locks = user_lock_wait(0);
 
 	gonzo_become();
-#ifdef __CYGWIN__
-	fd = glue_open(path->str_text, O_RDWR | O_CREAT | O_TRUNC, 0666);
-#else
 	fd = glue_open(path->str_text, O_RDWR | O_CREAT | O_TRUNC, 0600);
-#endif
 	if (fd < 0)
 	{
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("open $filename: $errno"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -603,7 +539,7 @@ lock_take()
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("fcntl(\"$filename\", F_GETFD): $errno"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -615,8 +551,8 @@ lock_take()
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_long(scp, "Argument", flags);
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "%d", flags);
 		fatal_intl(scp, i18n("fcntl(\"$filename\", F_SETFD, $arg): $errno"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -660,8 +596,8 @@ lock_take()
 				os_interrupt_cope();
 			scp = sub_context_new();
 			sub_errno_set(scp);
-			sub_var_set_string(scp, "File_Name", path);
-			sub_var_set_charstar(scp, "Argument", flock_string(&p));
+			sub_var_set(scp, "File_Name", "%S", path);
+			sub_var_set(scp, "Argument", "%s", flock_string(&p));
 			fatal_intl
 			(
 				scp,
@@ -686,8 +622,8 @@ lock_take()
 
 					scp = sub_context_new();
 					sub_errno_set(scp);
-					sub_var_set_string(scp, "File_Name", path);
-					sub_var_set_charstar(scp, "Argument", flock_string(&p));
+					sub_var_set(scp, "File_Name", "%S", path);
+					sub_var_set(scp, "Argument", "%s", flock_string(&p));
 					fatal_intl
 					(
 						scp,
@@ -713,8 +649,8 @@ lock_take()
 
 				scp = sub_context_new();
 				sub_errno_set(scp);
-				sub_var_set_string(scp, "File_Name", path);
-				sub_var_set_charstar(scp, "Argument", flock_string(&p));
+				sub_var_set(scp, "File_Name", "%S", path);
+				sub_var_set(scp, "Argument", "%s", flock_string(&p));
 				fatal_intl
 				(
 					scp,
@@ -723,45 +659,6 @@ lock_take()
 				/* NOTREACHED */
 				sub_context_delete(scp);
 			}
-
-			/*
-			 * Unlock any of the "release immediately" locks.
-			 * (These are used to gain a modicum of fairness.)
-			 */
-			for (j = 0; j < nplaces; ++j)
-			{
-				if (!place[j].release_immediately)
-					continue;
-				trace(("mark\n"));
-				p = place[j].location; /* yes, copy it */
-				p.l_type = F_UNLCK;
-				if (glue_fcntl(fd, F_SETLKW, &p))
-				{
-					sub_context_ty	*scp;
-	
-					scp = sub_context_new();
-					sub_errno_set(scp);
-					sub_var_set_string
-					(
-						scp,
-						"File_Name",
-						path
-					);
-					sub_var_set_charstar
-					(
-						scp,
-						"Argument",
-						flock_string(&p)
-					);
-					fatal_intl
-					(
-						scp,
-			    i18n("fcntl(\"$filename\", F_SETLKW, $arg): $errno")
-					);
-					/* NOTREACHED */
-					sub_context_delete(scp);
-				}
-			}
 			break;
 		}
 
@@ -776,8 +673,8 @@ lock_take()
 
 			scp = sub_context_new();
 			sub_errno_set(scp);
-			sub_var_set_string(scp, "File_Name", path);
-			sub_var_set_charstar(scp, "Argument", flock_string(&p));
+			sub_var_set(scp, "File_Name", "%S", path);
+			sub_var_set(scp, "Argument", "%s", flock_string(&p));
 			fatal_intl
 			(
 				scp,
@@ -804,7 +701,7 @@ lock_take()
 				scp = sub_context_new();
 
 				/* should never be reached */
-				sub_var_set_charstar(scp, "Name", lock_description(&p));
+				sub_var_set(scp, "Name", "%s", lock_description(&p));
 				fatal_intl(scp, i18n("$name lock not available"));
 				sub_context_delete(scp);
 			}
@@ -815,7 +712,7 @@ lock_take()
 
 			scp = sub_context_new();
 			p = place[j].location; /* yes, copy it */
-			sub_var_set_charstar(scp, "Name", lock_description(&p));
+			sub_var_set(scp, "Name", "%s", lock_description(&p));
 			if (wait_for_locks)
 				verbose_intl(scp, i18n("waiting for $name lock"));
 			else
@@ -839,46 +736,6 @@ lock_take()
 		/*
 		 * block on the lock that stopped us before
 		 */
-		if (j > 0 && place[j-1].release_immediately)
-		{
-			/*
-			 * If the lock is preceeded by a priority lock,
-			 * take that too, to stop them getting through.
-			 * We can probably get it without waiting,
-			 * because we already got it once before.
-			 */
-			trace(("mark\n"));
-			p = place[j-1].location; /* yes, copy it */
-			if (glue_fcntl(fd, F_SETLKW, &p))
-			{
-				sub_context_ty	*scp;
-	
-				if (errno == EINTR)
-					os_interrupt_cope();
-				scp = sub_context_new();
-				sub_errno_set(scp);
-				sub_var_set_string
-				(
-					scp,
-					"File_Name",
-					path
-				);
-				sub_var_set_charstar
-				(
-					scp,
-					"Argument",
-					flock_string(&p)
-				);
-				fatal_intl
-				(
-					scp,
-			    i18n("fcntl(\"$filename\", F_SETLKW, $arg): $errno")
-				);
-				/* NOTREACHED */
-				sub_context_delete(scp);
-			}
-		}
-		trace(("mark\n"));
 		p = place[j].location; /* yes, copy it */
 		if (glue_fcntl(fd, F_SETLKW, &p))
 		{
@@ -888,8 +745,8 @@ lock_take()
 				os_interrupt_cope();
 			scp = sub_context_new();
 			sub_errno_set(scp);
-			sub_var_set_string(scp, "File_Name", path);
-			sub_var_set_charstar(scp, "Argument", flock_string(&p));
+			sub_var_set(scp, "File_Name", "%S", path);
+			sub_var_set(scp, "Argument", "%s", flock_string(&p));
 			fatal_intl
 			(
 				scp,
@@ -903,15 +760,16 @@ lock_take()
 		 * and then release it,
 		 * before trying all over again.
 		 */
-		flock_construct(&p, F_UNLCK, 0L, 0x7FFFFFFF);
+		p = place[j].location; /* yes, copy it */
+		p.l_type = F_UNLCK;
 		if (glue_fcntl(fd, F_SETLKW, &p))
 		{
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
 			sub_errno_set(scp);
-			sub_var_set_string(scp, "File_Name", path);
-			sub_var_set_charstar(scp, "Argument", flock_string(&p));
+			sub_var_set(scp, "File_Name", "%S", path);
+			sub_var_set(scp, "Argument", "%s", flock_string(&p));
 			fatal_intl
 			(
 				scp,
@@ -933,7 +791,6 @@ lock_release()
 {
 	struct flock	p;
 	int		fildes;
-	int		err;
 
 	/*
 	 * set the file descriptor to -1
@@ -957,27 +814,14 @@ lock_release()
 	 * but some operating systems hang onto them if we don't.
 	 */
 	flock_construct(&p, F_UNLCK, 0L, 0x7FFFFFFF);
-	err = glue_fcntl(fildes, F_SETLKW, &p);
-#ifdef __CYGWIN__
-	if (err && errno == EACCES)
-	{
-		/*
-		 * For some reason Cygwin gives an error if you attempt
-		 * to release all locks when you have no locks taken.
-		 * Unix implementations, on the other hand, simply
-		 * return success.
-		 */
-		err = 0;
-	}
-#endif
-	if (err)
+	if (glue_fcntl(fildes, F_SETLKW, &p))
 	{
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_charstar(scp, "Argument", flock_string(&p));
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "%s", flock_string(&p));
 		fatal_intl
 		(
 			scp,
@@ -994,7 +838,6 @@ lock_release()
 	glue_close(fildes);
 	gonzo_become_undo();
 	nplaces = 0;
-	nplaces_max = 0;
 	mem_free((char *)place);
 	place = 0;
 	trace((/*{*/"}\n"));
@@ -1035,8 +878,8 @@ lock_walk_hunt(min, max, callback)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_charstar(scp, "Argument", flock_string(&flock));
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "%s", flock_string(&flock));
 		fatal_intl(scp, i18n("fcntl(\"$filename\", F_GETLK, $arg): $errno"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -1099,11 +942,6 @@ lock_walk_hunt(min, max, callback)
 				found.subset = found.address & BITS_MASK;
 				break;
 
-			case lock_mux_baseline_priority:
-				found.name = lock_walk_name_baseline_priority;
-				found.subset = found.address & BITS_MASK;
-				break;
-
 			case lock_mux_baseline:
 				found.name = lock_walk_name_baseline;
 				found.subset = found.address & BITS_MASK;
@@ -1203,7 +1041,7 @@ lock_walk(callback)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("open $filename: $errno"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -1220,7 +1058,7 @@ lock_walk(callback)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("fcntl(\"$filename\", F_GETFD): $errno"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -1232,8 +1070,8 @@ lock_walk(callback)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_long(scp, "Argument", flags);
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "%s", flags);
 		fatal_intl(scp, i18n("fcntl(\"$filename\", F_SETFD, $arg): $errno"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
