@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
  */
 
 #include <ac/stdlib.h>
-#include <ac/errno.h>
+#include <errno.h>
 #include <ac/stdio.h>
 #include <ac/string.h>
 #include <ac/limits.h>
@@ -79,7 +79,7 @@ interrupt(n)
 		return;
 	interrupted = 1;
 	scp = sub_context_new();
-	sub_var_set_charstar(scp, "Signal", strsignal(n));
+	sub_var_set(scp, "Signal", "%s", strsignal(n));
 	fatal_intl(scp, i18n("interrupted by $signal"));
 	/* NOTREACHED */
 	sub_context_delete(scp);
@@ -152,7 +152,7 @@ os_waitpid_status(child, cmd)
 		 * since we didn't do it, treat it as an error
 		 */
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Command", cmd);
+		sub_var_set(scp, "Command", "%s", cmd);
 		fatal_intl(scp, i18n("command \"$command\" stopped"));
 		/* NOTREACHED */
 
@@ -166,8 +166,8 @@ os_waitpid_status(child, cmd)
 		 * process dies from unhandled condition
 		 */
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Command", cmd);
-		sub_var_set_charstar(scp, "Signal", strsignal(c));
+		sub_var_set(scp, "Command", "%s", cmd);
+		sub_var_set(scp, "Signal", "%s", strsignal(c));
 		if (!b)
 			fatal_intl(scp, i18n("command \"$command\" terminated by $signal"));
 		else
@@ -204,7 +204,7 @@ os_exists(path)
 
 			scp = sub_context_new();
 			sub_errno_set(scp);
-			sub_var_set_string(scp, "File_Name", path);
+			sub_var_set(scp, "File_Name", "%S", path);
 			fatal_intl(scp, i18n("stat $filename: $errno"));
 			/* NOTREACHED */
 		}
@@ -232,8 +232,8 @@ os_mkdir(path, mode)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_format(scp, "Argument", "0%o", mode);
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "0%o", mode);
 		fatal_intl(scp, i18n("mkdir(\"$filename\", $arg): $errno"));
 		/* NOTREACHED */
 	}
@@ -250,8 +250,8 @@ os_mkdir(path, mode)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_long(scp, "Argument", gid);
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "%d", gid);
 		fatal_intl(scp, i18n("chgrp(\"$filename\", $arg): $errno"));
 		/* NOTREACHED */
 	}
@@ -268,8 +268,8 @@ os_mkdir(path, mode)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_format(scp, "Argument", "0$o", mode);
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "0$o", mode);
 		fatal_intl(scp, i18n("chmod(\"$filename\", $arg): $errno"));
 		/* NOTREACHED */
 	}
@@ -289,7 +289,7 @@ os_rmdir(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("rmdir $filename: $errno"));
 		/* NOTREACHED */
 	}
@@ -309,7 +309,7 @@ os_rmdir_errok(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		error_intl(scp, i18n("warning: rmdir $filename: $errno"));
 		sub_context_delete(scp);
 	}
@@ -329,7 +329,7 @@ os_rmdir_bg(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		error_intl(scp, i18n("warning: rmdir $filename: $errno"));
 		sub_context_delete(scp);
 	}
@@ -349,7 +349,7 @@ os_rmdir_tree(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		error_intl(scp, i18n("warning: rmdir $filename: $errno"));
 		sub_context_delete(scp);
 	}
@@ -357,6 +357,42 @@ os_rmdir_tree(path)
 }
 
 
+void
+os_mkdir_between(top, extn, mode)
+	string_ty	*top;
+	string_ty	*extn;
+	int		mode;
+{
+	char		*cp;
+	string_ty	*s1;
+	string_ty	*s2;
+
+	trace(("os_mkdir_between(top = %08lX, extn = %08lX, \
+mode = 0%o)\n{\n"/*}*/, top, extn, mode));
+	trace_string(top->str_text);
+	trace_string(extn->str_text);
+	assert(top->str_text[0] == '/');
+	assert(extn->str_text[0] != '/');
+	assert(extn->str_text[extn->str_length - 1] != '/');
+	assert(extn->str_length);
+	for (cp = extn->str_text; *cp; ++cp)
+	{
+		if (*cp != '/')
+			continue;
+		s1 = str_n_from_c(extn->str_text, cp - extn->str_text);
+		s2 = str_format("%S/%S", top, s1);
+		if (!os_exists(s2))
+		{
+			os_mkdir(s2, mode);
+			undo_rmdir_errok(s2);
+		}
+		str_free(s1);
+		str_free(s2);
+	}
+	trace((/*{*/"}\n"));
+}
+
+
 void
 os_rename(a, b)
 	string_ty	*a;
@@ -372,8 +408,8 @@ os_rename(a, b)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name1", a);
-		sub_var_set_string(scp, "File_Name2", b);
+		sub_var_set(scp, "File_Name1", "%S", a);
+		sub_var_set(scp, "File_Name2", "%S", b);
 		fatal_intl(scp, i18n("rename(\"$filename1\", \"$filename2\"): $errno"));
 		/* NOTREACHED */
 	}
@@ -413,7 +449,7 @@ os_unlink(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("stat $filename: $errno"));
 		/* NOTREACHED */
 	}
@@ -423,7 +459,7 @@ os_unlink(path)
 
 		scp = sub_context_new();
 		sub_errno_setx(scp, EISDIR);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("unlink $filename: $errno"));
 		/* NOTREACHED */
 	}
@@ -433,7 +469,7 @@ os_unlink(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("unlink $filename: $errno"));
 		/* NOTREACHED */
 	}
@@ -473,7 +509,7 @@ os_unlink_errok(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		if (errno != ENOENT && errno != ENOTDIR)
 			fatal_intl(scp, i18n("stat $filename: $errno"));
 		error_intl(scp, i18n("warning: stat $filename: $errno"));
@@ -485,7 +521,7 @@ os_unlink_errok(path)
 
 		scp = sub_context_new();
 		sub_errno_setx(scp, EISDIR);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		error_intl(scp, i18n("warning: unlink $filename: $errno"));
 		sub_context_delete(scp);
 	}
@@ -495,7 +531,7 @@ os_unlink_errok(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		error_intl(scp, i18n("warning: unlink $filename: $errno"));
 		sub_context_delete(scp);
 	}
@@ -503,6 +539,337 @@ os_unlink_errok(path)
 }
 
 
+/*
+ * NAME
+ *	os_curdir_sub - get current directory
+ *
+ * SYNOPSIS
+ *	string_ty *os_curdir_sub(void);
+ *
+ * DESCRIPTION
+ *	The os_curdir_sub function is used to determine the system's idea
+ *	of the current directory.
+ *
+ * RETURNS
+ *	A pointer to a string in dynamic memory is returned.
+ *	A null pointer is returned on error.
+ *
+ * CAVEAT
+ *	DO NOT use str_free() on the value returned.
+ */
+
+static string_ty *os_curdir_sub _((void));
+
+static string_ty *
+os_curdir_sub()
+{
+	static string_ty	*s;
+
+	os_become_must_be_active();
+	if (!s)
+	{
+		char	buffer[2000];
+
+		if (!glue_getcwd(buffer, sizeof(buffer)))
+		{
+			sub_context_ty	*scp;
+
+			scp = sub_context_new();
+			sub_errno_set(scp);
+			fatal_intl(scp, i18n("getcwd: $errno"));
+			/* NOTREACHED */
+		}
+		assert(buffer[0] == '/');
+		s = str_from_c(buffer);
+	}
+	return s;
+}
+
+
+/*
+ * NAME
+ *	os_curdir - full current directory path
+ *
+ * SYNOPSIS
+ *	string_ty *os_curdir(void);
+ *
+ * DESCRIPTION
+ *	Os_curdir is used to determine the pathname
+ *	of the current directory.  Automounter vaguaries will be elided.
+ *
+ * RETURNS
+ *	A pointer to a string in dynamic memory is returned.
+ *	A null pointer is returned on error.
+ *
+ * CAVEAT
+ *	Use str_free() when you are done with the value returned.
+ */
+
+string_ty *
+os_curdir()
+{
+	static string_ty	*result;
+
+	os_become_must_be_active();
+	if (!result)
+	{
+		string_ty	*dot;
+		
+		dot = str_from_c(".");
+		result = os_pathname(dot, 1);
+		str_free(dot);
+	}
+	return str_copy(result);
+}
+
+
+/*
+ * NAME
+ *	os_pathname - determine full file name
+ *
+ * SYNOPSIS
+ *	string_ty *os_pathname(string_ty *path, int resolve);
+ *
+ * DESCRIPTION
+ *	Os_pathname is used to determine the full path name
+ *	of a partial path given.
+ *
+ * ARGUMENTS
+ *	path	- path to canonicalize
+ *	resolve	- non-zero if should resolve symlinks, 0 if not
+ *
+ * RETURNS
+ *	pointer to dynamically allocated string.
+ *
+ * CAVEAT
+ *	Use str_free() when you are done with the value returned.
+ */
+
+string_ty *
+os_pathname(path, resolve)
+	string_ty	*path;
+	int		resolve;
+{
+	static char	*tmp;
+	static size_t	tmplen;
+	static size_t	ipos;
+	static size_t	opos;
+	int		c;
+	int		found;
+#ifdef S_IFLNK
+	int		loop;
+#endif
+
+	/*
+	 * Change relative pathnames to absolute
+	 */
+	trace(("os_pathname(path = %08lX)\n{\n"/*}*/, path));
+	if (!path)
+		path = os_curdir();
+	if (resolve)
+		os_become_must_be_active();
+	trace_string(path->str_text);
+	if (path->str_text[0] != '/')
+		path = str_format("%S/%S", os_curdir_sub(), path);
+	else
+		path = str_copy(path);
+	if (!tmp)
+	{
+		tmplen = 200;
+		tmp = mem_alloc(tmplen);
+	}
+
+	/*
+	 * Take kinks out of the pathname
+	 */
+	ipos = 0;
+	opos = 0;
+	found = 0;
+#ifdef S_IFLNK
+	loop = 0;
+#endif
+	while (!found)
+	{
+		/*
+		 * get the next character
+		 */
+		c = path->str_text[ipos];
+		if (c)
+			ipos++;
+		else
+		{
+			found = 1;
+			c = '/';
+		}
+
+		/*
+		 * remember the normal characters
+		 * until get to slash
+		 */
+		if (c != '/')
+			goto remember;
+
+		/*
+		 * leave root alone
+		 */
+		if (!opos)
+			goto remember;
+
+		/*
+		 * "/.." -> "/"
+		 */
+		if (opos == 3 && tmp[1] == '.' && tmp[2] == '.')
+		{
+			opos = 1;
+			continue;
+		}
+
+		/*
+		 * "a//" -> "a/"
+		 */
+		if (tmp[opos - 1] == '/')
+			continue;
+
+		/*
+		 * "a/./" -> "a/"
+		 */
+		if (opos >= 2 && tmp[opos - 1] == '.' && tmp[opos - 2] == '/')
+		{
+			opos--;
+			continue;
+		}
+
+		/*
+		 * "a/b/../" -> "a/"
+		 */
+		if
+		(
+			opos > 3
+		&&
+			tmp[opos - 1] == '.'
+		&&
+			tmp[opos - 2] == '.'
+		&&
+			tmp[opos - 3] == '/'
+		)
+		{
+			opos -= 4;
+			assert(opos > 0);
+			while (tmp[opos - 1] != '/')
+				opos--;
+			continue;
+		}
+
+		/*
+		 * see if the path so far is a symbolic link
+		 */
+#ifdef S_IFLNK
+		if (resolve)
+		{
+			char		pointer[2000];
+			int		nbytes;
+			string_ty	*s;
+
+			s = str_n_from_c(tmp, opos);
+			nbytes = glue_readlink(s->str_text, pointer, sizeof(pointer) - 1);
+			if (nbytes < 0)
+			{
+				/*
+				 * probably not a symbolic link
+				 */
+				if
+				(
+					errno != ENXIO
+				&&
+					errno != EINVAL
+				&& 
+					errno != ENOENT
+				&& 
+					errno != ENOTDIR
+				)
+				{
+					sub_context_ty	*scp;
+
+					scp = sub_context_new();
+					sub_errno_set(scp);
+					sub_var_set(scp, "File_Name", "%S", s);
+					fatal_intl(scp, i18n("readlink $filename: $errno"));
+					/* NOTREACHED */
+				}
+				str_free(s);
+			}
+			else
+			{
+				string_ty	*newpath;
+	
+				if (nbytes == 0)
+				{
+					pointer[0] = '.';
+					nbytes = 1;
+				}
+				if (++loop > 1000)
+				{
+					sub_context_ty	*scp;
+
+					scp = sub_context_new();
+					sub_errno_setx(scp, ELOOP);
+					sub_var_set(scp, "File_Name", "%S", s);
+					fatal_intl(scp, i18n("readlink $filename: $errno"));
+					/* NOTREACHED */
+				}
+				pointer[nbytes] = 0;
+	
+				str_free(s);
+				if (pointer[0] == '/')
+					tmp[1] = 0;
+				else
+				{
+					while (tmp[opos - 1] != '/')
+						opos--;
+					tmp[opos] = 0;
+				}
+				newpath =
+					str_format
+					(
+						"%s/%s/%s",
+						tmp,
+						pointer,
+						path->str_text + ipos
+					);
+				str_free(path);
+				path = newpath;
+				ipos = 0;
+				opos = 0;
+				found = 0;
+				continue;
+			}
+		}
+#endif
+	
+		/*
+		 * keep the slash
+		 */
+		remember:
+		if (opos >= tmplen)
+		{
+			tmplen += 100;
+			tmp = mem_change_size(tmp, tmplen);
+		}
+		tmp[opos++] = c;
+	}
+	str_free(path);
+	assert(opos >= 1);
+	assert(tmp[0] == '/');
+	assert(tmp[opos - 1] == '/');
+	if (opos >= 2)
+		opos--;
+	path = str_n_from_c(tmp, opos);
+	trace_string(path->str_text);
+	trace((/*{*/"}\n"));
+	return path;
+}
+
+
 /*
  * NAME
  *	os_entryname - take path apart
@@ -543,6 +910,49 @@ os_entryname(path)
 }
 
 
+/*
+ * NAME
+ *	os_dirname - take path apart
+ *
+ * SYNOPSIS
+ *	string_ty *os_dirname(string_ty *path);
+ *
+ * DESCRIPTION
+ *	Os_dirname is used to extract the directory part
+ *	of a pathname.
+ *
+ * RETURNS
+ *	pointer to dynamically allocated string.
+ *
+ * CAVEAT
+ *	Use str_free() when you are done with the value returned.
+ */
+
+string_ty *
+os_dirname(path)
+	string_ty	*path;
+{
+	string_ty	*s;
+	char		*cp;
+
+	trace(("os_dirname(path = %08lX)\n{\n"/*}*/, path));
+	trace_string(path->str_text);
+	s = os_pathname(path, 1);
+	cp = strrchr(s->str_text, '/');
+	assert(cp);
+	if (cp > s->str_text)
+	{
+		path = str_n_from_c(s->str_text, cp - s->str_text);
+		str_free(s);
+	}
+	else
+		path = s;
+	trace_string(path->str_text);
+	trace((/*{*/"}\n"));
+	return path;
+}
+
+
 string_ty *
 os_below_dir(higher, lower)
 	string_ty	*higher;
@@ -576,7 +986,7 @@ os_chdir(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("chdir $filename: $errno"));
 		/* NOTREACHED */
 	}
@@ -594,7 +1004,7 @@ os_setuid(uid)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_long(scp, "Argument", uid);
+		sub_var_set(scp, "Argument", "%d", uid);
 		fatal_intl(scp, i18n("setuid $arg: $errno"));
 		/* NOTREACHED */
 	}
@@ -614,7 +1024,7 @@ os_setgid(gid)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_long(scp, "Argument", gid);
+		sub_var_set(scp, "Argument", "%d", gid);
 		if (become_testing)
 		{
 			/*
@@ -650,8 +1060,8 @@ os_execute(cmd, flags, dir)
 		else
 			s = str_copy(cmd);
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Command", s);
-		sub_var_set_long(scp, "Number", result);
+		sub_var_set(scp, "Command", "%S", s);
+		sub_var_set(scp, "Number", "%d", result);
 		fatal_intl(scp, i18n("command \"$command\" exit status $number"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -689,7 +1099,7 @@ who_and_where(uid, gid, dir)
 		str_free(last_dir);
 		last_dir = rdir;
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", dir);
+		sub_var_set(scp, "File_Name", "%S", dir);
 		error_intl(scp, i18n("cd $filename"));
 		sub_context_delete(scp);
 	}
@@ -706,16 +1116,16 @@ who_and_where(uid, gid, dir)
 		last_uid = uid;
 		pw = getpwuid(uid);
 		if (pw)
-			sub_var_set_format(scp, "Name1", "\"%s\"", pw->pw_name);
+			sub_var_set(scp, "Name1", "\"%s\"", pw->pw_name);
 		else
-			sub_var_set_long(scp, "Name1", uid);
+			sub_var_set(scp, "Name1", "%d", uid);
 
 		last_gid = gid;
 		gr = getgrgid(gid);
 		if (gr)
-			sub_var_set_format(scp, "Name2", "\"%s\"", gr->gr_name);
+			sub_var_set(scp, "Name2", "\"%s\"", gr->gr_name);
 		else
-			sub_var_set_long(scp, "Name2", gid);
+			sub_var_set(scp, "Name2", "%d", gid);
 		error_intl(scp, i18n("user $name1, group $name2"));
 		sub_context_delete(scp);
 	}
@@ -808,7 +1218,7 @@ os_execute_retcode(cmd, flags, dir)
 		 * let the log file (user) know what we did
 		 */
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Message", cmd);
+		sub_var_set(scp, "Message", "%S", cmd);
 		error_intl(scp, "$message");
 		sub_context_delete(scp);
 
@@ -819,15 +1229,15 @@ os_execute_retcode(cmd, flags, dir)
 		execl(shell, shell, "-ec", cmd->str_text, (char *)0);
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_charstar(scp, "File_Name", shell);
+		sub_var_set(scp, "File_Name", "%s", shell);
 		fatal_intl(scp, i18n("exec \"$filename\": $errno"));
 		/* NOTREACHED */
 	}
 	if (result && (flags & OS_EXEC_FLAG_ERROK))
 	{
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Command", cmd);
-		sub_var_set_long(scp, "Number", result);
+		sub_var_set(scp, "Command", "%S", cmd);
+		sub_var_set(scp, "Number", "%d", result);
 		error_intl(scp, i18n("warning: command \"$command\" exit status $number"));
 		sub_context_delete(scp);
 		result = 0;
@@ -863,18 +1273,11 @@ os_mtime_range(path, oldest_p, newest_p)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("stat $filename: $errno"));
 		/* NOTREACHED */
 	}
 
-	/*
-	 * This is a bit tacky.  The codafs leaves the ctime at 0
-	 * until a stat change is made.  Compensate for this.
-	 */
-	if (st.st_ctime == 0)
-		st.st_ctime = st.st_mtime;
-
 	/*
 	 * Return the last modified time.
 	 * They may try to fake us out by using utime,
@@ -886,46 +1289,12 @@ os_mtime_range(path, oldest_p, newest_p)
 }
 
 
-time_t
-os_mtime_actual(path)
-	string_ty	*path;
-{
-	struct stat	st;
-	int		oret;
-
-	trace(("os_mtime_actual(path = %08lX)\n{\n"/*}*/, path));
-	os_become_must_be_active();
-	trace_string(path->str_text);
-
-#ifdef S_IFLNK
-	oret = glue_lstat(path->str_text, &st);
-#else
-	oret = glue_stat(path->str_text, &st);
-#endif
-	if (oret)
-	{
-		sub_context_ty	*scp;
-
-		scp = sub_context_new();
-		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		fatal_intl(scp, i18n("stat $filename: $errno"));
-		/* NOTREACHED */
-	}
-
-	trace(("return %ld;\n", (long)st.st_mtime));
-	trace((/*{*/"}\n"));
-	return st.st_mtime;
-}
-
-
 void
 os_mtime_set(path, when)
 	string_ty	*path;
 	time_t		when;
 {
 	struct utimbuf	utb;
-	int		err;
 
 	trace(("os_mtime_set(path = %08lX, when = %ld)\n{\n"/*}*/, path, when));
 	os_become_must_be_active();
@@ -933,18 +1302,13 @@ os_mtime_set(path, when)
 	trace(("when = %s", ctime(&when)));
 	utb.actime = when;
 	utb.modtime = when;
-	err = glue_utime(path->str_text, &utb);
-#ifdef __CYGWIN__
-	if (err && errno == EACCES)
-		err = 0;
-#endif
-	if (err)
+	if (glue_utime(path->str_text, &utb))
 	{
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("utime $filename: $errno"));
 		/* NOTREACHED */
 	}
@@ -971,7 +1335,7 @@ os_mtime_set_errok(path, when)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		error_intl(scp, i18n("warning: utime $filename: $errno"));
 		sub_context_delete(scp);
 	}
@@ -1004,18 +1368,18 @@ os_chown_check(path, mode, uid, gid)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("stat $filename: $errno"));
 		/* NOTREACHED */
 	}
-	if (mode > 0 && (st.st_mode & 07777) != mode)
+	if ((st.st_mode & 07777) != mode)
 	{
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_format(scp, "Number1", "%5.5o", st.st_mode & 07777);
-		sub_var_set_format(scp, "Number2", "%5.5o", mode);
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Number1", "%5.5o", st.st_mode & 07777);
+		sub_var_set(scp, "Number2", "%5.5o", mode);
 		error_intl
 		(
 			scp,
@@ -1035,9 +1399,9 @@ os_chown_check(path, mode, uid, gid)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", path);
-			sub_var_set_long(scp, "Number1", st.st_uid);
-			sub_var_set_long(scp, "Number2", geteuid());
+			sub_var_set(scp, "File_Name", "%S", path);
+			sub_var_set(scp, "Number1", "%d", st.st_uid);
+			sub_var_set(scp, "Number2", "%d", geteuid());
 			error_intl
 			(
 				scp,
@@ -1058,9 +1422,9 @@ os_chown_check(path, mode, uid, gid)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", path);
-			sub_var_set_long(scp, "Number1", st.st_uid);
-			sub_var_set_long(scp, "Number2", uid);
+			sub_var_set(scp, "File_Name", "%S", path);
+			sub_var_set(scp, "Number1", "%d", st.st_uid);
+			sub_var_set(scp, "Number2", "%d", uid);
 			error_intl
 			(
 				scp,
@@ -1074,9 +1438,9 @@ os_chown_check(path, mode, uid, gid)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", path);
-			sub_var_set_long(scp, "Number1", st.st_gid);
-			sub_var_set_long(scp, "Number2", gid);
+			sub_var_set(scp, "File_Name", "%S", path);
+			sub_var_set(scp, "Number1", "%d", st.st_gid);
+			sub_var_set(scp, "Number2", "%d", gid);
 			error_intl
 			(
 				scp,
@@ -1099,7 +1463,7 @@ os_chown_check(path, mode, uid, gid)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("$filename: has been tampered with (fatal)"));
 		/* NOTREACHED */
 	}
@@ -1122,8 +1486,8 @@ os_chmod(path, mode)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_format(scp, "Argument", "%5.5o", mode);
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "%5.5o", mode);
 		fatal_intl(scp, i18n("chmod(\"$filename\", $arg): $errno"));
 		/* NOTREACHED */
 	}
@@ -1152,7 +1516,7 @@ os_chmod_query(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("stat $filename: $errno"));
 		/* NOTREACHED */
 	}
@@ -1178,8 +1542,8 @@ os_chmod_errok(path, mode)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
-		sub_var_set_format(scp, "Argument", "%5.5o", mode);
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "%5.5o", mode);
 		error_intl(scp, i18n("warning: chmod(\"$filename\", $arg): $errno"));
 		sub_context_delete(scp);
 	}
@@ -1202,8 +1566,8 @@ os_link(from, to)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name1", from);
-		sub_var_set_string(scp, "File_Name2", to);
+		sub_var_set(scp, "File_Name1", "%S", from);
+		sub_var_set(scp, "File_Name2", "%S", to);
 		fatal_intl(scp, i18n("link(\"$filename1\", \"$filename2\"): $errno"));
 		/* NOTREACHED */
 	}
@@ -1226,7 +1590,7 @@ os_execute_slurp(cmd, flags, dir)
 	s2 = str_format("( %S ) > %S", cmd, s1);
 	os_execute(s2, flags, dir);
 	str_free(s2);
-	s2 = read_whole_file(s1);
+	s2 = read_whole_file(s1->str_text);
 	os_unlink(s1);
 	str_free(s1);
 	trace_string(s2->str_text);
@@ -1243,11 +1607,6 @@ os_become_init()
 	become_orig_umask = umask(DEFAULT_UMASK);
 	become_orig_uid = getuid();
 	become_orig_gid = getgid();
-#ifdef SINGLE_USER
-	become_testing = -1;
-	become_active_uid = become_orig_uid;
-	become_active_gid = become_orig_gid;
-#else
 	if (setuid(0))
 	{
 		become_testing = 1;
@@ -1256,7 +1615,6 @@ os_become_init()
 	}
 	else
 		setgid(0);
-#endif
 	become_inited = 1;
 }
 
@@ -1652,7 +2010,7 @@ os_edit(filename, et)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "Name", "EDITOR");
+			sub_var_set(scp, "Name", "EDITOR");
 			fatal_intl(scp, i18n("environment variable $name not set"));
 			/* NOTREACHED */
 		}
@@ -1686,16 +2044,13 @@ os_edit(filename, et)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name", arglex_token_name(arglex_token_edit));
+		sub_var_set(scp, "Name", "%s", arglex_token_name(arglex_token_edit));
 		fatal_intl(scp, i18n("may not use $name in the background"));
 		/* NOTREACHED */
 	}
 
 	/*
 	 * edit the file
-	 *
-	 * Please note: we ignore the exit status on purpose.
-	 * This is because vi (amongst others) returns a silly exit status.
 	 */
 	cmd = str_format("%s %S", editor, filename);
 	cwd = os_curdir();
@@ -1709,15 +2064,6 @@ os_edit(filename, et)
 string_ty *
 os_edit_new(et)
 	edit_ty		et;
-{
-	return os_edit_string((string_ty *)0, et);
-}
-
-
-string_ty *
-os_edit_string(subject, et)
-	string_ty	*subject;
-	edit_ty		et;
 {
 	string_ty	*filename;
 	string_ty	*result;
@@ -1732,24 +2078,13 @@ os_edit_string(subject, et)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", filename);
+		sub_var_set(scp, "File_Name", "%s", filename);
 		fatal_intl(scp, i18n("open $filename: $errno"));
 		sub_context_delete(scp);
 	}
-	if (subject)
-	{
-		glue_fwrite(subject->str_text, 1, subject->str_length, fp);
-		if
-		(
-			subject->str_length
-		&&
-			subject->str_text[subject->str_length - 1] != '\n'
-		)
-			glue_fputc('\n', fp);
-	}
 	glue_fclose(fp);
 	os_edit(filename, et);
-	result = read_whole_file(filename);
+	result = read_whole_file(filename->str_text);
 	os_unlink(filename);
 	os_become_undo();
 	return result;
@@ -1829,10 +2164,8 @@ pathconf_inner(path, arg)
 #else
 	/*
 	 * This system does not have the pathconf system call.
-	 * (Return EINVAL rather than ENOSYS, because the outer wrapper
-	 * expects EINVAL.)
 	 */
-	errno = EINVAL;
+	errno = ENOSYS;
 	return -1;
 #endif
 }
@@ -1886,7 +2219,7 @@ os_pathconf_path_max(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("pathconf(\"$filename\", {PATH_MAX}): $errno"));
 		/* NOTREACHED */
 	}
@@ -1913,7 +2246,7 @@ os_pathconf_name_max(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("pathconf(\"$filename\", {NAME_MAX}): $errno"));
 		/* NOTREACHED */
 	}
@@ -1935,8 +2268,8 @@ os_symlink(src, dst)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name1", src);
-		sub_var_set_string(scp, "File_Name2", dst);
+		sub_var_set(scp, "File_Name1", "%S", src);
+		sub_var_set(scp, "File_Name2", "%S", dst);
 		fatal_intl(scp, i18n("symlink(\"$filename1\", \"$filename2\"): $errno"));
 		sub_context_delete(scp);
 	}
@@ -1970,7 +2303,7 @@ os_readlink(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("readlink $filename: $errno"));
 		sub_context_delete(scp);
 	}
@@ -2020,6 +2353,36 @@ os_symlink_query(path)
 }
 
 
+void
+os_junkfile(path, mode)
+	string_ty	*path;
+	int		mode;
+{
+	os_become_must_be_active();
+	if (glue_junkfile(path->str_text))
+	{
+		sub_context_ty	*scp;
+
+		scp = sub_context_new();
+		sub_errno_set(scp);
+		sub_var_set(scp, "File_Name", "%S", path);
+		fatal_intl(scp, i18n("junkfile $filename: $errno"));
+		sub_context_delete(scp);
+	}
+	if (glue_chmod(path->str_text, mode))
+	{
+		sub_context_ty	*scp;
+
+		scp = sub_context_new();
+		sub_errno_set(scp);
+		sub_var_set(scp, "File_Name", "%S", path);
+		sub_var_set(scp, "Argument", "%5.5o", mode);
+		fatal_intl(scp, i18n("chmod(\"$filename\", $arg): $errno"));
+		/* NOTREACHED */
+	}
+}
+
+
 /*
  * NAME
  *	os_throttle
@@ -2083,7 +2446,7 @@ os_owner_query(path, uid_p, gid_p)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("stat $filename: $errno"));
 		/* NOTREACHED */
 	}
@@ -2110,7 +2473,7 @@ os_fingerprint(path)
 
 		scp = sub_context_new();
 		sub_errno_set(scp);
-		sub_var_set_string(scp, "File_Name", path);
+		sub_var_set(scp, "File_Name", "%S", path);
 		fatal_intl(scp, i18n("fingerprint $filename: $errno"));
 		/* NOTREACHED */
 	}
