@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -21,14 +21,14 @@
  */
 
 #include <ac/ctype.h>
-#include <ac/stdio.h>
+#include <stdio.h>
 #include <ac/string.h>
 #include <ac/stdlib.h>
 
 #include <arglex2.h>
 #include <change.h>
-#include <change/branch.h>
-#include <change/file.h>
+#include <change_bran.h>
+#include <change_file.h>
 #include <commit.h>
 #include <error.h>
 #include <fstrcmp.h>
@@ -40,7 +40,6 @@
 #include <project.h>
 #include <project_hist.h>
 #include <pstate.h>
-#include <skip_unlucky.h>
 #include <sub.h>
 #include <trace.h>
 #include <user.h>
@@ -244,8 +243,8 @@ convert_to_new_format(pp)
 
 			yuck:
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", pp->pstate_path);
-			sub_var_set_charstar(scp, "FieLD_Name", "src");
+			sub_var_set(scp, "File_Name", "%S", pp->pstate_path);
+			sub_var_set(scp, "FieLD_Name", "src");
 			project_fatal(pp, scp, i18n("$filename: corrupted \"$field_name\" field"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -259,10 +258,8 @@ convert_to_new_format(pp)
 		sp2->mask |= fstate_src_action_mask;
 		if (sp1->edit_number)
 		{
-			sp2->edit = history_version_type.alloc();
-			sp2->edit->revision = str_copy(sp1->edit_number);
-			sp2->edit_origin = history_version_type.alloc();
-			sp2->edit_origin->revision = str_copy(sp1->edit_number);
+			sp2->edit_number = str_copy(sp1->edit_number);
+			sp2->edit_number_origin = str_copy(sp1->edit_number);
 		}
 		sp2->locked_by = sp1->locked_by;
 		sp2->about_to_be_created_by = sp1->about_to_be_created_by;
@@ -387,11 +384,6 @@ convert_to_new_format(pp)
 		pstate_data->version_previous = 0;
 	}
 
-	/*
-	 * By default we reuse change numbers.
-	 */
-	change_branch_reuse_change_numbers_set(pp->pcp, 1);
-
 	/*
 	 * Phew!  Who would ever have guessed there was so much to do
 	 * when it came to converting a project to use branching?
@@ -541,74 +533,6 @@ lock_sync(pp)
 }
 
 
-static void get_the_owner _((project_ty *));
-
-static void
-get_the_owner(pp)
-	project_ty	*pp;
-{
-	string_ty	*s;
-
-	/*
-	 * If the project owner is already established,
-	 * don't do anything here.
-	 */
-	if (pp->uid >= 0 && pp->gid >= 0)
-		return;
-
-	/*
-	 * When checking the project home path owner, we append ``/.''
-	 * to force the automounter to mount it.  Some automounters
-	 * don't actually trigger until the directory lookup happens,
-	 * which gives nasty results when we stat the directory to see
-	 * who ownes it (the automounter frequently returns 0,0 which
-	 * gives a "tampering" error).
-	 */
-	os_become_orig();
-	s = str_format("%S/.", project_home_path_get(pp));
-	os_owner_query(s, &pp->uid, &pp->gid);
-	str_free(s);
-	os_become_undo();
-
-	/*
-	 * Make sure the project UID and GID are acceptable.  This mirrors
-	 * the tests in aegis/aenpr.c when the project is first created.
-	 */
-	if (pp->uid < AEGIS_MIN_UID)
-	{
-		sub_context_ty	*scp;
-
-		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", project_home_path_get(pp));
-		sub_var_set_long(scp, "Number1", pp->uid);
-		sub_var_set_long(scp, "Number2", AEGIS_MIN_UID);
-		fatal_intl
-		(
-			scp,
-		    i18n("$filename: uid $number1 invalid, must be >= $number2")
-		);
-		/* NOTREACHED */
-		sub_context_delete(scp);
-	}
-	if (pp->gid < AEGIS_MIN_GID)
-	{
-		sub_context_ty	*scp;
-
-		scp = sub_context_new();
-		sub_var_set_string(scp, "File_Name", project_home_path_get(pp));
-		sub_var_set_long(scp, "Number1", pp->gid);
-		sub_var_set_long(scp, "Number2", AEGIS_MIN_GID);
-		fatal_intl
-		(
-			scp,
-		    i18n("$filename: gid $number1 invalid, must be >= $number2")
-		);
-		/* NOTREACHED */
-		sub_context_delete(scp);
-	}
-}
-
-
 pstate
 project_pstate_get(pp)
 	project_ty	*pp;
@@ -631,10 +555,8 @@ project_pstate_get(pp)
 		 * This also means we can use UNIX system security
 		 * to exclude unwelcome access.
 		 */
-		get_the_owner(pp);
 		os_become_orig();
-		os_chown_check(path, 0, pp->uid, pp->gid);
-		pp->pstate_data = pstate_read_file(path);
+		pp->pstate_data = pstate_read_file(path->str_text);
 		os_become_undo();
 
 		if (!pp->pstate_data->next_test_number)
@@ -642,8 +564,8 @@ project_pstate_get(pp)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "File_Name", pp->pstate_path);
-			sub_var_set_charstar(scp, "FieLD_Name", "next_test_number");
+			sub_var_set(scp, "File_Name", "%S", pp->pstate_path);
+			sub_var_set(scp, "FieLD_Name", "next_test_number");
 			project_fatal
 			(
 				pp,
@@ -831,7 +753,7 @@ name_has_numeric_suffix(name, left, right)
 	if (!*ep)
 		/* still pointing to end of string */
 		return 0;
-	if (ep < name->str_text + 2 || !ispunct(ep[-1]))	/*lint !e416*/
+	if (ep < name->str_text + 2 || !ispunct(ep[-1]))
 		return 0;
 	*left = str_n_from_c(name->str_text, ep - 1 - name->str_text);
 	*right = magic_zero_encode(atol(ep));
@@ -845,15 +767,12 @@ project_bind_existing(pp)
 {
 	string_ty	*s;
 	string_ty	*parent_name;
-	int		alias_retry_count;
 
 	/*
 	 * make sure project exists
 	 */
 	trace(("project_bind_existing(pp = %08lX)\n{\n"/*}*/, pp));
 	assert(!pp->home_path);
-	alias_retry_count = 0;
-	alias_retry:
 	s = gonzo_project_home_path_from_name(pp->name);
 
 	/*
@@ -896,32 +815,6 @@ project_bind_existing(pp)
 		return;
 	}
 
-	/*
-	 * If the name was not found, try to find an alias match for it.
-	 * Loop if an alias is found.
-	 */
-	if (!s)
-	{
-		string_ty	*other;
-
-		other = gonzo_alias_to_actual(pp->name);
-		if (other)
-		{
-			if (++alias_retry_count > 5)
-			{
-				project_fatal
-				(
-					pp,
-					0,
-					i18n("alias loop detected")
-				);
-			}
-			str_free(pp->name);
-			pp->name = str_copy(other);
-			goto alias_retry;
-		}
-	}
-
 	/*
 	 * If the name was not found, try to find a fuzzy match for it.
 	 * In general, this results in more informative error messages.
@@ -953,8 +846,8 @@ project_bind_existing(pp)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", pp->name);
-			sub_var_set_string(scp, "Guess", best);
+			sub_var_set(scp, "Name", "%S", pp->name);
+			sub_var_set(scp, "Guess", "%S", best);
 			fatal_intl(scp, i18n("no $name project, closest is $guess"));
 		}
 		else
@@ -962,7 +855,7 @@ project_bind_existing(pp)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", pp->name);
+			sub_var_set(scp, "Name", "%S", pp->name);
 			fatal_intl(scp, i18n("no $name project"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -1026,7 +919,7 @@ project_bind_new(pp)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Name", pp->name);
+		sub_var_set(scp, "Name", "%S", pp->name);
 		fatal_intl(scp, i18n("project $name exists"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -1235,7 +1128,7 @@ project_find_branch(pp, version_string)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Number", version_string);
+		sub_var_set(scp, "Number", "%s", version_string);
 		fatal_intl(scp, i18n("bad version $number"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -1257,7 +1150,7 @@ project_find_branch(pp, version_string)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "Number", version_string);
+			sub_var_set(scp, "Number", "%s", version_string);
 			change_fatal(cp, scp, i18n("version $number not a branch"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -1280,7 +1173,6 @@ project_pstate_write(pp)
 	string_ty	*filename_new;
 	string_ty	*filename_old;
 	static int	count;
-	int		compress;
 
 	trace(("project_pstate_write(pp)\n{\n"/*}*/, pp));
 
@@ -1293,7 +1185,6 @@ project_pstate_write(pp)
 	/*
 	 * write it out
 	 */
-	compress = project_compress_database_get(pp);
 	if (pp->pstate_data)
 	{
 		filename = project_pstate_path_get(pp);
@@ -1307,13 +1198,13 @@ project_pstate_write(pp)
 		if (pp->is_a_new_file)
 		{
 			undo_unlink_errok(filename_new);
-			pstate_write_file(filename_new, pp->pstate_data, compress);
+			pstate_write_file(filename_new->str_text, pp->pstate_data);
 			commit_rename(filename_new, filename);
 		}
 		else
 		{
 			undo_unlink_errok(filename_new);
-			pstate_write_file(filename_new, pp->pstate_data, compress);
+			pstate_write_file(filename_new->str_text, pp->pstate_data);
 			commit_rename(filename, filename_old);
 			commit_rename(filename_new, filename);
 			commit_unlink_errok(filename_old);
@@ -1364,7 +1255,7 @@ project_home_path_get(pp)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", pp->name);
+			sub_var_set(scp, "Name", "%S", pp->name);
 			fatal_intl(scp, i18n("no $name project"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -1415,7 +1306,7 @@ project_home_path_set(pp, s)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_charstar(scp, "Name", arglex_token_name(arglex_token_directory));
+		sub_var_set(scp, "Name", "%s", arglex_token_name(arglex_token_directory));
 		fatal_intl(scp, i18n("duplicate $name option"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -1438,7 +1329,7 @@ project_top_path_get(pp, resolve)
 	change_ty	*cp;
 
 	cp = project_change_get(pp);
-	return change_top_path_get(cp, resolve);
+	return change_development_directory_get(cp, resolve);
 }
 
 
@@ -1611,7 +1502,7 @@ project_error(pp, scp, s)
 	 * pass the message to the error function
 	 */
 	/* re-use substitution context */
-	sub_var_set_string(scp, "Message", msg);
+	sub_var_set(scp, "Message", "%S", msg);
 	str_free(msg);
 	subst_intl_project(scp, pp);
 	error_intl(scp, i18n("project \"$project\": $message"));
@@ -1648,7 +1539,7 @@ project_fatal(pp, scp, s)
 	 * pass the message to the error function
 	 */
 	/* re-use substitution context */
-	sub_var_set_string(scp, "Message", msg);
+	sub_var_set(scp, "Message", "%S", msg);
 	str_free(msg);
 	subst_intl_project(scp, pp);
 	fatal_intl(scp, i18n("project \"$project\": $message"));
@@ -1686,7 +1577,7 @@ project_verbose(pp, scp, s)
 	 * pass the message to the error function
 	 */
 	/* re-use the substitution context */
-	sub_var_set_string(scp, "Message", msg);
+	sub_var_set(scp, "Message", "%S", msg);
 	str_free(msg);
 	subst_intl_project(scp, pp);
 	verbose_intl(scp, i18n("project \"$project\": $message"));
@@ -1821,7 +1712,12 @@ project_uid_get(pp)
 {
 	while (pp->parent)
 		pp = pp->parent;
-	get_the_owner(pp);
+	if (pp->uid < 0)
+	{
+		os_become_orig();
+		os_owner_query(project_home_path_get(pp), &pp->uid, &pp->gid);
+		os_become_undo();
+	}
 	return pp->uid;
 }
 
@@ -1832,7 +1728,12 @@ project_gid_get(pp)
 {
 	while (pp->parent)
 		pp = pp->parent;
-	get_the_owner(pp);
+	if (pp->gid < 0)
+	{
+		os_become_orig();
+		os_owner_query(project_home_path_get(pp), &pp->uid, &pp->gid);
+		os_become_undo();
+	}
 	return pp->gid;
 }
 
@@ -1904,7 +1805,7 @@ project_become_undo()
  *	when not futher required.
  */
 
-fstate_src
+string_ty *
 project_delta_to_edit(pp, delta_number, file_name)
 	project_ty	*pp;
 	long		delta_number;
@@ -1942,7 +1843,7 @@ project_delta_to_edit(pp, delta_number, file_name)
  *	when not futher required.
  */
 
-fstate_src
+string_ty *
 project_delta_date_to_edit(pp, when, file_name)
 	project_ty	*pp;
 	time_t		when;
@@ -1975,17 +1876,12 @@ project_next_test_number_get(pp)
 {
 	pstate		pstate_data;
 	long		result;
-	int		skip;
 
 	trace(("project_next_test_number_get(pp = %08lX)\n{\n"/*}*/, pp));
-	skip = project_skip_unlucky_get(pp);
 	while (pp->parent)
 		pp = pp->parent;
 	pstate_data = project_pstate_get(pp);
-	result = pstate_data->next_test_number;
-	if (skip)
-		result = skip_unlucky(result);
-	pstate_data->next_test_number = result + 1;
+	result = pstate_data->next_test_number++;
 	trace(("return %ld;\n", result));
 	trace((/*{*/"}\n"));
 	return result;
@@ -2015,95 +1911,89 @@ project_minimum_change_number_set(pp, n)
 }
 
 
-int
-project_reuse_change_numbers_get(pp)
-	project_ty	*pp;
-{
-	change_ty	*cp;
-
-	cp = project_change_get(pp);
-	return change_branch_reuse_change_numbers_get(cp);
-}
-
-
 void
-project_reuse_change_numbers_set(pp, n)
-	project_ty	*pp;
-	int		n;
+project_list_get(wlp)
+	string_list_ty		*wlp;
 {
-	change_ty	*cp;
+	size_t		j;
 
-	cp = project_change_get(pp);
-	change_branch_reuse_change_numbers_set(cp, n);
-}
+	/*
+	 * get the top-level project list
+	 */
+	trace(("project_list_get()\n{\n"/*}*/));
+	gonzo_project_list(wlp);
 
+	/*
+	 * chase down each one, looking for branches
+	 *
+	 * This list will get longer as we search.  It is bounded by the
+	 * finite nature of the branch tree.
+	 */
+	for (j = 0; j < wlp->nstrings; ++j)
+	{
+		string_ty	*name;
+		project_ty	*pp;
+		int		err;
 
-long
-project_minimum_branch_number_get(pp)
-	project_ty	*pp;
-{
-	change_ty	*cp;
+		name = wlp->string[j];
+		trace(("name = \"%s\"\n", name->str_text));
+		pp = project_alloc(name);
+		project_bind_existing(pp);
 
-	cp = project_change_get(pp);
-	return change_branch_minimum_branch_number_get(cp);
-}
+		/*
+		 * watch out for permissions
+		 * (returns errno of attempt to read project state)
+		 */
+		err = project_is_readable(pp);
 
+		if (!err)
+		{
+			change_ty	*cp;
+			long		*lp;
+			size_t		len;
+			long		k;
 
-void
-project_minimum_branch_number_set(pp, n)
-	project_ty	*pp;
-	long		n;
-{
-	change_ty	*cp;
+			/*
+			 * check each change
+			 * add it to the list if it is a branch
+			 */
+			trace(("readable\n"));
+			cp = project_change_get(pp);
+			change_branch_sub_branch_list_get(cp, &lp, &len);
+			for (k = 0; k < len; ++k)
+			{
+				long		cn;
+				change_ty	*cp2;
 
-	cp = project_change_get(pp);
-	change_branch_minimum_branch_number_set(cp, n);
-}
+				cn = lp[k];
+				trace(("cn = %ld\n", cn));
+				cp2 = change_alloc(pp, cn);
+				change_bind_existing(cp2);
+				/* active only */
+				if (change_is_a_branch(cp2))
+				{
+					string_ty	*s;
 
+					/* punctuation (needs cp2) */
+					trace(("is a branch\n"));
+					s = str_format("%S.%ld", name, magic_zero_decode(cn));
+					string_list_append(wlp, s);
+					str_free(s);
+				}
+				change_free(cp2);
+			}
+			/* do NOT free ``lp'' */
+			/* do NOT free ``cp'' */
+		}
+		project_free(pp);
+	}
 
-int
-project_skip_unlucky_get(pp)
-	project_ty	*pp;
-{
-	change_ty	*cp;
-
-	cp = project_change_get(pp);
-	return change_branch_skip_unlucky_get(cp);
-}
-
-
-void
-project_skip_unlucky_set(pp, n)
-	project_ty	*pp;
-	int		n;
-{
-	change_ty	*cp;
-
-	cp = project_change_get(pp);
-	change_branch_skip_unlucky_set(cp, n);
-}
-
-
-int
-project_compress_database_get(pp)
-	project_ty	*pp;
-{
-	change_ty	*cp;
-
-	cp = project_change_get(pp);
-	return change_branch_compress_database_get(cp);
-}
-
-
-void
-project_compress_database_set(pp, n)
-	project_ty	*pp;
-	int		n;
-{
-	change_ty	*cp;
-
-	cp = project_change_get(pp);
-	change_branch_compress_database_set(cp, n);
+	/*
+	 * sort the list of names
+	 * (C locale)
+	 */
+	string_list_sort(wlp);
+	trace((/*{*/"}\n"));
 }
 
 
