@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1995-1998, 2001 Peter Miller;
+ *	Copyright (C) 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * MANIFEST: functions to manipulate project history
  */
 
-#include <change/branch.h>
+#include <change_bran.h>
 #include <error.h>
 #include <project_hist.h>
 #include <trace.h>
