@@ -1,6 +1,6 @@
 /*
  *	aegis - project change supervisor
- *	Copyright (C) 1991-2001 Peter Miller;
+ *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 #include <ac/stdlib.h>
 #include <ac/string.h>
 
+#include <ac/pwd.h>
 #include <ac/grp.h>
 #include <ac/unistd.h>
 
@@ -32,7 +33,6 @@
 #include <commit.h>
 #include <error.h>
 #include <fstrcmp.h>
-#include <getpw_cache.h>
 #include <gonzo.h>
 #include <help.h>
 #include <lock.h>
@@ -40,11 +40,9 @@
 #include <os.h>
 #include <project.h>
 #include <project_hist.h>
-#include <stracc.h>
 #include <sub.h>
 #include <trace.h>
 #include <user.h>
-#include <uname.h>
 #include <undo.h>
 #include <str_list.h>
 #include <zero.h>
@@ -101,7 +99,7 @@ user_set_project(up, pp)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", up->gid);
+		sub_var_set(scp, "Number", "%d", up->gid);
 		fatal_intl(scp, i18n("gid $number unknown"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -179,13 +177,13 @@ user_numeric(pp, uid)
 	 * Always use the number as the primary reference:
 	 * system treats the first entry as cannonical, so do we.
 	 */
-	pw = getpwuid_cached(uid);
+	pw = getpwuid(uid);
 	if (!pw)
 	{
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", uid);
+		sub_var_set(scp, "Number", "%d", uid);
 		fatal_intl(scp, i18n("uid $number unknown"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -223,7 +221,7 @@ user_numeric(pp, uid)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_long(scp, "Number", up->gid);
+		sub_var_set(scp, "Number", "%d", up->gid);
 		fatal_intl(scp, i18n("gid $number unknown"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -309,7 +307,7 @@ user_numeric2(uid, gid)
 	 * try the passwd file,
 	 *	otherwise default to something sensable
 	 */
-	pw = getpwuid_cached(uid);
+	pw = getpwuid(uid);
 	if (pw)
 	{
 		up->name = str_from_c(pw->pw_name);
@@ -385,7 +383,7 @@ user_symbolic(pp, name)
 
 	trace(("user_symbolic(pp = %08lX, name = \"%s\")\n{\n"/*}*/, pp,
 		name->str_text));
-	pw = getpwnam_cached(name);
+	pw = getpwnam(name->str_text);
 	if (!pw)
 	{
 		string_ty	*best;
@@ -414,8 +412,8 @@ user_symbolic(pp, name)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", name);
-			sub_var_set_string(scp, "Guess", best);
+			sub_var_set(scp, "Name", "%S", name);
+			sub_var_set(scp, "Guess", "%S", best);
 			fatal_intl
 			(
 				scp,
@@ -429,7 +427,7 @@ user_symbolic(pp, name)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_string(scp, "Name", name);
+			sub_var_set(scp, "Name", "%S", name);
 			fatal_intl(scp, i18n("user $name unknown"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -603,17 +601,6 @@ user_name(up)
 }
 
 
-string_ty *
-user_name2(up)
-	user_ty		*up;
-{
-	trace(("user_name2(up = %08lX)\n{\n"/*}*/, up));
-	trace(("return \"%s\";\n", up->name->str_text));
-	trace((/*{*/"}\n"));
-	return up->full_name;
-}
-
-
 /*
  * NAME
  *	user_id
@@ -811,7 +798,7 @@ user_ustate_get(up)
 		if (os_exists(up->ustate_path))
 		{
 			up->ustate_data =
-				ustate_read_file(up->ustate_path);
+				ustate_read_file(up->ustate_path->str_text);
 		}
 		else
 		{
@@ -894,7 +881,7 @@ user_uconf_get(up)
 		user_become(up);
 		if (os_exists(up->uconf_path))
 		{
-			tmp = uconf_read_file(up->uconf_path);
+			tmp = uconf_read_file(up->uconf_path->str_text);
 			fix_default_change(tmp);
 		}
 		else
@@ -968,18 +955,6 @@ user_uconf_get(up)
 			data->lock_wait_preference = tmp->lock_wait_preference;
 			data->mask |= uconf_lock_wait_preference_mask;
 		}
-		if (!data->email_address && tmp->email_address)
-			data->email_address = str_copy(tmp->email_address);
-		if
-		(
-			!(data->mask & uconf_whiteout_preference_mask)
-		&&
-			(tmp->mask & uconf_whiteout_preference_mask)
-		)
-		{
-			data->whiteout_preference = tmp->whiteout_preference;
-			data->mask |= uconf_whiteout_preference_mask;
-		}
 		uconf_type.free(tmp);
 	}
 	trace(("return %08lX;\n", up->uconf_data));
@@ -1056,7 +1031,7 @@ user_full_name(name)
 	static size_t	trimmed_max;
 
 	trace(("user_full_name(name = \"%s\")\n{\n"/*}*/, name->str_text));
-	pw = getpwnam_cached(name);
+	pw = getpwnam(name->str_text);
 	if (!pw)
 		result = "";
 	else if (pw->pw_gecos && pw->pw_gecos[0])
@@ -1131,13 +1106,13 @@ user_ustate_write(up)
 	if (up->ustate_is_new)
 	{
 		undo_unlink_errok(filename_new);
-		ustate_write_file(filename_new, up->ustate_data, 0);
+		ustate_write_file(filename_new->str_text, up->ustate_data);
 		commit_rename(filename_new, up->ustate_path);
 	}
 	else
 	{
 		undo_unlink_errok(filename_new);
-		ustate_write_file(filename_new, up->ustate_data, 0);
+		ustate_write_file(filename_new->str_text, up->ustate_data);
 		commit_rename(up->ustate_path, filename_old);
 		commit_rename(filename_new, up->ustate_path);
 		commit_unlink_errok(filename_old);
@@ -1431,9 +1406,9 @@ user_error(up, scp, fmt)
 	s = subst_intl(scp, fmt);
 
 	/* re-use substitution context */
-	sub_var_set_string(scp, "MeSsaGe", s);
+	sub_var_set(scp, "MeSsaGe", "%S", s);
 	str_free(s);
-	sub_var_set_string(scp, "Name", up->name);
+	sub_var_set(scp, "Name", "%S", up->name);
 	error_intl(scp, i18n("user $name: $message"));
 
 	if (need_to_delete)
@@ -1463,9 +1438,9 @@ user_fatal(up, scp, fmt)
 	s = subst_intl(scp, fmt);
 
 	/* re-use substitution context */
-	sub_var_set_string(scp, "MeSsaGe", s);
+	sub_var_set(scp, "MeSsaGe", "%S", s);
 	str_free(s);
-	sub_var_set_string(scp, "Name", up->name);
+	sub_var_set(scp, "Name", "%S", up->name);
 	fatal_intl(scp, i18n("user $name: $message"));
 
 	if (need_to_delete)
@@ -1578,7 +1553,7 @@ project_dot_change(s, p)
 	||
 		memcmp(s->str_text, p->str_text, p->str_length)
 	||
-		!ispunct((unsigned char)s->str_text[p->str_length])
+		s->str_text[p->str_length] != '.'
 	)
 		return 0;
 	suffix = s->str_text + p->str_length + 1;
@@ -1610,7 +1585,7 @@ user_default_change(up)
 			sub_context_ty	*scp;
 
 			scp = sub_context_new();
-			sub_var_set_charstar(scp, "Name", "AEGIS_CHANGE");
+			sub_var_set(scp, "Name", "AEGIS_CHANGE");
 			fatal_intl(scp, i18n("$$$name must be positive"));
 			/* NOTREACHED */
 			sub_context_delete(scp);
@@ -1984,13 +1959,13 @@ user_uid_check(name)
 {
 	struct passwd	*pw;
 
-	pw = getpwnam_cached(name);
+	pw = getpwnam(name->str_text);
 	if (!pw)
 	{
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Name", name);
+		sub_var_set(scp, "Name", "%S", name);
 		fatal_intl(scp, i18n("user $name unknown"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -2034,7 +2009,7 @@ user_gid_check(name)
 		sub_context_ty	*scp;
 
 		scp = sub_context_new();
-		sub_var_set_string(scp, "Name", name);
+		sub_var_set(scp, "Name", "%S", name);
 		fatal_intl(scp, i18n("group \"$name\" unknown"));
 		/* NOTREACHED */
 		sub_context_delete(scp);
@@ -2170,7 +2145,7 @@ ask(filename, isdir)
 		(
 			"Delete the \"%s\" %s? ",
 			filename->str_text,
-			(isdir ? "directory and everything below it" : "file")
+			(isdir ? "directory" : "file")
 		);
 		fflush(stdout);
 
@@ -2241,7 +2216,7 @@ user_delete_file_query(up, filename, isdir)
 	(
 		cmd_line_pref == del_pref_interactive
 	&&
-		(!isatty(0) || os_background())
+		(!isatty(0) || !isatty(1) || os_background())
 	)
 		cmd_line_pref = del_pref_no_keep;
 
@@ -2292,46 +2267,14 @@ user_pager_preference(up)
 }
 
 
-static int uconf_persevere_option = -1;
-
-
-void
-user_persevere_argument(usage)
-	void		(*usage)_((void));
-{
-	if (uconf_persevere_option >= 0)
-		duplicate_option(usage);
-	switch (arglex_token)
-	{
-	default:
-		assert(0);
-		return;
-
-	case arglex_token_persevere:
-		uconf_persevere_option = 1;
-		break;
-
-	case arglex_token_no_persevere:
-		uconf_persevere_option = 0;
-		break;
-	}
-}
-
-
 int
-user_persevere_preference(up, dflt)
+user_persevere_preference(up)
 	user_ty		*up;
-	int		dflt;
 {
 	uconf		uconf_data;
 
-	if (uconf_persevere_option >= 0)
-		return uconf_persevere_option;
-
 	uconf_data = user_uconf_get(up);
-	if (uconf_data->mask & uconf_persevere_preference_mask)
-		return (uconf_data->persevere_preference == uconf_persevere_preference_all);
-	return dflt;
+	return (uconf_data->persevere_preference == uconf_persevere_preference_all);
 }
 
 
@@ -2406,52 +2349,6 @@ user_lock_wait(up)
 }
 
 
-static int uconf_whiteout_option = -1;
-
-
-void
-user_whiteout_argument(usage)
-	void		(*usage)_((void));
-{
-	if (uconf_whiteout_option >= 0)
-		duplicate_option(usage);
-	switch (arglex_token)
-	{
-	default:
-		assert(0);
-		return;
-
-	case arglex_token_whiteout:
-		uconf_whiteout_option = 1;
-		break;
-
-	case arglex_token_whiteout_not:
-		uconf_whiteout_option = 0;
-		break;
-	}
-}
-
-
-int
-user_whiteout(up)
-	user_ty		*up;
-{
-	if (uconf_whiteout_option < 0)
-	{
-		uconf		uconf_data;
-		uconf_whiteout_preference_ty result;
-
-		if (!up)
-			up = user_executing((project_ty *)0);
-		uconf_data = user_uconf_get(up);
-		result = uconf_data->whiteout_preference;
-		uconf_whiteout_option =
-			(result == uconf_whiteout_preference_always);
-	}
-	return uconf_whiteout_option;
-}
-
-
 static int uconf_symlink_pref_option = -1;
 
 
@@ -2552,92 +2449,3 @@ user_relative_filename_preference(up, dflt)
 	}
 	return user_relative_filename_preference_option;
 }
-
-
-/*
- * NAME
- *	clean_up
- *
- * SYNOPSIS
- *	string_ty *clean_up(string_ty *);
- *
- * DESCRIPTION
- *	The clean_up function is used to clean up a user's full name
- *	into an rfc822-acceptable string, suitable for use within an
- *	email address.
- *
- * RETURNS
- *	string_ty *; use str_free when finished with
- */
-
-static string_ty *clean_up _((string_ty *));
-
-static string_ty *
-clean_up(s)
-	string_ty	*s;
-{
-	stracc_t	buf;
-	const char	*cp;
-	int		c;
-	string_ty	*result;
-	int		prev;
-
-	stracc_constructor(&buf);
-	stracc_open(&buf);
-	prev = ' ';
-	for (cp = s->str_text; *cp; ++cp)
-	{
-		c = (unsigned char)*cp;
-		if (isspace(c) || strchr("@,<>()[]{}'\"", c) || !isprint(c))
-			c = ' ';
-		if (c != ' ' || prev != ' ')
-			stracc_char(&buf, c);
-		prev = c;
-	}
-	while (buf.length > 0 && buf.buffer[buf.length - 1] == ' ')
-		buf.length--;
-	result = stracc_close(&buf);
-	stracc_destructor(&buf);
-	return result;
-}
-
-
-/*
- * NAME
- *	user_email_address
- *
- * SYNOPSIS
- *	string_ty *user_email_address(user_ty *);
- *
- * DESCRIPTION
- *	The user_email_address is used to read the user's preferences
- *	for her email address.	Defaults to full name from /etc/passwd,
- *	then login name at hostname (not generally useful).
- *
- * RETURNS
- *	string_ty *; DO NOT use str_free when finished
- */
-
-string_ty *
-user_email_address(up)
-	user_ty		*up;
-{
-	uconf		uconf_data;
-	string_ty	*full_name;
-
-	uconf_data = user_uconf_get(up);
-	if (!uconf_data->email_address)
-	{
-		full_name = clean_up(user_name2(up));
-		uconf_data->email_address =
-			str_format
-			(
-				"%S <%S@%S>",
-				full_name,
-				user_name(up),
-				uname_node_get()
-			);
-		str_free(full_name);
-	}
-	return uconf_data->email_address;
-}
