@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1991-2001 Peter Miller;
+#	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -73,7 +73,7 @@ check_it()
 {
 	sed	-e "s|$work|...|g" \
 		-e 's|= [0-9][0-9]*; /.*|= TIME;|' \
-		-e "s/\"$USER\"/\"USER\"/g" \
+		-e "s/$USER/USER/g" \
 		-e 's/delta[0-9][0-9]*/delta/' \
 		-e 's/19[0-9][0-9]/YYYY/' \
 		-e 's/20[0-9][0-9]/YYYY/' \
@@ -203,8 +203,6 @@ branch =
 	reviewer_may_integrate = false;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	change =
 	[
 	];
@@ -212,7 +210,6 @@ branch =
 	[
 		"USER",
 	];
-	reuse_change_numbers = true;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -241,10 +238,6 @@ developers_may_create_changes = false;
 umask = 022;
 default_test_exemption = false;
 minimum_change_number = 10;
-reuse_change_numbers = true;
-minimum_branch_number = 1;
-skip_unlucky = false;
-compress_database = false;
 fubar
 if test $? -ne 0 ; then no_result; fi
 check_it test.out ok
@@ -497,7 +490,7 @@ if test ! -r $workproj/info/change/0/001 ; then fail ; fi
 #
 # finish development of the change
 #
-activity="develop end 495"
+aectivity="develop end 444"
 $bin/aegis -dev_end -list -lib $worklib -p foo > test.out
 if test $? -ne 0 ; then fail; fi
 $bin/aegis -dev_end -lib $worklib -p foo
@@ -532,7 +525,6 @@ if test $? -ne 0 ; then fail; fi
 #
 # check the the file states are as they should be
 #
-activity="review fail ck.a 501"
 cat > ok << 'fubar'
 brief_description = "This change is used to test the aegis functionality with respect to change descriptions.";
 description = "This change is used to test the aegis functionality with respect to change descriptions.";
@@ -549,17 +541,6 @@ copyright_years =
 	YYYY,
 ];
 state = being_developed;
-build_time = TIME;
-test_time = TIME;
-architecture_times =
-[
-	{
-		variant = "unspecified";
-		node = "NODE";
-		build_time = TIME;
-		test_time = TIME;
-	},
-];
 development_directory = ".../foo.chan";
 history =
 [
@@ -588,7 +569,6 @@ history =
 fubar
 if test $? -ne 0 ; then no_result; fi
 check_it $workproj/info/change/0/001 ok
-activity="review fail ck.b 501"
 cat > ok << 'fubar'
 src =
 [
@@ -642,13 +622,6 @@ src =
 			oldest = TIME;
 			crypto = "GUNK";
 		};
-		architecture_times =
-		[
-			{
-				variant = "unspecified";
-				test_time = TIME;
-			},
-		];
 	},
 ];
 fubar
@@ -915,31 +888,19 @@ src =
 	{
 		file_name = "config";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
 		usage = source;
 	},
 	{
 		file_name = "main.c";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
 		usage = source;
 	},
 	{
 		file_name = "test/00/t0001a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
 		usage = test;
 	},
 ];
@@ -995,8 +956,6 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	history =
 	[
 		{
@@ -1026,7 +985,6 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 1;
-	reuse_change_numbers = true;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -1156,7 +1114,7 @@ if test $? -ne 0 ; then cat test.out; fail; fi
 cat > ok << 'fubar'
 brief_description = "This change was added to make the various listings much more interesting.";
 description = "This change was added to make the various listings much more interesting.";
-cause = internal_enhancement;
+cause = internal_bug;
 test_exempt = false;
 test_baseline_exempt = false;
 regression_test_exempt = true;
@@ -1226,11 +1184,10 @@ if test $? -ne 0 ; then cat test.out; fail; fi
 activity="integrate pass 1174"
 $bin/aegis -intpass -nl -lib $worklib -p foo > test.out 2>&1
 if test $? -ne 0 ; then cat test.out; fail; fi
-activity="integrate pass 1193"
 cat > ok << 'fubar'
 brief_description = "This change was added to make the various listings much more interesting.";
 description = "This change was added to make the various listings much more interesting.";
-cause = internal_enhancement;
+cause = internal_bug;
 test_exempt = false;
 test_baseline_exempt = false;
 regression_test_exempt = true;
@@ -1281,46 +1238,31 @@ history =
 fubar
 if test $? -ne 0 ; then no_result; fi
 check_it $workproj/info/change/0/002 ok
-activity="integrate pass 1248"
 cat > ok << 'fubar'
 src =
 [
 	{
 		file_name = "main.c";
 		action = modify;
-		edit =
-		{
-			revision = "1.2";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.2";
+		edit_number_origin = "1.1";
 		usage = source;
 	},
 	{
 		file_name = "test/00/t0002a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
 		usage = test;
 	},
 ];
 fubar
 if test $? -ne 0 ; then no_result; fi
 check_it $workproj/info/change/0/002.fs ok
-activity="integrate pass 1269"
 cat > ok << 'fubar'
 next_test_number = 3;
 fubar
 if test $? -ne 0 ; then no_result; fi
 check_it $workproj/info/state ok
-activity="integrate pass 1275"
 cat > ok << 'fubar'
 brief_description = "A bogus project created to test things.";
 description = "The \"foo\" program.";
@@ -1372,8 +1314,6 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	history =
 	[
 		{
@@ -1407,28 +1347,18 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 1;
-	reuse_change_numbers = true;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
 check_it $workproj/info/trunk ok
-activity="integrate pass 1367"
 cat > ok << 'fubar'
 src =
 [
 	{
 		file_name = "config";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = source;
 		file_fp =
 		{
@@ -1444,16 +1374,8 @@ src =
 	{
 		file_name = "main.c";
 		action = create;
-		edit =
-		{
-			revision = "1.2";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.2";
-			encoding = none;
-		};
+		edit_number = "1.2";
+		edit_number_origin = "1.2";
 		usage = source;
 		file_fp =
 		{
@@ -1470,16 +1392,8 @@ src =
 	{
 		file_name = "test/00/t0001a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = test;
 		file_fp =
 		{
@@ -1498,16 +1412,8 @@ src =
 	{
 		file_name = "test/00/t0002a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = test;
 		file_fp =
 		{
@@ -1528,7 +1434,6 @@ src =
 fubar
 if test $? -ne 0 ; then no_result; fi
 check_it $workproj/info/trunk.fs ok
-activity="integrate pass 1451"
 cat > ok << 'fubar'
 own =
 [
