@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1991-2001 Peter Miller;
+#	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -84,7 +84,7 @@ check_it()
 {
 	sed	-e "s|$work|...|g" \
 		-e 's|= [0-9][0-9]*; /.*|= TIME;|' \
-		-e "s/\"$USER\"/\"USER\"/g" \
+		-e "s/$USER/USER/g" \
 		-e 's/19[0-9][0-9]/YYYY/' \
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/crypto = ".*"/crypto = "GUNK"/' \
@@ -423,31 +423,19 @@ src =
 	{
 		file_name = "config";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
 		usage = source;
 	},
 	{
 		file_name = "main.c";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
 		usage = source;
 	},
 	{
 		file_name = "test/00/t0001a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
 		usage = test;
 	},
 ];
@@ -494,8 +482,6 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	history =
 	[
 		{
@@ -524,8 +510,6 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
-	reuse_change_numbers = true;
-	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -538,16 +522,8 @@ src =
 	{
 		file_name = "config";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = source;
 		file_fp =
 		{
@@ -569,16 +545,8 @@ src =
 	{
 		file_name = "main.c";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = source;
 		file_fp =
 		{
@@ -600,16 +568,8 @@ src =
 	{
 		file_name = "test/00/t0001a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = test;
 		file_fp =
 		{
@@ -664,8 +624,6 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	change =
 	[
 		1,
@@ -691,8 +649,6 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
-	reuse_change_numbers = true;
-	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -750,8 +706,6 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	change =
 	[
 		1,
@@ -777,8 +731,6 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
-	reuse_change_numbers = true;
-	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -865,11 +817,7 @@ src =
 	{
 		file_name = "main.c";
 		action = modify;
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number_origin = "1.1";
 		usage = source;
 	},
 ];
@@ -916,8 +864,6 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	history =
 	[
 		{
@@ -947,8 +893,6 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
-	reuse_change_numbers = true;
-	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
