@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1995-2001 Peter Miller;
+#	Copyright (C) 1995, 1996, 1997, 1998 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -83,7 +83,7 @@ check_it()
 {
 	sed	-e "s|$work|...|g" \
 		-e 's|= [0-9][0-9]*; /.*|= TIME;|' \
-		-e "s/\"$USER\"/\"USER\"/g" \
+		-e "s/$USER/USER/g" \
 		-e 's/19[0-9][0-9]/YYYY/' \
 		-e 's/20[0-9][0-9]/YYYY/' \
 		< $1 > $work/sed.out
@@ -236,8 +236,6 @@ branch =
 	integrate_pass_notify_command = "sh ${source lib/ip.sh} $project $change $developer $reviewer $integrator";
 	integrate_fail_notify_command = "sh ${source lib/if.sh} $project $change $developer $reviewer $integrator";
 	default_test_exemption = true;
-	skip_unlucky = false;
-	compress_database = false;
 	history =
 	[
 		{
@@ -310,7 +308,6 @@ branch =
 	[
 		"USER",
 	];
-	reuse_change_numbers = true;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -321,31 +318,15 @@ src =
 	{
 		file_name = "config";
 		action = create;
-		edit =
-		{
-			revision = "3";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "3";
-			encoding = none;
-		};
+		edit_number = "3";
+		edit_number_origin = "3";
 		usage = source;
 	},
 	{
 		file_name = "main.c";
 		action = create;
-		edit =
-		{
-			revision = "2";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "2";
-			encoding = none;
-		};
+		edit_number = "2";
+		edit_number_origin = "2";
 		usage = build;
 	},
 ];
