@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	aegis - project change supervisor
-#	Copyright (C) 1995-2001 Peter Miller;
+#	Copyright (C) 1995, 1996, 1997, 1998 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -76,7 +76,7 @@ check_it()
 {
 	sed	-e "s|$work|...|g" \
 		-e 's|= [0-9][0-9]*; /.*|= TIME;|' \
-		-e "s/\"$USER\"/\"USER\"/g" \
+		-e "s/$USER/USER/g" \
 		-e 's/19[0-9][0-9]/YYYY/' \
 		-e 's/20[0-9][0-9]/YYYY/' \
 		-e 's/node = ".*";/node = "NODE";/' \
@@ -441,8 +441,6 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	change =
 	[
 	];
@@ -463,8 +461,6 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
-	reuse_change_numbers = true;
-	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -524,8 +520,6 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	change =
 	[
 	];
@@ -546,8 +540,6 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
-	reuse_change_numbers = true;
-	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then no_result; fi
@@ -574,9 +566,9 @@ activity="check change state file 498"
 cat > ok << fubar
 brief_description = "change one of branch two";
 description = "change one of branch two";
-cause = internal_bug;
+cause = internal_enhancement;
 test_exempt = false;
-test_baseline_exempt = false;
+test_baseline_exempt = true;
 regression_test_exempt = true;
 architecture =
 [
@@ -754,16 +746,8 @@ src =
 	{
 		file_name = "main.c";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = source;
 		locked_by = 1;
 		about_to_be_copied_by = 1;
@@ -849,8 +833,6 @@ branch =
 	reviewer_may_integrate = true;
 	developers_may_create_changes = false;
 	default_test_exemption = false;
-	skip_unlucky = false;
-	compress_database = false;
 	history =
 	[
 		{
@@ -879,8 +861,6 @@ branch =
 		"USER",
 	];
 	minimum_change_number = 10;
-	reuse_change_numbers = true;
-	minimum_branch_number = 1;
 };
 fubar
 if test $? -ne 0 ; then cat test.out; no_result; fi
@@ -892,16 +872,8 @@ src =
 	{
 		file_name = "main.c";
 		action = modify;
-		edit =
-		{
-			revision = "1.2";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.2";
+		edit_number_origin = "1.1";
 		usage = source;
 		file_fp =
 		{
@@ -924,16 +896,8 @@ src =
 	{
 		file_name = "test/00/t0002a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = test;
 		file_fp =
 		{
@@ -977,16 +941,8 @@ src =
 	{
 		file_name = "config";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = source;
 		file_fp =
 		{
@@ -1002,16 +958,8 @@ src =
 	{
 		file_name = "main.c";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = source;
 		file_fp =
 		{
@@ -1028,16 +976,8 @@ src =
 	{
 		file_name = "test/00/t0001a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = test;
 		file_fp =
 		{
@@ -1094,16 +1034,8 @@ src =
 	{
 		file_name = "main.c";
 		action = modify;
-		edit =
-		{
-			revision = "1.2";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.2";
+		edit_number_origin = "1.1";
 		usage = source;
 		file_fp =
 		{
@@ -1126,16 +1058,8 @@ src =
 	{
 		file_name = "test/00/t0002a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = test;
 		file_fp =
 		{
@@ -1177,16 +1101,8 @@ src =
 	{
 		file_name = "main.c";
 		action = modify;
-		edit =
-		{
-			revision = "1.3";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.3";
+		edit_number_origin = "1.1";
 		usage = source;
 		test =
 		[
@@ -1197,16 +1113,8 @@ src =
 	{
 		file_name = "test/00/t0002a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.2";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.2";
+		edit_number_origin = "1.1";
 		usage = test;
 	},
 ];
@@ -1230,16 +1138,8 @@ src =
 	{
 		file_name = "config";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = source;
 		file_fp =
 		{
@@ -1255,16 +1155,8 @@ src =
 	{
 		file_name = "main.c";
 		action = create;
-		edit =
-		{
-			revision = "1.3";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.3";
-			encoding = none;
-		};
+		edit_number = "1.3";
+		edit_number_origin = "1.3";
 		usage = source;
 		file_fp =
 		{
@@ -1281,16 +1173,8 @@ src =
 	{
 		file_name = "test/00/t0001a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.1";
-			encoding = none;
-		};
+		edit_number = "1.1";
+		edit_number_origin = "1.1";
 		usage = test;
 		file_fp =
 		{
@@ -1309,16 +1193,8 @@ src =
 	{
 		file_name = "test/00/t0002a.sh";
 		action = create;
-		edit =
-		{
-			revision = "1.2";
-			encoding = none;
-		};
-		edit_origin =
-		{
-			revision = "1.2";
-			encoding = none;
-		};
+		edit_number = "1.2";
+		edit_number_origin = "1.2";
 		usage = test;
 		file_fp =
 		{
